#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


        //#include "chipmunk/chipmunk_types.h"
        //#include "chipmunk/cpVect.h"
        #include "chipmunk/chipmunk_ffi.h"
        #include "chipmunk/chipmunk.h"
        #include "chipmunk/chipmunk_unsafe.h"
        #include "chipmunk/cpPolyline.h"
        #include "chipmunk/cpMarch.h"
        
        #include "chipmunk/cpHastySpace.h" 

        // from chipmunk_private.h
        // Ideally this should not come from here, but pickle needs it.
        void cpSpaceSetStaticBody(cpSpace *space, cpBody *body);

        

#include "chipmunk/chipmunk_private.h"

typedef struct cpVectArr cpVectArr;


struct cpVectArr {
	int num, max;
	cpVect *arr;
};

void cpSpaceBodyIteratorFuncForPositions(cpBody *body, void *data){
    cpVectArr *arr = (cpVectArr*)data;
    cpVect v = cpBodyGetPosition(body);
    if (arr->num == (arr->max - 1) || arr->num == arr->max) {
        arr->max = 3*(arr->max + 1)/2;
        arr->arr = (cpVect*)cprealloc(arr->arr, arr->max*sizeof(cpVect));
    }
    arr->arr[arr->num] = v;
    arr->num++;
    
}

void cpSpaceGetBodyPositions(cpSpace *space, cpVectArr *arr) {
    cpSpaceEachBody(space, cpSpaceBodyIteratorFuncForPositions, arr);
	
}


    

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpBB, cpBB)
/*  1 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // cpBB
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  4 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpBB, cpVect)
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 34), // cpVect
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpShape *)
/*  9 */ _CFFI_OP(_CFFI_OP_POINTER, 1010), // cpShape *
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpShape *, cpTransform)
/* 12 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 13 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 33), // cpTransform
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpShape const *)
/* 16 */ _CFFI_OP(_CFFI_OP_POINTER, 1010), // cpShape const *
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpVect, double)
/* 19 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 20 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(cpVect, double, double)
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 24 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 25 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // cpBB()(double, double, double, double)
/* 28 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 29 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 30 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 31 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(cpBody *, double, double)
/* 34 */ _CFFI_OP(_CFFI_OP_POINTER, 987), // cpBody *
/* 35 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 36 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 38 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(cpConstraint const *)
/* 39 */ _CFFI_OP(_CFFI_OP_POINTER, 991), // cpConstraint const *
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(cpShape const *)
/* 42 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 44 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(cpSpace *, cpBody *)
/* 45 */ _CFFI_OP(_CFFI_OP_POINTER, 1014), // cpSpace *
/* 46 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(cpSpace const *)
/* 49 */ _CFFI_OP(_CFFI_OP_POINTER, 1014), // cpSpace const *
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 51 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(double, double)
/* 52 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 53 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 55 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // cpBody *()(void)
/* 56 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION, 672), // cpBodyType()(cpBody *)
/* 58 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 59 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION, 61), // cpCircleShape *()(cpCircleShape *, cpBody *, double, cpVect)
/* 61 */ _CFFI_OP(_CFFI_OP_POINTER, 988), // cpCircleShape *
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 63 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 64 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 66 */ _CFFI_OP(_CFFI_OP_FUNCTION, 61), // cpCircleShape *()(void)
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION, 989), // cpCollisionHandler *()(cpSpace *)
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION, 989), // cpCollisionHandler *()(cpSpace *, uintptr_t)
/* 72 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 73 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 26), // uintptr_t
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION, 989), // cpCollisionHandler *()(cpSpace *, uintptr_t, uintptr_t)
/* 76 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 77 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 26),
/* 78 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 26),
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 80 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, cpVect)
/* 81 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 82 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 83 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 85 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, cpVect, cpVect)
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 87 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 88 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, cpVect, cpVect, cpVect)
/* 92 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 93 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 94 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 96 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 98 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, cpVect, cpVect, double, double)
/* 99 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 100 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 101 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 102 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 103 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 104 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, cpVect, cpVect, double, double, double)
/* 107 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 108 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 109 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 110 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 111 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 112 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 113 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, double)
/* 116 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 117 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 118 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 119 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 120 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, double, double)
/* 121 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 122 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 123 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 124 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpBody *, cpBody *, double, double, double)
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 128 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 129 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 130 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 131 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION, 135), // cpConstraint *()(cpSpace *, cpConstraint *)
/* 134 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 135 */ _CFFI_OP(_CFFI_OP_POINTER, 991), // cpConstraint *
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION, 992), // cpContactPointSet()(cpArbiter const *)
/* 138 */ _CFFI_OP(_CFFI_OP_POINTER, 985), // cpArbiter const *
/* 139 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION, 992), // cpContactPointSet()(cpShape const *, cpShape const *)
/* 141 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 143 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION, 145), // cpDampedRotarySpring *()(cpDampedRotarySpring *, cpBody *, cpBody *, double, double, double)
/* 145 */ _CFFI_OP(_CFFI_OP_POINTER, 993), // cpDampedRotarySpring *
/* 146 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 147 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 148 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 149 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 150 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION, 145), // cpDampedRotarySpring *()(void)
/* 153 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 154 */ _CFFI_OP(_CFFI_OP_FUNCTION, 155), // cpDampedSpring *()(cpDampedSpring *, cpBody *, cpBody *, cpVect, cpVect, double, double, double)
/* 155 */ _CFFI_OP(_CFFI_OP_POINTER, 994), // cpDampedSpring *
/* 156 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 157 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 158 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 159 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 160 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 161 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 162 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 163 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 164 */ _CFFI_OP(_CFFI_OP_FUNCTION, 155), // cpDampedSpring *()(void)
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 166 */ _CFFI_OP(_CFFI_OP_FUNCTION, 167), // cpGearJoint *()(cpGearJoint *, cpBody *, cpBody *, double, double)
/* 167 */ _CFFI_OP(_CFFI_OP_POINTER, 995), // cpGearJoint *
/* 168 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 169 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 170 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 171 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 172 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 173 */ _CFFI_OP(_CFFI_OP_FUNCTION, 167), // cpGearJoint *()(void)
/* 174 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 175 */ _CFFI_OP(_CFFI_OP_FUNCTION, 176), // cpGrooveJoint *()(cpGrooveJoint *, cpBody *, cpBody *, cpVect, cpVect, cpVect)
/* 176 */ _CFFI_OP(_CFFI_OP_POINTER, 996), // cpGrooveJoint *
/* 177 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 178 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 179 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 180 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 181 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 182 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 183 */ _CFFI_OP(_CFFI_OP_FUNCTION, 176), // cpGrooveJoint *()(void)
/* 184 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 185 */ _CFFI_OP(_CFFI_OP_FUNCTION, 186), // cpPinJoint *()(cpPinJoint *, cpBody *, cpBody *, cpVect, cpVect)
/* 186 */ _CFFI_OP(_CFFI_OP_POINTER, 999), // cpPinJoint *
/* 187 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 188 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 189 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 190 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 191 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 192 */ _CFFI_OP(_CFFI_OP_FUNCTION, 186), // cpPinJoint *()(void)
/* 193 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 194 */ _CFFI_OP(_CFFI_OP_FUNCTION, 195), // cpPivotJoint *()(cpPivotJoint *, cpBody *, cpBody *, cpVect, cpVect)
/* 195 */ _CFFI_OP(_CFFI_OP_POINTER, 1000), // cpPivotJoint *
/* 196 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 197 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 198 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 199 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 200 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 201 */ _CFFI_OP(_CFFI_OP_FUNCTION, 195), // cpPivotJoint *()(void)
/* 202 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 203 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // cpPolyShape *()(cpPolyShape *, cpBody *, cpBB, double)
/* 204 */ _CFFI_OP(_CFFI_OP_POINTER, 1002), // cpPolyShape *
/* 205 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 206 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 207 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 208 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 209 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // cpPolyShape *()(cpPolyShape *, cpBody *, double, double, double)
/* 210 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 211 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 212 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 213 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 214 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 215 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 216 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // cpPolyShape *()(cpPolyShape *, cpBody *, int, cpVect const *, cpTransform, double)
/* 217 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 218 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 219 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 220 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // cpVect const *
/* 221 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 222 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 223 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 224 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // cpPolyShape *()(cpPolyShape *, cpBody *, int, cpVect const *, double)
/* 225 */ _CFFI_OP(_CFFI_OP_NOOP, 204),
/* 226 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 227 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 228 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 229 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 230 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 231 */ _CFFI_OP(_CFFI_OP_FUNCTION, 204), // cpPolyShape *()(void)
/* 232 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 233 */ _CFFI_OP(_CFFI_OP_FUNCTION, 234), // cpPolyline *()(cpPolyline *, double)
/* 234 */ _CFFI_OP(_CFFI_OP_POINTER, 1004), // cpPolyline *
/* 235 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 236 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 237 */ _CFFI_OP(_CFFI_OP_FUNCTION, 242), // cpPolylineSet *()(cpPolyline *, double)
/* 238 */ _CFFI_OP(_CFFI_OP_NOOP, 234),
/* 239 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 240 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 241 */ _CFFI_OP(_CFFI_OP_FUNCTION, 242), // cpPolylineSet *()(cpPolylineSet *)
/* 242 */ _CFFI_OP(_CFFI_OP_POINTER, 1005), // cpPolylineSet *
/* 243 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 244 */ _CFFI_OP(_CFFI_OP_FUNCTION, 242), // cpPolylineSet *()(void)
/* 245 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 246 */ _CFFI_OP(_CFFI_OP_FUNCTION, 247), // cpRatchetJoint *()(cpRatchetJoint *, cpBody *, cpBody *, double, double)
/* 247 */ _CFFI_OP(_CFFI_OP_POINTER, 1006), // cpRatchetJoint *
/* 248 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 249 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 250 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 251 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 252 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 253 */ _CFFI_OP(_CFFI_OP_FUNCTION, 247), // cpRatchetJoint *()(void)
/* 254 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 255 */ _CFFI_OP(_CFFI_OP_FUNCTION, 256), // cpRotaryLimitJoint *()(cpRotaryLimitJoint *, cpBody *, cpBody *, double, double)
/* 256 */ _CFFI_OP(_CFFI_OP_POINTER, 1007), // cpRotaryLimitJoint *
/* 257 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 258 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 259 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 260 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 261 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 262 */ _CFFI_OP(_CFFI_OP_FUNCTION, 256), // cpRotaryLimitJoint *()(void)
/* 263 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 264 */ _CFFI_OP(_CFFI_OP_FUNCTION, 265), // cpSegmentShape *()(cpSegmentShape *, cpBody *, cpVect, cpVect, double)
/* 265 */ _CFFI_OP(_CFFI_OP_POINTER, 1009), // cpSegmentShape *
/* 266 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 267 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 268 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 269 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 271 */ _CFFI_OP(_CFFI_OP_FUNCTION, 265), // cpSegmentShape *()(void)
/* 272 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 273 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, cpBB, double)
/* 274 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 275 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 276 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 277 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 278 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, cpVect, cpVect, double)
/* 279 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 280 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 281 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 282 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 283 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 284 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, double, cpVect)
/* 285 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 286 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 287 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 288 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 289 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, double, double, double)
/* 290 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 291 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 292 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 293 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 294 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 295 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, int, cpVect const *, cpTransform, double)
/* 296 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 297 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 298 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 299 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 300 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 301 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 302 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpBody *, int, cpVect const *, double)
/* 303 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 304 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 305 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 306 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 307 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 308 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpSpace *, cpShape *)
/* 309 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 310 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 311 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 312 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpSpace *, cpVect, cpVect, double, cpShapeFilter, cpSegmentQueryInfo *)
/* 313 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 314 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 315 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 316 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 317 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 26), // cpShapeFilter
/* 318 */ _CFFI_OP(_CFFI_OP_POINTER, 1008), // cpSegmentQueryInfo *
/* 319 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 320 */ _CFFI_OP(_CFFI_OP_FUNCTION, 9), // cpShape *()(cpSpace *, cpVect, double, cpShapeFilter, cpPointQueryInfo *)
/* 321 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 322 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 323 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 324 */ _CFFI_OP(_CFFI_OP_NOOP, 317),
/* 325 */ _CFFI_OP(_CFFI_OP_POINTER, 1001), // cpPointQueryInfo *
/* 326 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 327 */ _CFFI_OP(_CFFI_OP_FUNCTION, 317), // cpShapeFilter()(cpShape const *)
/* 328 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 329 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 330 */ _CFFI_OP(_CFFI_OP_FUNCTION, 331), // cpSimpleMotor *()(cpSimpleMotor *, cpBody *, cpBody *, double)
/* 331 */ _CFFI_OP(_CFFI_OP_POINTER, 1011), // cpSimpleMotor *
/* 332 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 333 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 334 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 335 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 336 */ _CFFI_OP(_CFFI_OP_FUNCTION, 331), // cpSimpleMotor *()(void)
/* 337 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION, 339), // cpSlideJoint *()(cpSlideJoint *, cpBody *, cpBody *, cpVect, cpVect, double, double)
/* 339 */ _CFFI_OP(_CFFI_OP_POINTER, 1013), // cpSlideJoint *
/* 340 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 341 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 342 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 343 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 344 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 345 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 346 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 347 */ _CFFI_OP(_CFFI_OP_FUNCTION, 339), // cpSlideJoint *()(void)
/* 348 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 349 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // cpSpace *()(cpBody const *)
/* 350 */ _CFFI_OP(_CFFI_OP_POINTER, 987), // cpBody const *
/* 351 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 352 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // cpSpace *()(cpConstraint const *)
/* 353 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 354 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 355 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // cpSpace *()(cpShape const *)
/* 356 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 357 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 358 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // cpSpace *()(cpSpace *)
/* 359 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 360 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 361 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // cpSpace *()(void)
/* 362 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 363 */ _CFFI_OP(_CFFI_OP_FUNCTION, 942), // cpSpaceDebugColor()(cpShape *, void *)
/* 364 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 365 */ _CFFI_OP(_CFFI_OP_POINTER, 1031), // void *
/* 366 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 367 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpArbiter *)
/* 368 */ _CFFI_OP(_CFFI_OP_POINTER, 985), // cpArbiter *
/* 369 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 370 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpArbiter const *)
/* 371 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 372 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 373 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpArbiter const *, int)
/* 374 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 375 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 377 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpBB)
/* 378 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 380 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpBB, cpVect)
/* 381 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 382 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 383 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 384 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpBody const *)
/* 385 */ _CFFI_OP(_CFFI_OP_NOOP, 350),
/* 386 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 387 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpBody const *, cpVect)
/* 388 */ _CFFI_OP(_CFFI_OP_NOOP, 350),
/* 389 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 390 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 391 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpConstraint const *)
/* 392 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 393 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 394 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpShape *)
/* 395 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 396 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 397 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpShape const *)
/* 398 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 399 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 400 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpShape const *, int)
/* 401 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 402 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 403 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 404 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(cpSpace const *)
/* 405 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 406 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 407 */ _CFFI_OP(_CFFI_OP_FUNCTION, 6), // cpVect()(int, cpVect const *)
/* 408 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 409 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 410 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 411 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpArbiter const *)
/* 412 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 413 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 414 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpArbiter const *, int)
/* 415 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 416 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 417 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 418 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpBB)
/* 419 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 420 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 421 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpBB, cpBB)
/* 422 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 423 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 424 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 425 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpBB, cpVect, cpVect)
/* 426 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 427 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 428 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 429 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 430 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpBody const *)
/* 431 */ _CFFI_OP(_CFFI_OP_NOOP, 350),
/* 432 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 433 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpConstraint *)
/* 434 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 435 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 436 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpConstraint *, double)
/* 437 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 438 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 439 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 440 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpConstraint const *)
/* 441 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 442 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 443 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpShape *)
/* 444 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 445 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 446 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpShape const *)
/* 447 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 448 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 449 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpShape const *, cpVect, cpPointQueryInfo *)
/* 450 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 451 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 452 */ _CFFI_OP(_CFFI_OP_NOOP, 325),
/* 453 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 454 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpSpace const *)
/* 455 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 456 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 457 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpVect, cpVect, double)
/* 458 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 459 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 460 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 461 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 462 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(cpVect, void *)
/* 463 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 464 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 465 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 466 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, cpBB)
/* 467 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 468 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 469 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 470 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, cpVect, cpVect, double)
/* 471 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 472 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 473 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 474 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 475 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 476 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, double)
/* 477 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 478 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 479 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 480 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, double, double)
/* 481 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 482 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 483 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 484 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 485 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, double, double, cpVect)
/* 486 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 487 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 488 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 489 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 490 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 491 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(double, int, cpVect const *, cpVect, double)
/* 492 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 493 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 494 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 495 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 496 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 497 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 498 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // double()(int, cpVect const *, double)
/* 499 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 500 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 501 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 502 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 503 */ _CFFI_OP(_CFFI_OP_FUNCTION, 747), // double(*()(cpConstraint const *))(cpConstraint *, double)
/* 504 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 505 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 506 */ _CFFI_OP(_CFFI_OP_FUNCTION, 219), // int()(cpArbiter const *)
/* 507 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 508 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 509 */ _CFFI_OP(_CFFI_OP_FUNCTION, 219), // int()(cpShape const *)
/* 510 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 511 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 512 */ _CFFI_OP(_CFFI_OP_FUNCTION, 219), // int()(cpSpace const *)
/* 513 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 514 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 515 */ _CFFI_OP(_CFFI_OP_FUNCTION, 73), // uintptr_t()(cpShape const *)
/* 516 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 517 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 518 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpArbiter *)
/* 519 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 520 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpArbiter *, cpSpace *)
/* 522 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 523 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 524 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 525 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpArbiter *, cpSpace *, void *)
/* 526 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 527 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 528 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 529 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 530 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpArbiter const *)
/* 531 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 532 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 533 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpBB, cpBB)
/* 534 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 535 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 536 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 537 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpBB, cpVect)
/* 538 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 539 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 540 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 541 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpBB, cpVect, cpVect)
/* 542 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 543 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 544 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 545 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 546 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpBody const *)
/* 547 */ _CFFI_OP(_CFFI_OP_NOOP, 350),
/* 548 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 549 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpConstraint const *)
/* 550 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 551 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 552 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpPolyline *)
/* 553 */ _CFFI_OP(_CFFI_OP_NOOP, 234),
/* 554 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 555 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpShape const *)
/* 556 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 557 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 558 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpShape const *, cpVect, cpVect, double, cpSegmentQueryInfo *)
/* 559 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 560 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 561 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 562 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 563 */ _CFFI_OP(_CFFI_OP_NOOP, 318),
/* 564 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 565 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *)
/* 566 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 567 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 568 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *, cpBody *)
/* 569 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 570 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 571 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 572 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *, cpConstraint *)
/* 573 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 574 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 575 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 576 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *, cpShape *)
/* 577 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 578 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 579 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 580 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *, cpShape *, void(*)(cpShape *, cpContactPointSet *, void *), void *)
/* 581 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 582 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 583 */ _CFFI_OP(_CFFI_OP_POINTER, 779), // void(*)(cpShape *, cpContactPointSet *, void *)
/* 584 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 585 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 586 */ _CFFI_OP(_CFFI_OP_FUNCTION, 755), // unsigned char()(cpSpace *, void(*)(cpSpace *, void *, void *), void *, void *)
/* 587 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 588 */ _CFFI_OP(_CFFI_OP_POINTER, 914), // void(*)(cpSpace *, void *, void *)
/* 589 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 590 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 591 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 592 */ _CFFI_OP(_CFFI_OP_FUNCTION, 904), // unsigned int()(cpSpace const *)
/* 593 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 594 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 595 */ _CFFI_OP(_CFFI_OP_FUNCTION, 650), // unsigned long()(cpSpace *)
/* 596 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 597 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 598 */ _CFFI_OP(_CFFI_OP_FUNCTION, 365), // void *()(cpArbiter const *)
/* 599 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 600 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 601 */ _CFFI_OP(_CFFI_OP_FUNCTION, 365), // void *()(cpBody const *)
/* 602 */ _CFFI_OP(_CFFI_OP_NOOP, 350),
/* 603 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 604 */ _CFFI_OP(_CFFI_OP_FUNCTION, 365), // void *()(cpConstraint const *)
/* 605 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 606 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 607 */ _CFFI_OP(_CFFI_OP_FUNCTION, 365), // void *()(cpShape const *)
/* 608 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 609 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 610 */ _CFFI_OP(_CFFI_OP_FUNCTION, 365), // void *()(cpSpace const *)
/* 611 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 612 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 613 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, cpContactPointSet *)
/* 614 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 615 */ _CFFI_OP(_CFFI_OP_POINTER, 992), // cpContactPointSet *
/* 616 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 617 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, cpSpace *)
/* 618 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 619 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 620 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 621 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, cpSpace *, void *)
/* 622 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 623 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 624 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 625 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 626 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, cpVect)
/* 627 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 628 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 629 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 630 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, double)
/* 631 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 632 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 633 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 634 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter *, void *)
/* 635 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 636 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 637 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 638 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter const *, cpBody * *, cpBody * *)
/* 639 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 640 */ _CFFI_OP(_CFFI_OP_POINTER, 34), // cpBody * *
/* 641 */ _CFFI_OP(_CFFI_OP_NOOP, 640),
/* 642 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 643 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpArbiter const *, cpShape * *, cpShape * *)
/* 644 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 645 */ _CFFI_OP(_CFFI_OP_POINTER, 9), // cpShape * *
/* 646 */ _CFFI_OP(_CFFI_OP_NOOP, 645),
/* 647 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 648 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBB, unsigned long, unsigned long, double, void(*)(cpVect, cpVect, void *), void *, double(*)(cpVect, void *), void *)
/* 649 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 650 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 651 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 652 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 653 */ _CFFI_OP(_CFFI_OP_POINTER, 953), // void(*)(cpVect, cpVect, void *)
/* 654 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 655 */ _CFFI_OP(_CFFI_OP_POINTER, 462), // double(*)(cpVect, void *)
/* 656 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 657 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 658 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *)
/* 659 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 660 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 661 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpArbiter *, void *)
/* 662 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 663 */ _CFFI_OP(_CFFI_OP_NOOP, 368),
/* 664 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 665 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 666 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpBody *)
/* 667 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 668 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 669 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 670 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpBodyType)
/* 671 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 672 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // cpBodyType
/* 673 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 674 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpConstraint *, void *)
/* 675 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 676 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 677 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 678 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 679 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpShape *)
/* 680 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 681 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 682 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 683 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpShape *, void *)
/* 684 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 685 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 686 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 687 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 688 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpVect)
/* 689 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 690 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 691 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 692 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpVect, cpVect)
/* 693 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 694 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 695 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 696 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 697 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, cpVect, double, double)
/* 698 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 699 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 700 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 701 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 702 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 703 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, double)
/* 704 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 705 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 706 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 707 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void *)
/* 708 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 709 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 710 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 711 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void(*)(cpBody *, cpArbiter *, void *), void *)
/* 712 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 713 */ _CFFI_OP(_CFFI_OP_POINTER, 661), // void(*)(cpBody *, cpArbiter *, void *)
/* 714 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 715 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 716 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void(*)(cpBody *, cpConstraint *, void *), void *)
/* 717 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 718 */ _CFFI_OP(_CFFI_OP_POINTER, 674), // void(*)(cpBody *, cpConstraint *, void *)
/* 719 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 720 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 721 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void(*)(cpBody *, cpShape *, void *), void *)
/* 722 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 723 */ _CFFI_OP(_CFFI_OP_POINTER, 683), // void(*)(cpBody *, cpShape *, void *)
/* 724 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 725 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 726 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void(*)(cpBody *, cpVect, double, double))
/* 727 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 728 */ _CFFI_OP(_CFFI_OP_POINTER, 697), // void(*)(cpBody *, cpVect, double, double)
/* 729 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 730 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpBody *, void(*)(cpBody *, double))
/* 731 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 732 */ _CFFI_OP(_CFFI_OP_POINTER, 703), // void(*)(cpBody *, double)
/* 733 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 734 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *)
/* 735 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 736 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 737 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, cpSpace *)
/* 738 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 739 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 740 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 741 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, cpVect)
/* 742 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 743 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 744 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 745 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, double(*)(cpConstraint *, double))
/* 746 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 747 */ _CFFI_OP(_CFFI_OP_POINTER, 436), // double(*)(cpConstraint *, double)
/* 748 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 749 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, double)
/* 750 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 751 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 752 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 753 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, unsigned char)
/* 754 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 755 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 756 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 757 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, void *)
/* 758 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 759 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 760 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 761 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpConstraint *, void(*)(cpConstraint *, cpSpace *))
/* 762 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 763 */ _CFFI_OP(_CFFI_OP_POINTER, 737), // void(*)(cpConstraint *, cpSpace *)
/* 764 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 765 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpPolyline *)
/* 766 */ _CFFI_OP(_CFFI_OP_NOOP, 234),
/* 767 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 768 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpPolylineSet *, unsigned char)
/* 769 */ _CFFI_OP(_CFFI_OP_NOOP, 242),
/* 770 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 771 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 772 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *)
/* 773 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 774 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 775 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpBody *)
/* 776 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 777 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 778 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 779 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpContactPointSet *, void *)
/* 780 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 781 */ _CFFI_OP(_CFFI_OP_NOOP, 615),
/* 782 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 783 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 784 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpShapeFilter)
/* 785 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 786 */ _CFFI_OP(_CFFI_OP_NOOP, 317),
/* 787 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 788 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpVect)
/* 789 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 790 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 791 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 792 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpVect, cpVect)
/* 793 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 794 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 795 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 796 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 797 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpVect, cpVect, double, void *)
/* 798 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 799 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 800 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 801 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 802 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 803 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 804 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, cpVect, double, cpVect, void *)
/* 805 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 806 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 807 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 808 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 809 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 810 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 811 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, double)
/* 812 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 813 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 814 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 815 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, int, cpVect *)
/* 816 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 817 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 818 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // cpVect *
/* 819 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 820 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, int, cpVect *, cpTransform)
/* 821 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 822 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 823 */ _CFFI_OP(_CFFI_OP_NOOP, 818),
/* 824 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 825 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 826 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, uintptr_t)
/* 827 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 828 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 26),
/* 829 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 830 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, unsigned char)
/* 831 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 832 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 833 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 834 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpShape *, void *)
/* 835 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 836 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 837 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 838 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *)
/* 839 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 840 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 841 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpBB, cpShapeFilter, void(*)(cpShape *, void *), void *)
/* 842 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 843 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 844 */ _CFFI_OP(_CFFI_OP_NOOP, 317),
/* 845 */ _CFFI_OP(_CFFI_OP_POINTER, 834), // void(*)(cpShape *, void *)
/* 846 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 847 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 848 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpBody *)
/* 849 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 850 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 851 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 852 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpConstraint *)
/* 853 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 854 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 855 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 856 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpShape *)
/* 857 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 858 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 859 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 860 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpSpaceDebugDrawOptions *)
/* 861 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 862 */ _CFFI_OP(_CFFI_OP_POINTER, 1017), // cpSpaceDebugDrawOptions *
/* 863 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 864 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpVect)
/* 865 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 866 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 867 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 868 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpVect, cpVect, double, cpShapeFilter, void(*)(cpShape *, cpVect, cpVect, double, void *), void *)
/* 869 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 870 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 871 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 872 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 873 */ _CFFI_OP(_CFFI_OP_NOOP, 317),
/* 874 */ _CFFI_OP(_CFFI_OP_POINTER, 797), // void(*)(cpShape *, cpVect, cpVect, double, void *)
/* 875 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 876 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 877 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpVect, double, cpShapeFilter, void(*)(cpShape *, cpVect, double, cpVect, void *), void *)
/* 878 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 879 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 880 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 881 */ _CFFI_OP(_CFFI_OP_NOOP, 317),
/* 882 */ _CFFI_OP(_CFFI_OP_POINTER, 804), // void(*)(cpShape *, cpVect, double, cpVect, void *)
/* 883 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 884 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 885 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, cpVectArr *)
/* 886 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 887 */ _CFFI_OP(_CFFI_OP_POINTER, 1018), // cpVectArr *
/* 888 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 889 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, double)
/* 890 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 891 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 892 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 893 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, double, int)
/* 894 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 895 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 896 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 897 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 898 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, int)
/* 899 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 900 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 901 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 902 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, unsigned int)
/* 903 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 904 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 905 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 906 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, unsigned long)
/* 907 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 908 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 909 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 910 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, void *)
/* 911 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 912 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 913 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 914 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, void *, void *)
/* 915 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 916 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 917 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 918 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 919 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, void(*)(cpBody *, void *), void *)
/* 920 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 921 */ _CFFI_OP(_CFFI_OP_POINTER, 707), // void(*)(cpBody *, void *)
/* 922 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 923 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 924 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, void(*)(cpConstraint *, void *), void *)
/* 925 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 926 */ _CFFI_OP(_CFFI_OP_POINTER, 757), // void(*)(cpConstraint *, void *)
/* 927 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 928 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 929 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpSpace *, void(*)(cpShape *, void *), void *)
/* 930 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 931 */ _CFFI_OP(_CFFI_OP_NOOP, 845),
/* 932 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 933 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 934 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpVect, cpVect, cpPolylineSet *)
/* 935 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 936 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 937 */ _CFFI_OP(_CFFI_OP_NOOP, 242),
/* 938 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 939 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpVect, cpVect, cpSpaceDebugColor, void *)
/* 940 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 941 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 942 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 31), // cpSpaceDebugColor
/* 943 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 944 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 945 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpVect, cpVect, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 946 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 947 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 948 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 949 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 950 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 951 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 952 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 953 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpVect, cpVect, void *)
/* 954 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 955 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 956 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 957 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 958 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(cpVect, double, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 959 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 960 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 961 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 962 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 963 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 964 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 965 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 966 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(double, cpVect, cpSpaceDebugColor, void *)
/* 967 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 968 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 969 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 970 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 971 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 972 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1031), // void()(int, cpVect const *, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 973 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 974 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 975 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 976 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 977 */ _CFFI_OP(_CFFI_OP_NOOP, 942),
/* 978 */ _CFFI_OP(_CFFI_OP_NOOP, 365),
/* 979 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 980 */ _CFFI_OP(_CFFI_OP_FUNCTION, 763), // void(*()(cpConstraint const *))(cpConstraint *, cpSpace *)
/* 981 */ _CFFI_OP(_CFFI_OP_NOOP, 39),
/* 982 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 983 */ _CFFI_OP(_CFFI_OP_POINTER, 984), // char const *
/* 984 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 985 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // cpArbiter
/* 986 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // cpArray
/* 987 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // cpBody
/* 988 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // cpCircleShape
/* 989 */ _CFFI_OP(_CFFI_OP_POINTER, 990), // cpCollisionHandler *
/* 990 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // cpCollisionHandler
/* 991 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // cpConstraint
/* 992 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // cpContactPointSet
/* 993 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // cpDampedRotarySpring
/* 994 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // cpDampedSpring
/* 995 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // cpGearJoint
/* 996 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // cpGrooveJoint
/* 997 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // cpHashSet
/* 998 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // cpHastySpace
/* 999 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // cpPinJoint
/* 1000 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // cpPivotJoint
/* 1001 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // cpPointQueryInfo
/* 1002 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // cpPolyShape
/* 1003 */ _CFFI_OP(_CFFI_OP_POINTER, 234), // cpPolyline * *
/* 1004 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // cpPolyline
/* 1005 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // cpPolylineSet
/* 1006 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // cpRatchetJoint
/* 1007 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 22), // cpRotaryLimitJoint
/* 1008 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 23), // cpSegmentQueryInfo
/* 1009 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 24), // cpSegmentShape
/* 1010 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 25), // cpShape
/* 1011 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 27), // cpSimpleMotor
/* 1012 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 28), // cpSimpleMotorJoint
/* 1013 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 29), // cpSlideJoint
/* 1014 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 30), // cpSpace
/* 1015 */ _CFFI_OP(_CFFI_OP_POINTER, 363), // cpSpaceDebugColor(*)(cpShape *, void *)
/* 1016 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // cpSpaceDebugDrawFlags
/* 1017 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 32), // cpSpaceDebugDrawOptions
/* 1018 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 35), // cpVectArr
/* 1019 */ _CFFI_OP(_CFFI_OP_OPEN_ARRAY, 6), // cpVect[]
/* 1020 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13), // float
/* 1021 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // struct $1
/* 1022 */ _CFFI_OP(_CFFI_OP_ARRAY, 1021), // struct $1[2]
/* 1023 */ (_cffi_opcode_t)(2),
/* 1024 */ _CFFI_OP(_CFFI_OP_POINTER, 525), // unsigned char(*)(cpArbiter *, cpSpace *, void *)
/* 1025 */ _CFFI_OP(_CFFI_OP_POINTER, 621), // void(*)(cpArbiter *, cpSpace *, void *)
/* 1026 */ _CFFI_OP(_CFFI_OP_POINTER, 939), // void(*)(cpVect, cpVect, cpSpaceDebugColor, void *)
/* 1027 */ _CFFI_OP(_CFFI_OP_POINTER, 945), // void(*)(cpVect, cpVect, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 1028 */ _CFFI_OP(_CFFI_OP_POINTER, 958), // void(*)(cpVect, double, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 1029 */ _CFFI_OP(_CFFI_OP_POINTER, 966), // void(*)(double, cpVect, cpSpaceDebugColor, void *)
/* 1030 */ _CFFI_OP(_CFFI_OP_POINTER, 972), // void(*)(int, cpVect const *, double, cpSpaceDebugColor, cpSpaceDebugColor, void *)
/* 1031 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_CP_BODY_TYPE_DYNAMIC(unsigned long long *o)
{
  int n = (CP_BODY_TYPE_DYNAMIC) <= 0;
  *o = (unsigned long long)((CP_BODY_TYPE_DYNAMIC) | 0);  /* check that CP_BODY_TYPE_DYNAMIC is an integer */
  return n;
}

static int _cffi_const_CP_BODY_TYPE_KINEMATIC(unsigned long long *o)
{
  int n = (CP_BODY_TYPE_KINEMATIC) <= 0;
  *o = (unsigned long long)((CP_BODY_TYPE_KINEMATIC) | 0);  /* check that CP_BODY_TYPE_KINEMATIC is an integer */
  return n;
}

static int _cffi_const_CP_BODY_TYPE_STATIC(unsigned long long *o)
{
  int n = (CP_BODY_TYPE_STATIC) <= 0;
  *o = (unsigned long long)((CP_BODY_TYPE_STATIC) | 0);  /* check that CP_BODY_TYPE_STATIC is an integer */
  return n;
}

static int _cffi_const_CP_SPACE_DEBUG_DRAW_SHAPES(unsigned long long *o)
{
  int n = (CP_SPACE_DEBUG_DRAW_SHAPES) <= 0;
  *o = (unsigned long long)((CP_SPACE_DEBUG_DRAW_SHAPES) | 0);  /* check that CP_SPACE_DEBUG_DRAW_SHAPES is an integer */
  return n;
}

static int _cffi_const_CP_SPACE_DEBUG_DRAW_CONSTRAINTS(unsigned long long *o)
{
  int n = (CP_SPACE_DEBUG_DRAW_CONSTRAINTS) <= 0;
  *o = (unsigned long long)((CP_SPACE_DEBUG_DRAW_CONSTRAINTS) | 0);  /* check that CP_SPACE_DEBUG_DRAW_CONSTRAINTS is an integer */
  return n;
}

static int _cffi_const_CP_SPACE_DEBUG_DRAW_COLLISION_POINTS(unsigned long long *o)
{
  int n = (CP_SPACE_DEBUG_DRAW_COLLISION_POINTS) <= 0;
  *o = (unsigned long long)((CP_SPACE_DEBUG_DRAW_COLLISION_POINTS) | 0);  /* check that CP_SPACE_DEBUG_DRAW_COLLISION_POINTS is an integer */
  return n;
}

static unsigned char _cffi_d_cpArbiterCallWildcardBeginA(cpArbiter * x0, cpSpace * x1)
{
  return cpArbiterCallWildcardBeginA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardBeginA(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardBeginA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterCallWildcardBeginA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterCallWildcardBeginA _cffi_d_cpArbiterCallWildcardBeginA
#endif

static unsigned char _cffi_d_cpArbiterCallWildcardBeginB(cpArbiter * x0, cpSpace * x1)
{
  return cpArbiterCallWildcardBeginB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardBeginB(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardBeginB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterCallWildcardBeginB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterCallWildcardBeginB _cffi_d_cpArbiterCallWildcardBeginB
#endif

static void _cffi_d_cpArbiterCallWildcardPostSolveA(cpArbiter * x0, cpSpace * x1)
{
  cpArbiterCallWildcardPostSolveA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardPostSolveA(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardPostSolveA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterCallWildcardPostSolveA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterCallWildcardPostSolveA _cffi_d_cpArbiterCallWildcardPostSolveA
#endif

static void _cffi_d_cpArbiterCallWildcardPostSolveB(cpArbiter * x0, cpSpace * x1)
{
  cpArbiterCallWildcardPostSolveB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardPostSolveB(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardPostSolveB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterCallWildcardPostSolveB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterCallWildcardPostSolveB _cffi_d_cpArbiterCallWildcardPostSolveB
#endif

static unsigned char _cffi_d_cpArbiterCallWildcardPreSolveA(cpArbiter * x0, cpSpace * x1)
{
  return cpArbiterCallWildcardPreSolveA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardPreSolveA(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardPreSolveA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterCallWildcardPreSolveA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterCallWildcardPreSolveA _cffi_d_cpArbiterCallWildcardPreSolveA
#endif

static unsigned char _cffi_d_cpArbiterCallWildcardPreSolveB(cpArbiter * x0, cpSpace * x1)
{
  return cpArbiterCallWildcardPreSolveB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardPreSolveB(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardPreSolveB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterCallWildcardPreSolveB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterCallWildcardPreSolveB _cffi_d_cpArbiterCallWildcardPreSolveB
#endif

static void _cffi_d_cpArbiterCallWildcardSeparateA(cpArbiter * x0, cpSpace * x1)
{
  cpArbiterCallWildcardSeparateA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardSeparateA(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardSeparateA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterCallWildcardSeparateA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterCallWildcardSeparateA _cffi_d_cpArbiterCallWildcardSeparateA
#endif

static void _cffi_d_cpArbiterCallWildcardSeparateB(cpArbiter * x0, cpSpace * x1)
{
  cpArbiterCallWildcardSeparateB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterCallWildcardSeparateB(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpSpace * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterCallWildcardSeparateB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterCallWildcardSeparateB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterCallWildcardSeparateB _cffi_d_cpArbiterCallWildcardSeparateB
#endif

static void _cffi_d_cpArbiterGetBodies(cpArbiter const * x0, cpBody * * x1, cpBody * * x2)
{
  cpArbiterGetBodies(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetBodies(PyObject *self, PyObject *args)
{
  cpArbiter const * x0;
  cpBody * * x1;
  cpBody * * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpArbiterGetBodies", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(640), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(640), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(640), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(640), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterGetBodies(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterGetBodies _cffi_d_cpArbiterGetBodies
#endif

static cpContactPointSet _cffi_d_cpArbiterGetContactPointSet(cpArbiter const * x0)
{
  return cpArbiterGetContactPointSet(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetContactPointSet(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpContactPointSet result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetContactPointSet(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(992));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterGetContactPointSet(cpContactPointSet *result, cpArbiter const * x0)
{
  { *result = cpArbiterGetContactPointSet(x0); }
}
#endif

static int _cffi_d_cpArbiterGetCount(cpArbiter const * x0)
{
  return cpArbiterGetCount(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetCount(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetCount(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterGetCount _cffi_d_cpArbiterGetCount
#endif

static double _cffi_d_cpArbiterGetDepth(cpArbiter const * x0, int x1)
{
  return cpArbiterGetDepth(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetDepth(PyObject *self, PyObject *args)
{
  cpArbiter const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterGetDepth", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetDepth(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterGetDepth _cffi_d_cpArbiterGetDepth
#endif

static double _cffi_d_cpArbiterGetFriction(cpArbiter const * x0)
{
  return cpArbiterGetFriction(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetFriction(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetFriction(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterGetFriction _cffi_d_cpArbiterGetFriction
#endif

static cpVect _cffi_d_cpArbiterGetNormal(cpArbiter const * x0)
{
  return cpArbiterGetNormal(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetNormal(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetNormal(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterGetNormal(cpVect *result, cpArbiter const * x0)
{
  { *result = cpArbiterGetNormal(x0); }
}
#endif

static cpVect _cffi_d_cpArbiterGetPointA(cpArbiter const * x0, int x1)
{
  return cpArbiterGetPointA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetPointA(PyObject *self, PyObject *args)
{
  cpArbiter const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterGetPointA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetPointA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterGetPointA(cpVect *result, cpArbiter const * x0, int x1)
{
  { *result = cpArbiterGetPointA(x0, x1); }
}
#endif

static cpVect _cffi_d_cpArbiterGetPointB(cpArbiter const * x0, int x1)
{
  return cpArbiterGetPointB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetPointB(PyObject *self, PyObject *args)
{
  cpArbiter const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterGetPointB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetPointB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterGetPointB(cpVect *result, cpArbiter const * x0, int x1)
{
  { *result = cpArbiterGetPointB(x0, x1); }
}
#endif

static double _cffi_d_cpArbiterGetRestitution(cpArbiter const * x0)
{
  return cpArbiterGetRestitution(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetRestitution(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetRestitution(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterGetRestitution _cffi_d_cpArbiterGetRestitution
#endif

static void _cffi_d_cpArbiterGetShapes(cpArbiter const * x0, cpShape * * x1, cpShape * * x2)
{
  cpArbiterGetShapes(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetShapes(PyObject *self, PyObject *args)
{
  cpArbiter const * x0;
  cpShape * * x1;
  cpShape * * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpArbiterGetShapes", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(645), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(645), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(645), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpShape * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(645), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterGetShapes(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterGetShapes _cffi_d_cpArbiterGetShapes
#endif

static cpVect _cffi_d_cpArbiterGetSurfaceVelocity(cpArbiter * x0)
{
  return cpArbiterGetSurfaceVelocity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetSurfaceVelocity(PyObject *self, PyObject *arg0)
{
  cpArbiter * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetSurfaceVelocity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterGetSurfaceVelocity(cpVect *result, cpArbiter * x0)
{
  { *result = cpArbiterGetSurfaceVelocity(x0); }
}
#endif

static void * _cffi_d_cpArbiterGetUserData(cpArbiter const * x0)
{
  return cpArbiterGetUserData(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterGetUserData(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterGetUserData(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(365));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterGetUserData _cffi_d_cpArbiterGetUserData
#endif

static unsigned char _cffi_d_cpArbiterIgnore(cpArbiter * x0)
{
  return cpArbiterIgnore(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterIgnore(PyObject *self, PyObject *arg0)
{
  cpArbiter * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterIgnore(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterIgnore _cffi_d_cpArbiterIgnore
#endif

static unsigned char _cffi_d_cpArbiterIsFirstContact(cpArbiter const * x0)
{
  return cpArbiterIsFirstContact(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterIsFirstContact(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterIsFirstContact(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterIsFirstContact _cffi_d_cpArbiterIsFirstContact
#endif

static unsigned char _cffi_d_cpArbiterIsRemoval(cpArbiter const * x0)
{
  return cpArbiterIsRemoval(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterIsRemoval(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterIsRemoval(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterIsRemoval _cffi_d_cpArbiterIsRemoval
#endif

static void _cffi_d_cpArbiterSetContactPointSet(cpArbiter * x0, cpContactPointSet * x1)
{
  cpArbiterSetContactPointSet(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterSetContactPointSet(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpContactPointSet * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterSetContactPointSet", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(615), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpContactPointSet *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(615), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterSetContactPointSet(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterSetContactPointSet _cffi_d_cpArbiterSetContactPointSet
#endif

static void _cffi_d_cpArbiterSetFriction(cpArbiter * x0, double x1)
{
  cpArbiterSetFriction(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterSetFriction(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterSetFriction", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterSetFriction(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterSetFriction _cffi_d_cpArbiterSetFriction
#endif

static void _cffi_d_cpArbiterSetRestitution(cpArbiter * x0, double x1)
{
  cpArbiterSetRestitution(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterSetRestitution(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterSetRestitution", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterSetRestitution(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterSetRestitution _cffi_d_cpArbiterSetRestitution
#endif

static void _cffi_d_cpArbiterSetSurfaceVelocity(cpArbiter * x0, cpVect x1)
{
  cpArbiterSetSurfaceVelocity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterSetSurfaceVelocity(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterSetSurfaceVelocity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterSetSurfaceVelocity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpArbiterSetSurfaceVelocity(cpArbiter * x0, cpVect *x1)
{
  { cpArbiterSetSurfaceVelocity(x0, *x1); }
}
#endif

static void _cffi_d_cpArbiterSetUserData(cpArbiter * x0, void * x1)
{
  cpArbiterSetUserData(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterSetUserData(PyObject *self, PyObject *args)
{
  cpArbiter * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpArbiterSetUserData", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(368), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpArbiterSetUserData(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpArbiterSetUserData _cffi_d_cpArbiterSetUserData
#endif

static cpVect _cffi_d_cpArbiterTotalImpulse(cpArbiter const * x0)
{
  return cpArbiterTotalImpulse(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterTotalImpulse(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterTotalImpulse(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpArbiterTotalImpulse(cpVect *result, cpArbiter const * x0)
{
  { *result = cpArbiterTotalImpulse(x0); }
}
#endif

static double _cffi_d_cpArbiterTotalKE(cpArbiter const * x0)
{
  return cpArbiterTotalKE(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpArbiterTotalKE(PyObject *self, PyObject *arg0)
{
  cpArbiter const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpArbiter const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpArbiterTotalKE(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpArbiterTotalKE _cffi_d_cpArbiterTotalKE
#endif

static double _cffi_d_cpAreaForCircle(double x0, double x1)
{
  return cpAreaForCircle(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpAreaForCircle(PyObject *self, PyObject *args)
{
  double x0;
  double x1;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpAreaForCircle", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpAreaForCircle(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
#  define _cffi_f_cpAreaForCircle _cffi_d_cpAreaForCircle
#endif

static double _cffi_d_cpAreaForPoly(int x0, cpVect const * x1, double x2)
{
  return cpAreaForPoly(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpAreaForPoly(PyObject *self, PyObject *args)
{
  int x0;
  cpVect const * x1;
  double x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpAreaForPoly", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpAreaForPoly(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpAreaForPoly _cffi_d_cpAreaForPoly
#endif

static double _cffi_d_cpAreaForSegment(cpVect x0, cpVect x1, double x2)
{
  return cpAreaForSegment(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpAreaForSegment(PyObject *self, PyObject *args)
{
  cpVect x0;
  cpVect x1;
  double x2;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpAreaForSegment", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(6), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpAreaForSegment(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpAreaForSegment(cpVect *x0, cpVect *x1, double x2)
{
  double result;
  { result = cpAreaForSegment(*x0, *x1, x2); }
  return result;
}
#endif

static double _cffi_d_cpBBArea(cpBB x0)
{
  return cpBBArea(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBArea(PyObject *self, PyObject *arg0)
{
  cpBB x0;
  double result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBArea(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpBBArea(cpBB *x0)
{
  double result;
  { result = cpBBArea(*x0); }
  return result;
}
#endif

static cpVect _cffi_d_cpBBCenter(cpBB x0)
{
  return cpBBCenter(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBCenter(PyObject *self, PyObject *arg0)
{
  cpBB x0;
  cpVect result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBCenter(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  return pyresult;
}
#else
static void _cffi_f_cpBBCenter(cpVect *result, cpBB *x0)
{
  { *result = cpBBCenter(*x0); }
}
#endif

static cpVect _cffi_d_cpBBClampVect(cpBB x0, cpVect x1)
{
  return cpBBClampVect(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBClampVect(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBClampVect", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBClampVect(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  return pyresult;
}
#else
static void _cffi_f_cpBBClampVect(cpVect *result, cpBB *x0, cpVect *x1)
{
  { *result = cpBBClampVect(*x0, *x1); }
}
#endif

static unsigned char _cffi_d_cpBBContainsBB(cpBB x0, cpBB x1)
{
  return cpBBContainsBB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBContainsBB(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpBB x1;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBContainsBB", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBContainsBB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  return pyresult;
}
#else
static unsigned char _cffi_f_cpBBContainsBB(cpBB *x0, cpBB *x1)
{
  unsigned char result;
  { result = cpBBContainsBB(*x0, *x1); }
  return result;
}
#endif

static unsigned char _cffi_d_cpBBContainsVect(cpBB x0, cpVect x1)
{
  return cpBBContainsVect(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBContainsVect(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBContainsVect", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBContainsVect(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  return pyresult;
}
#else
static unsigned char _cffi_f_cpBBContainsVect(cpBB *x0, cpVect *x1)
{
  unsigned char result;
  { result = cpBBContainsVect(*x0, *x1); }
  return result;
}
#endif

static cpBB _cffi_d_cpBBExpand(cpBB x0, cpVect x1)
{
  return cpBBExpand(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBExpand(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBExpand", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBExpand(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBExpand(cpBB *result, cpBB *x0, cpVect *x1)
{
  { *result = cpBBExpand(*x0, *x1); }
}
#endif

static unsigned char _cffi_d_cpBBIntersects(cpBB x0, cpBB x1)
{
  return cpBBIntersects(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBIntersects(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpBB x1;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBIntersects", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBIntersects(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  return pyresult;
}
#else
static unsigned char _cffi_f_cpBBIntersects(cpBB *x0, cpBB *x1)
{
  unsigned char result;
  { result = cpBBIntersects(*x0, *x1); }
  return result;
}
#endif

static unsigned char _cffi_d_cpBBIntersectsSegment(cpBB x0, cpVect x1, cpVect x2)
{
  return cpBBIntersectsSegment(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBIntersectsSegment(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpVect x2;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBBIntersectsSegment", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBIntersectsSegment(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  return pyresult;
}
#else
static unsigned char _cffi_f_cpBBIntersectsSegment(cpBB *x0, cpVect *x1, cpVect *x2)
{
  unsigned char result;
  { result = cpBBIntersectsSegment(*x0, *x1, *x2); }
  return result;
}
#endif

static cpBB _cffi_d_cpBBMerge(cpBB x0, cpBB x1)
{
  return cpBBMerge(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBMerge(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpBB x1;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBMerge", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBMerge(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBMerge(cpBB *result, cpBB *x0, cpBB *x1)
{
  { *result = cpBBMerge(*x0, *x1); }
}
#endif

static double _cffi_d_cpBBMergedArea(cpBB x0, cpBB x1)
{
  return cpBBMergedArea(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBMergedArea(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpBB x1;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBMergedArea", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBMergedArea(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpBBMergedArea(cpBB *x0, cpBB *x1)
{
  double result;
  { result = cpBBMergedArea(*x0, *x1); }
  return result;
}
#endif

static cpBB _cffi_d_cpBBNew(double x0, double x1, double x2, double x3)
{
  return cpBBNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBNew(PyObject *self, PyObject *args)
{
  double x0;
  double x1;
  double x2;
  double x3;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpBBNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBNew(cpBB *result, double x0, double x1, double x2, double x3)
{
  { *result = cpBBNew(x0, x1, x2, x3); }
}
#endif

static cpBB _cffi_d_cpBBNewForCircle(cpVect x0, double x1)
{
  return cpBBNewForCircle(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBNewForCircle(PyObject *self, PyObject *args)
{
  cpVect x0;
  double x1;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBNewForCircle", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(6), arg0) < 0)
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBNewForCircle(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBNewForCircle(cpBB *result, cpVect *x0, double x1)
{
  { *result = cpBBNewForCircle(*x0, x1); }
}
#endif

static cpBB _cffi_d_cpBBNewForExtents(cpVect x0, double x1, double x2)
{
  return cpBBNewForExtents(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBNewForExtents(PyObject *self, PyObject *args)
{
  cpVect x0;
  double x1;
  double x2;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBBNewForExtents", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(6), arg0) < 0)
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBNewForExtents(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBNewForExtents(cpBB *result, cpVect *x0, double x1, double x2)
{
  { *result = cpBBNewForExtents(*x0, x1, x2); }
}
#endif

static cpBB _cffi_d_cpBBOffset(cpBB x0, cpVect x1)
{
  return cpBBOffset(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBOffset(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBOffset", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBOffset(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  return pyresult;
}
#else
static void _cffi_f_cpBBOffset(cpBB *result, cpBB *x0, cpVect *x1)
{
  { *result = cpBBOffset(*x0, *x1); }
}
#endif

static double _cffi_d_cpBBSegmentQuery(cpBB x0, cpVect x1, cpVect x2)
{
  return cpBBSegmentQuery(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBSegmentQuery(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpVect x2;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBBSegmentQuery", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBSegmentQuery(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpBBSegmentQuery(cpBB *x0, cpVect *x1, cpVect *x2)
{
  double result;
  { result = cpBBSegmentQuery(*x0, *x1, *x2); }
  return result;
}
#endif

static cpVect _cffi_d_cpBBWrapVect(cpBB x0, cpVect x1)
{
  return cpBBWrapVect(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBBWrapVect(PyObject *self, PyObject *args)
{
  cpBB x0;
  cpVect x1;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBBWrapVect", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBBWrapVect(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  return pyresult;
}
#else
static void _cffi_f_cpBBWrapVect(cpVect *result, cpBB *x0, cpVect *x1)
{
  { *result = cpBBWrapVect(*x0, *x1); }
}
#endif

static void _cffi_d_cpBodyActivate(cpBody * x0)
{
  cpBodyActivate(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyActivate(PyObject *self, PyObject *arg0)
{
  cpBody * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyActivate(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyActivate _cffi_d_cpBodyActivate
#endif

static void _cffi_d_cpBodyActivateStatic(cpBody * x0, cpShape * x1)
{
  cpBodyActivateStatic(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyActivateStatic(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpShape * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyActivateStatic", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyActivateStatic(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyActivateStatic _cffi_d_cpBodyActivateStatic
#endif

static cpBody * _cffi_d_cpBodyAlloc(void)
{
  return cpBodyAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyAlloc(PyObject *self, PyObject *noarg)
{
  cpBody * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  return pyresult;
}
#else
#  define _cffi_f_cpBodyAlloc _cffi_d_cpBodyAlloc
#endif

static void _cffi_d_cpBodyApplyForceAtLocalPoint(cpBody * x0, cpVect x1, cpVect x2)
{
  cpBodyApplyForceAtLocalPoint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyApplyForceAtLocalPoint(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyApplyForceAtLocalPoint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyApplyForceAtLocalPoint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodyApplyForceAtLocalPoint(cpBody * x0, cpVect *x1, cpVect *x2)
{
  { cpBodyApplyForceAtLocalPoint(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpBodyApplyForceAtWorldPoint(cpBody * x0, cpVect x1, cpVect x2)
{
  cpBodyApplyForceAtWorldPoint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyApplyForceAtWorldPoint(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyApplyForceAtWorldPoint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyApplyForceAtWorldPoint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodyApplyForceAtWorldPoint(cpBody * x0, cpVect *x1, cpVect *x2)
{
  { cpBodyApplyForceAtWorldPoint(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpBodyApplyImpulseAtLocalPoint(cpBody * x0, cpVect x1, cpVect x2)
{
  cpBodyApplyImpulseAtLocalPoint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyApplyImpulseAtLocalPoint(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyApplyImpulseAtLocalPoint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyApplyImpulseAtLocalPoint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodyApplyImpulseAtLocalPoint(cpBody * x0, cpVect *x1, cpVect *x2)
{
  { cpBodyApplyImpulseAtLocalPoint(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpBodyApplyImpulseAtWorldPoint(cpBody * x0, cpVect x1, cpVect x2)
{
  cpBodyApplyImpulseAtWorldPoint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyApplyImpulseAtWorldPoint(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyApplyImpulseAtWorldPoint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyApplyImpulseAtWorldPoint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodyApplyImpulseAtWorldPoint(cpBody * x0, cpVect *x1, cpVect *x2)
{
  { cpBodyApplyImpulseAtWorldPoint(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpBodyDestroy(cpBody * x0)
{
  cpBodyDestroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyDestroy(PyObject *self, PyObject *arg0)
{
  cpBody * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyDestroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyDestroy _cffi_d_cpBodyDestroy
#endif

static void _cffi_d_cpBodyEachArbiter(cpBody * x0, void(* x1)(cpBody *, cpArbiter *, void *), void * x2)
{
  cpBodyEachArbiter(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyEachArbiter(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void(* x1)(cpBody *, cpArbiter *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyEachArbiter", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, cpArbiter *, void *))_cffi_to_c_pointer(arg1, _cffi_type(713));
  if (x1 == (void(*)(cpBody *, cpArbiter *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyEachArbiter(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyEachArbiter _cffi_d_cpBodyEachArbiter
#endif

static void _cffi_d_cpBodyEachConstraint(cpBody * x0, void(* x1)(cpBody *, cpConstraint *, void *), void * x2)
{
  cpBodyEachConstraint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyEachConstraint(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void(* x1)(cpBody *, cpConstraint *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyEachConstraint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, cpConstraint *, void *))_cffi_to_c_pointer(arg1, _cffi_type(718));
  if (x1 == (void(*)(cpBody *, cpConstraint *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyEachConstraint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyEachConstraint _cffi_d_cpBodyEachConstraint
#endif

static void _cffi_d_cpBodyEachShape(cpBody * x0, void(* x1)(cpBody *, cpShape *, void *), void * x2)
{
  cpBodyEachShape(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyEachShape(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void(* x1)(cpBody *, cpShape *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyEachShape", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, cpShape *, void *))_cffi_to_c_pointer(arg1, _cffi_type(723));
  if (x1 == (void(*)(cpBody *, cpShape *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyEachShape(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyEachShape _cffi_d_cpBodyEachShape
#endif

static void _cffi_d_cpBodyFree(cpBody * x0)
{
  cpBodyFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyFree(PyObject *self, PyObject *arg0)
{
  cpBody * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyFree _cffi_d_cpBodyFree
#endif

static double _cffi_d_cpBodyGetAngle(cpBody const * x0)
{
  return cpBodyGetAngle(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetAngle(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetAngle(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetAngle _cffi_d_cpBodyGetAngle
#endif

static double _cffi_d_cpBodyGetAngularVelocity(cpBody const * x0)
{
  return cpBodyGetAngularVelocity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetAngularVelocity(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetAngularVelocity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetAngularVelocity _cffi_d_cpBodyGetAngularVelocity
#endif

static cpVect _cffi_d_cpBodyGetCenterOfGravity(cpBody const * x0)
{
  return cpBodyGetCenterOfGravity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetCenterOfGravity(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetCenterOfGravity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetCenterOfGravity(cpVect *result, cpBody const * x0)
{
  { *result = cpBodyGetCenterOfGravity(x0); }
}
#endif

static cpVect _cffi_d_cpBodyGetForce(cpBody const * x0)
{
  return cpBodyGetForce(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetForce(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetForce(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetForce(cpVect *result, cpBody const * x0)
{
  { *result = cpBodyGetForce(x0); }
}
#endif

static double _cffi_d_cpBodyGetMass(cpBody const * x0)
{
  return cpBodyGetMass(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetMass(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetMass(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetMass _cffi_d_cpBodyGetMass
#endif

static double _cffi_d_cpBodyGetMoment(cpBody const * x0)
{
  return cpBodyGetMoment(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetMoment(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetMoment(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetMoment _cffi_d_cpBodyGetMoment
#endif

static cpVect _cffi_d_cpBodyGetPosition(cpBody const * x0)
{
  return cpBodyGetPosition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetPosition(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetPosition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetPosition(cpVect *result, cpBody const * x0)
{
  { *result = cpBodyGetPosition(x0); }
}
#endif

static cpVect _cffi_d_cpBodyGetRotation(cpBody const * x0)
{
  return cpBodyGetRotation(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetRotation(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetRotation(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetRotation(cpVect *result, cpBody const * x0)
{
  { *result = cpBodyGetRotation(x0); }
}
#endif

static cpSpace * _cffi_d_cpBodyGetSpace(cpBody const * x0)
{
  return cpBodyGetSpace(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetSpace(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSpace * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetSpace(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetSpace _cffi_d_cpBodyGetSpace
#endif

static double _cffi_d_cpBodyGetTorque(cpBody const * x0)
{
  return cpBodyGetTorque(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetTorque(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetTorque(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetTorque _cffi_d_cpBodyGetTorque
#endif

static cpBodyType _cffi_d_cpBodyGetType(cpBody * x0)
{
  return cpBodyGetType(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetType(PyObject *self, PyObject *arg0)
{
  cpBody * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBodyType result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetType(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(672));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetType _cffi_d_cpBodyGetType
#endif

static void * _cffi_d_cpBodyGetUserData(cpBody const * x0)
{
  return cpBodyGetUserData(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetUserData(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetUserData(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(365));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyGetUserData _cffi_d_cpBodyGetUserData
#endif

static cpVect _cffi_d_cpBodyGetVelocity(cpBody const * x0)
{
  return cpBodyGetVelocity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetVelocity(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetVelocity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetVelocity(cpVect *result, cpBody const * x0)
{
  { *result = cpBodyGetVelocity(x0); }
}
#endif

static cpVect _cffi_d_cpBodyGetVelocityAtLocalPoint(cpBody const * x0, cpVect x1)
{
  return cpBodyGetVelocityAtLocalPoint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetVelocityAtLocalPoint(PyObject *self, PyObject *args)
{
  cpBody const * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyGetVelocityAtLocalPoint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetVelocityAtLocalPoint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetVelocityAtLocalPoint(cpVect *result, cpBody const * x0, cpVect *x1)
{
  { *result = cpBodyGetVelocityAtLocalPoint(x0, *x1); }
}
#endif

static cpVect _cffi_d_cpBodyGetVelocityAtWorldPoint(cpBody const * x0, cpVect x1)
{
  return cpBodyGetVelocityAtWorldPoint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyGetVelocityAtWorldPoint(PyObject *self, PyObject *args)
{
  cpBody const * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyGetVelocityAtWorldPoint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyGetVelocityAtWorldPoint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyGetVelocityAtWorldPoint(cpVect *result, cpBody const * x0, cpVect *x1)
{
  { *result = cpBodyGetVelocityAtWorldPoint(x0, *x1); }
}
#endif

static cpBody * _cffi_d_cpBodyInit(cpBody * x0, double x1, double x2)
{
  return cpBodyInit(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyInit(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  double x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBodyInit", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyInit(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyInit _cffi_d_cpBodyInit
#endif

static unsigned char _cffi_d_cpBodyIsSleeping(cpBody const * x0)
{
  return cpBodyIsSleeping(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyIsSleeping(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyIsSleeping(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyIsSleeping _cffi_d_cpBodyIsSleeping
#endif

static double _cffi_d_cpBodyKineticEnergy(cpBody const * x0)
{
  return cpBodyKineticEnergy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyKineticEnergy(PyObject *self, PyObject *arg0)
{
  cpBody const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyKineticEnergy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBodyKineticEnergy _cffi_d_cpBodyKineticEnergy
#endif

static cpVect _cffi_d_cpBodyLocalToWorld(cpBody const * x0, cpVect x1)
{
  return cpBodyLocalToWorld(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyLocalToWorld(PyObject *self, PyObject *args)
{
  cpBody const * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyLocalToWorld", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyLocalToWorld(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyLocalToWorld(cpVect *result, cpBody const * x0, cpVect *x1)
{
  { *result = cpBodyLocalToWorld(x0, *x1); }
}
#endif

static cpBody * _cffi_d_cpBodyNew(double x0, double x1)
{
  return cpBodyNew(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyNew(PyObject *self, PyObject *args)
{
  double x0;
  double x1;
  cpBody * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyNew", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyNew(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  return pyresult;
}
#else
#  define _cffi_f_cpBodyNew _cffi_d_cpBodyNew
#endif

static cpBody * _cffi_d_cpBodyNewKinematic(void)
{
  return cpBodyNewKinematic();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyNewKinematic(PyObject *self, PyObject *noarg)
{
  cpBody * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyNewKinematic(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  return pyresult;
}
#else
#  define _cffi_f_cpBodyNewKinematic _cffi_d_cpBodyNewKinematic
#endif

static cpBody * _cffi_d_cpBodyNewStatic(void)
{
  return cpBodyNewStatic();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyNewStatic(PyObject *self, PyObject *noarg)
{
  cpBody * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyNewStatic(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  return pyresult;
}
#else
#  define _cffi_f_cpBodyNewStatic _cffi_d_cpBodyNewStatic
#endif

static void _cffi_d_cpBodySetAngle(cpBody * x0, double x1)
{
  cpBodySetAngle(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetAngle(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetAngle", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetAngle(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetAngle _cffi_d_cpBodySetAngle
#endif

static void _cffi_d_cpBodySetAngularVelocity(cpBody * x0, double x1)
{
  cpBodySetAngularVelocity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetAngularVelocity(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetAngularVelocity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetAngularVelocity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetAngularVelocity _cffi_d_cpBodySetAngularVelocity
#endif

static void _cffi_d_cpBodySetCenterOfGravity(cpBody * x0, cpVect x1)
{
  cpBodySetCenterOfGravity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetCenterOfGravity(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetCenterOfGravity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetCenterOfGravity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodySetCenterOfGravity(cpBody * x0, cpVect *x1)
{
  { cpBodySetCenterOfGravity(x0, *x1); }
}
#endif

static void _cffi_d_cpBodySetForce(cpBody * x0, cpVect x1)
{
  cpBodySetForce(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetForce(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetForce", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetForce(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodySetForce(cpBody * x0, cpVect *x1)
{
  { cpBodySetForce(x0, *x1); }
}
#endif

static void _cffi_d_cpBodySetMass(cpBody * x0, double x1)
{
  cpBodySetMass(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetMass(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetMass", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetMass(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetMass _cffi_d_cpBodySetMass
#endif

static void _cffi_d_cpBodySetMoment(cpBody * x0, double x1)
{
  cpBodySetMoment(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetMoment(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetMoment", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetMoment(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetMoment _cffi_d_cpBodySetMoment
#endif

static void _cffi_d_cpBodySetPosition(cpBody * x0, cpVect x1)
{
  cpBodySetPosition(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetPosition(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetPosition", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetPosition(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodySetPosition(cpBody * x0, cpVect *x1)
{
  { cpBodySetPosition(x0, *x1); }
}
#endif

static void _cffi_d_cpBodySetPositionUpdateFunc(cpBody * x0, void(* x1)(cpBody *, double))
{
  cpBodySetPositionUpdateFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetPositionUpdateFunc(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void(* x1)(cpBody *, double);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetPositionUpdateFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, double))_cffi_to_c_pointer(arg1, _cffi_type(732));
  if (x1 == (void(*)(cpBody *, double))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetPositionUpdateFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetPositionUpdateFunc _cffi_d_cpBodySetPositionUpdateFunc
#endif

static void _cffi_d_cpBodySetTorque(cpBody * x0, double x1)
{
  cpBodySetTorque(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetTorque(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetTorque", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetTorque(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetTorque _cffi_d_cpBodySetTorque
#endif

static void _cffi_d_cpBodySetType(cpBody * x0, cpBodyType x1)
{
  cpBodySetType(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetType(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBodyType x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetType", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(672), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetType(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetType _cffi_d_cpBodySetType
#endif

static void _cffi_d_cpBodySetUserData(cpBody * x0, void * x1)
{
  cpBodySetUserData(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetUserData(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetUserData", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetUserData(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetUserData _cffi_d_cpBodySetUserData
#endif

static void _cffi_d_cpBodySetVelocity(cpBody * x0, cpVect x1)
{
  cpBodySetVelocity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetVelocity(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetVelocity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetVelocity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodySetVelocity(cpBody * x0, cpVect *x1)
{
  { cpBodySetVelocity(x0, *x1); }
}
#endif

static void _cffi_d_cpBodySetVelocityUpdateFunc(cpBody * x0, void(* x1)(cpBody *, cpVect, double, double))
{
  cpBodySetVelocityUpdateFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySetVelocityUpdateFunc(PyObject *self, PyObject *args)
{
  cpBody * x0;
  void(* x1)(cpBody *, cpVect, double, double);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySetVelocityUpdateFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, cpVect, double, double))_cffi_to_c_pointer(arg1, _cffi_type(728));
  if (x1 == (void(*)(cpBody *, cpVect, double, double))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySetVelocityUpdateFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySetVelocityUpdateFunc _cffi_d_cpBodySetVelocityUpdateFunc
#endif

static void _cffi_d_cpBodySleep(cpBody * x0)
{
  cpBodySleep(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySleep(PyObject *self, PyObject *arg0)
{
  cpBody * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySleep(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySleep _cffi_d_cpBodySleep
#endif

static void _cffi_d_cpBodySleepWithGroup(cpBody * x0, cpBody * x1)
{
  cpBodySleepWithGroup(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodySleepWithGroup(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodySleepWithGroup", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodySleepWithGroup(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodySleepWithGroup _cffi_d_cpBodySleepWithGroup
#endif

static void _cffi_d_cpBodyUpdatePosition(cpBody * x0, double x1)
{
  cpBodyUpdatePosition(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyUpdatePosition(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyUpdatePosition", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyUpdatePosition(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpBodyUpdatePosition _cffi_d_cpBodyUpdatePosition
#endif

static void _cffi_d_cpBodyUpdateVelocity(cpBody * x0, cpVect x1, double x2, double x3)
{
  cpBodyUpdateVelocity(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyUpdateVelocity(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  double x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpBodyUpdateVelocity", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpBodyUpdateVelocity(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpBodyUpdateVelocity(cpBody * x0, cpVect *x1, double x2, double x3)
{
  { cpBodyUpdateVelocity(x0, *x1, x2, x3); }
}
#endif

static cpVect _cffi_d_cpBodyWorldToLocal(cpBody const * x0, cpVect x1)
{
  return cpBodyWorldToLocal(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBodyWorldToLocal(PyObject *self, PyObject *args)
{
  cpBody const * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpBodyWorldToLocal", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(350), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBodyWorldToLocal(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpBodyWorldToLocal(cpVect *result, cpBody const * x0, cpVect *x1)
{
  { *result = cpBodyWorldToLocal(x0, *x1); }
}
#endif

static cpPolyShape * _cffi_d_cpBoxShapeInit(cpPolyShape * x0, cpBody * x1, double x2, double x3, double x4)
{
  return cpBoxShapeInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBoxShapeInit(PyObject *self, PyObject *args)
{
  cpPolyShape * x0;
  cpBody * x1;
  double x2;
  double x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpBoxShapeInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBoxShapeInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBoxShapeInit _cffi_d_cpBoxShapeInit
#endif

static cpPolyShape * _cffi_d_cpBoxShapeInit2(cpPolyShape * x0, cpBody * x1, cpBB x2, double x3)
{
  return cpBoxShapeInit2(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBoxShapeInit2(PyObject *self, PyObject *args)
{
  cpPolyShape * x0;
  cpBody * x1;
  cpBB x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpBoxShapeInit2", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(1), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBoxShapeInit2(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpPolyShape * _cffi_f_cpBoxShapeInit2(cpPolyShape * x0, cpBody * x1, cpBB *x2, double x3)
{
  cpPolyShape * result;
  { result = cpBoxShapeInit2(x0, x1, *x2, x3); }
  return result;
}
#endif

static cpShape * _cffi_d_cpBoxShapeNew(cpBody * x0, double x1, double x2, double x3)
{
  return cpBoxShapeNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBoxShapeNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  double x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpBoxShapeNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBoxShapeNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpBoxShapeNew _cffi_d_cpBoxShapeNew
#endif

static cpShape * _cffi_d_cpBoxShapeNew2(cpBody * x0, cpBB x1, double x2)
{
  return cpBoxShapeNew2(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpBoxShapeNew2(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBB x1;
  double x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpBoxShapeNew2", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpBoxShapeNew2(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpBoxShapeNew2(cpBody * x0, cpBB *x1, double x2)
{
  cpShape * result;
  { result = cpBoxShapeNew2(x0, *x1, x2); }
  return result;
}
#endif

static cpVect _cffi_d_cpCentroidForPoly(int x0, cpVect const * x1)
{
  return cpCentroidForPoly(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCentroidForPoly(PyObject *self, PyObject *args)
{
  int x0;
  cpVect const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpCentroidForPoly", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCentroidForPoly(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpCentroidForPoly(cpVect *result, int x0, cpVect const * x1)
{
  { *result = cpCentroidForPoly(x0, x1); }
}
#endif

static cpCircleShape * _cffi_d_cpCircleShapeAlloc(void)
{
  return cpCircleShapeAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeAlloc(PyObject *self, PyObject *noarg)
{
  cpCircleShape * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCircleShapeAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(61));
  return pyresult;
}
#else
#  define _cffi_f_cpCircleShapeAlloc _cffi_d_cpCircleShapeAlloc
#endif

static cpVect _cffi_d_cpCircleShapeGetOffset(cpShape const * x0)
{
  return cpCircleShapeGetOffset(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeGetOffset(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCircleShapeGetOffset(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpCircleShapeGetOffset(cpVect *result, cpShape const * x0)
{
  { *result = cpCircleShapeGetOffset(x0); }
}
#endif

static double _cffi_d_cpCircleShapeGetRadius(cpShape const * x0)
{
  return cpCircleShapeGetRadius(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeGetRadius(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCircleShapeGetRadius(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpCircleShapeGetRadius _cffi_d_cpCircleShapeGetRadius
#endif

static cpCircleShape * _cffi_d_cpCircleShapeInit(cpCircleShape * x0, cpBody * x1, double x2, cpVect x3)
{
  return cpCircleShapeInit(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeInit(PyObject *self, PyObject *args)
{
  cpCircleShape * x0;
  cpBody * x1;
  double x2;
  cpVect x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpCircleShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpCircleShapeInit", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpCircleShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCircleShapeInit(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(61));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpCircleShape * _cffi_f_cpCircleShapeInit(cpCircleShape * x0, cpBody * x1, double x2, cpVect *x3)
{
  cpCircleShape * result;
  { result = cpCircleShapeInit(x0, x1, x2, *x3); }
  return result;
}
#endif

static cpShape * _cffi_d_cpCircleShapeNew(cpBody * x0, double x1, cpVect x2)
{
  return cpCircleShapeNew(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  double x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpCircleShapeNew", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpCircleShapeNew(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpCircleShapeNew(cpBody * x0, double x1, cpVect *x2)
{
  cpShape * result;
  { result = cpCircleShapeNew(x0, x1, *x2); }
  return result;
}
#endif

static void _cffi_d_cpCircleShapeSetOffset(cpShape * x0, cpVect x1)
{
  cpCircleShapeSetOffset(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeSetOffset(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpCircleShapeSetOffset", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpCircleShapeSetOffset(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpCircleShapeSetOffset(cpShape * x0, cpVect *x1)
{
  { cpCircleShapeSetOffset(x0, *x1); }
}
#endif

static void _cffi_d_cpCircleShapeSetRadius(cpShape * x0, double x1)
{
  cpCircleShapeSetRadius(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpCircleShapeSetRadius(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpCircleShapeSetRadius", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpCircleShapeSetRadius(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpCircleShapeSetRadius _cffi_d_cpCircleShapeSetRadius
#endif

static void _cffi_d_cpConstraintDestroy(cpConstraint * x0)
{
  cpConstraintDestroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintDestroy(PyObject *self, PyObject *arg0)
{
  cpConstraint * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintDestroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintDestroy _cffi_d_cpConstraintDestroy
#endif

static void _cffi_d_cpConstraintFree(cpConstraint * x0)
{
  cpConstraintFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintFree(PyObject *self, PyObject *arg0)
{
  cpConstraint * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintFree _cffi_d_cpConstraintFree
#endif

static cpBody * _cffi_d_cpConstraintGetBodyA(cpConstraint const * x0)
{
  return cpConstraintGetBodyA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetBodyA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetBodyA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetBodyA _cffi_d_cpConstraintGetBodyA
#endif

static cpBody * _cffi_d_cpConstraintGetBodyB(cpConstraint const * x0)
{
  return cpConstraintGetBodyB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetBodyB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetBodyB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetBodyB _cffi_d_cpConstraintGetBodyB
#endif

static unsigned char _cffi_d_cpConstraintGetCollideBodies(cpConstraint const * x0)
{
  return cpConstraintGetCollideBodies(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetCollideBodies(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetCollideBodies(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetCollideBodies _cffi_d_cpConstraintGetCollideBodies
#endif

static double _cffi_d_cpConstraintGetErrorBias(cpConstraint const * x0)
{
  return cpConstraintGetErrorBias(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetErrorBias(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetErrorBias(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetErrorBias _cffi_d_cpConstraintGetErrorBias
#endif

static double _cffi_d_cpConstraintGetImpulse(cpConstraint * x0)
{
  return cpConstraintGetImpulse(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetImpulse(PyObject *self, PyObject *arg0)
{
  cpConstraint * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetImpulse(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetImpulse _cffi_d_cpConstraintGetImpulse
#endif

static double _cffi_d_cpConstraintGetMaxBias(cpConstraint const * x0)
{
  return cpConstraintGetMaxBias(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetMaxBias(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetMaxBias(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetMaxBias _cffi_d_cpConstraintGetMaxBias
#endif

static double _cffi_d_cpConstraintGetMaxForce(cpConstraint const * x0)
{
  return cpConstraintGetMaxForce(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetMaxForce(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetMaxForce(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetMaxForce _cffi_d_cpConstraintGetMaxForce
#endif

static void(* _cffi_d_cpConstraintGetPostSolveFunc(cpConstraint const * x0))(cpConstraint *, cpSpace *)
{
  return cpConstraintGetPostSolveFunc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetPostSolveFunc(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void(* result)(cpConstraint *, cpSpace *);
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetPostSolveFunc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(763));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetPostSolveFunc _cffi_d_cpConstraintGetPostSolveFunc
#endif

static void(* _cffi_d_cpConstraintGetPreSolveFunc(cpConstraint const * x0))(cpConstraint *, cpSpace *)
{
  return cpConstraintGetPreSolveFunc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetPreSolveFunc(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void(* result)(cpConstraint *, cpSpace *);
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetPreSolveFunc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(763));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetPreSolveFunc _cffi_d_cpConstraintGetPreSolveFunc
#endif

static cpSpace * _cffi_d_cpConstraintGetSpace(cpConstraint const * x0)
{
  return cpConstraintGetSpace(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetSpace(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSpace * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetSpace(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetSpace _cffi_d_cpConstraintGetSpace
#endif

static void * _cffi_d_cpConstraintGetUserData(cpConstraint const * x0)
{
  return cpConstraintGetUserData(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintGetUserData(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintGetUserData(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(365));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintGetUserData _cffi_d_cpConstraintGetUserData
#endif

static unsigned char _cffi_d_cpConstraintIsDampedRotarySpring(cpConstraint const * x0)
{
  return cpConstraintIsDampedRotarySpring(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsDampedRotarySpring(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsDampedRotarySpring(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsDampedRotarySpring _cffi_d_cpConstraintIsDampedRotarySpring
#endif

static unsigned char _cffi_d_cpConstraintIsDampedSpring(cpConstraint const * x0)
{
  return cpConstraintIsDampedSpring(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsDampedSpring(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsDampedSpring(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsDampedSpring _cffi_d_cpConstraintIsDampedSpring
#endif

static unsigned char _cffi_d_cpConstraintIsGearJoint(cpConstraint const * x0)
{
  return cpConstraintIsGearJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsGearJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsGearJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsGearJoint _cffi_d_cpConstraintIsGearJoint
#endif

static unsigned char _cffi_d_cpConstraintIsGrooveJoint(cpConstraint const * x0)
{
  return cpConstraintIsGrooveJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsGrooveJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsGrooveJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsGrooveJoint _cffi_d_cpConstraintIsGrooveJoint
#endif

static unsigned char _cffi_d_cpConstraintIsPinJoint(cpConstraint const * x0)
{
  return cpConstraintIsPinJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsPinJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsPinJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsPinJoint _cffi_d_cpConstraintIsPinJoint
#endif

static unsigned char _cffi_d_cpConstraintIsPivotJoint(cpConstraint const * x0)
{
  return cpConstraintIsPivotJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsPivotJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsPivotJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsPivotJoint _cffi_d_cpConstraintIsPivotJoint
#endif

static unsigned char _cffi_d_cpConstraintIsRatchetJoint(cpConstraint const * x0)
{
  return cpConstraintIsRatchetJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsRatchetJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsRatchetJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsRatchetJoint _cffi_d_cpConstraintIsRatchetJoint
#endif

static unsigned char _cffi_d_cpConstraintIsRotaryLimitJoint(cpConstraint const * x0)
{
  return cpConstraintIsRotaryLimitJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsRotaryLimitJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsRotaryLimitJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsRotaryLimitJoint _cffi_d_cpConstraintIsRotaryLimitJoint
#endif

static unsigned char _cffi_d_cpConstraintIsSimpleMotor(cpConstraint const * x0)
{
  return cpConstraintIsSimpleMotor(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsSimpleMotor(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsSimpleMotor(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsSimpleMotor _cffi_d_cpConstraintIsSimpleMotor
#endif

static unsigned char _cffi_d_cpConstraintIsSlideJoint(cpConstraint const * x0)
{
  return cpConstraintIsSlideJoint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintIsSlideJoint(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpConstraintIsSlideJoint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpConstraintIsSlideJoint _cffi_d_cpConstraintIsSlideJoint
#endif

static void _cffi_d_cpConstraintSetCollideBodies(cpConstraint * x0, unsigned char x1)
{
  cpConstraintSetCollideBodies(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetCollideBodies(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetCollideBodies", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetCollideBodies(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetCollideBodies _cffi_d_cpConstraintSetCollideBodies
#endif

static void _cffi_d_cpConstraintSetErrorBias(cpConstraint * x0, double x1)
{
  cpConstraintSetErrorBias(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetErrorBias(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetErrorBias", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetErrorBias(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetErrorBias _cffi_d_cpConstraintSetErrorBias
#endif

static void _cffi_d_cpConstraintSetMaxBias(cpConstraint * x0, double x1)
{
  cpConstraintSetMaxBias(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetMaxBias(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetMaxBias", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetMaxBias(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetMaxBias _cffi_d_cpConstraintSetMaxBias
#endif

static void _cffi_d_cpConstraintSetMaxForce(cpConstraint * x0, double x1)
{
  cpConstraintSetMaxForce(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetMaxForce(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetMaxForce", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetMaxForce(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetMaxForce _cffi_d_cpConstraintSetMaxForce
#endif

static void _cffi_d_cpConstraintSetPostSolveFunc(cpConstraint * x0, void(* x1)(cpConstraint *, cpSpace *))
{
  cpConstraintSetPostSolveFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetPostSolveFunc(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  void(* x1)(cpConstraint *, cpSpace *);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetPostSolveFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpConstraint *, cpSpace *))_cffi_to_c_pointer(arg1, _cffi_type(763));
  if (x1 == (void(*)(cpConstraint *, cpSpace *))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetPostSolveFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetPostSolveFunc _cffi_d_cpConstraintSetPostSolveFunc
#endif

static void _cffi_d_cpConstraintSetPreSolveFunc(cpConstraint * x0, void(* x1)(cpConstraint *, cpSpace *))
{
  cpConstraintSetPreSolveFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetPreSolveFunc(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  void(* x1)(cpConstraint *, cpSpace *);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetPreSolveFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpConstraint *, cpSpace *))_cffi_to_c_pointer(arg1, _cffi_type(763));
  if (x1 == (void(*)(cpConstraint *, cpSpace *))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetPreSolveFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetPreSolveFunc _cffi_d_cpConstraintSetPreSolveFunc
#endif

static void _cffi_d_cpConstraintSetUserData(cpConstraint * x0, void * x1)
{
  cpConstraintSetUserData(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpConstraintSetUserData(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpConstraintSetUserData", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpConstraintSetUserData(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpConstraintSetUserData _cffi_d_cpConstraintSetUserData
#endif

static cpDampedRotarySpring * _cffi_d_cpDampedRotarySpringAlloc(void)
{
  return cpDampedRotarySpringAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringAlloc(PyObject *self, PyObject *noarg)
{
  cpDampedRotarySpring * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(145));
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringAlloc _cffi_d_cpDampedRotarySpringAlloc
#endif

static double _cffi_d_cpDampedRotarySpringGetDamping(cpConstraint const * x0)
{
  return cpDampedRotarySpringGetDamping(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringGetDamping(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringGetDamping(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringGetDamping _cffi_d_cpDampedRotarySpringGetDamping
#endif

static double _cffi_d_cpDampedRotarySpringGetRestAngle(cpConstraint const * x0)
{
  return cpDampedRotarySpringGetRestAngle(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringGetRestAngle(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringGetRestAngle(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringGetRestAngle _cffi_d_cpDampedRotarySpringGetRestAngle
#endif

static double(* _cffi_d_cpDampedRotarySpringGetSpringTorqueFunc(cpConstraint const * x0))(cpConstraint *, double)
{
  return cpDampedRotarySpringGetSpringTorqueFunc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringGetSpringTorqueFunc(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double(* result)(cpConstraint *, double);
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringGetSpringTorqueFunc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(747));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringGetSpringTorqueFunc _cffi_d_cpDampedRotarySpringGetSpringTorqueFunc
#endif

static double _cffi_d_cpDampedRotarySpringGetStiffness(cpConstraint const * x0)
{
  return cpDampedRotarySpringGetStiffness(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringGetStiffness(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringGetStiffness(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringGetStiffness _cffi_d_cpDampedRotarySpringGetStiffness
#endif

static cpDampedRotarySpring * _cffi_d_cpDampedRotarySpringInit(cpDampedRotarySpring * x0, cpBody * x1, cpBody * x2, double x3, double x4, double x5)
{
  return cpDampedRotarySpringInit(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringInit(PyObject *self, PyObject *args)
{
  cpDampedRotarySpring * x0;
  cpBody * x1;
  cpBody * x2;
  double x3;
  double x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpDampedRotarySpring * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringInit", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(145), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpDampedRotarySpring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(145), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringInit(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(145));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringInit _cffi_d_cpDampedRotarySpringInit
#endif

static cpConstraint * _cffi_d_cpDampedRotarySpringNew(cpBody * x0, cpBody * x1, double x2, double x3, double x4)
{
  return cpDampedRotarySpringNew(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  double x2;
  double x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringNew", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedRotarySpringNew(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedRotarySpringNew _cffi_d_cpDampedRotarySpringNew
#endif

static void _cffi_d_cpDampedRotarySpringSetDamping(cpConstraint * x0, double x1)
{
  cpDampedRotarySpringSetDamping(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringSetDamping(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringSetDamping", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedRotarySpringSetDamping(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedRotarySpringSetDamping _cffi_d_cpDampedRotarySpringSetDamping
#endif

static void _cffi_d_cpDampedRotarySpringSetRestAngle(cpConstraint * x0, double x1)
{
  cpDampedRotarySpringSetRestAngle(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringSetRestAngle(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringSetRestAngle", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedRotarySpringSetRestAngle(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedRotarySpringSetRestAngle _cffi_d_cpDampedRotarySpringSetRestAngle
#endif

static void _cffi_d_cpDampedRotarySpringSetSpringTorqueFunc(cpConstraint * x0, double(* x1)(cpConstraint *, double))
{
  cpDampedRotarySpringSetSpringTorqueFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringSetSpringTorqueFunc(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double(* x1)(cpConstraint *, double);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringSetSpringTorqueFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double(*)(cpConstraint *, double))_cffi_to_c_pointer(arg1, _cffi_type(747));
  if (x1 == (double(*)(cpConstraint *, double))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedRotarySpringSetSpringTorqueFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedRotarySpringSetSpringTorqueFunc _cffi_d_cpDampedRotarySpringSetSpringTorqueFunc
#endif

static void _cffi_d_cpDampedRotarySpringSetStiffness(cpConstraint * x0, double x1)
{
  cpDampedRotarySpringSetStiffness(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedRotarySpringSetStiffness(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedRotarySpringSetStiffness", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedRotarySpringSetStiffness(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedRotarySpringSetStiffness _cffi_d_cpDampedRotarySpringSetStiffness
#endif

static cpDampedSpring * _cffi_d_cpDampedSpringAlloc(void)
{
  return cpDampedSpringAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringAlloc(PyObject *self, PyObject *noarg)
{
  cpDampedSpring * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(155));
  return pyresult;
}
#else
#  define _cffi_f_cpDampedSpringAlloc _cffi_d_cpDampedSpringAlloc
#endif

static cpVect _cffi_d_cpDampedSpringGetAnchorA(cpConstraint const * x0)
{
  return cpDampedSpringGetAnchorA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetAnchorA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetAnchorA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpDampedSpringGetAnchorA(cpVect *result, cpConstraint const * x0)
{
  { *result = cpDampedSpringGetAnchorA(x0); }
}
#endif

static cpVect _cffi_d_cpDampedSpringGetAnchorB(cpConstraint const * x0)
{
  return cpDampedSpringGetAnchorB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetAnchorB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetAnchorB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpDampedSpringGetAnchorB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpDampedSpringGetAnchorB(x0); }
}
#endif

static double _cffi_d_cpDampedSpringGetDamping(cpConstraint const * x0)
{
  return cpDampedSpringGetDamping(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetDamping(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetDamping(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedSpringGetDamping _cffi_d_cpDampedSpringGetDamping
#endif

static double _cffi_d_cpDampedSpringGetRestLength(cpConstraint const * x0)
{
  return cpDampedSpringGetRestLength(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetRestLength(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetRestLength(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedSpringGetRestLength _cffi_d_cpDampedSpringGetRestLength
#endif

static double(* _cffi_d_cpDampedSpringGetSpringForceFunc(cpConstraint const * x0))(cpConstraint *, double)
{
  return cpDampedSpringGetSpringForceFunc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetSpringForceFunc(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double(* result)(cpConstraint *, double);
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetSpringForceFunc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(747));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedSpringGetSpringForceFunc _cffi_d_cpDampedSpringGetSpringForceFunc
#endif

static double _cffi_d_cpDampedSpringGetStiffness(cpConstraint const * x0)
{
  return cpDampedSpringGetStiffness(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringGetStiffness(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringGetStiffness(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpDampedSpringGetStiffness _cffi_d_cpDampedSpringGetStiffness
#endif

static cpDampedSpring * _cffi_d_cpDampedSpringInit(cpDampedSpring * x0, cpBody * x1, cpBody * x2, cpVect x3, cpVect x4, double x5, double x6, double x7)
{
  return cpDampedSpringInit(x0, x1, x2, x3, x4, x5, x6, x7);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringInit(PyObject *self, PyObject *args)
{
  cpDampedSpring * x0;
  cpBody * x1;
  cpBody * x2;
  cpVect x3;
  cpVect x4;
  double x5;
  double x6;
  double x7;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpDampedSpring * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringInit", 8, 8, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(155), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpDampedSpring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(155), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  x6 = (double)_cffi_to_c_double(arg6);
  if (x6 == (double)-1 && PyErr_Occurred())
    return NULL;

  x7 = (double)_cffi_to_c_double(arg7);
  if (x7 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringInit(x0, x1, x2, x3, x4, x5, x6, x7); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(155));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpDampedSpring * _cffi_f_cpDampedSpringInit(cpDampedSpring * x0, cpBody * x1, cpBody * x2, cpVect *x3, cpVect *x4, double x5, double x6, double x7)
{
  cpDampedSpring * result;
  { result = cpDampedSpringInit(x0, x1, x2, *x3, *x4, x5, x6, x7); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpDampedSpringNew(cpBody * x0, cpBody * x1, cpVect x2, cpVect x3, double x4, double x5, double x6)
{
  return cpDampedSpringNew(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  double x4;
  double x5;
  double x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringNew", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  x6 = (double)_cffi_to_c_double(arg6);
  if (x6 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpDampedSpringNew(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpDampedSpringNew(cpBody * x0, cpBody * x1, cpVect *x2, cpVect *x3, double x4, double x5, double x6)
{
  cpConstraint * result;
  { result = cpDampedSpringNew(x0, x1, *x2, *x3, x4, x5, x6); }
  return result;
}
#endif

static void _cffi_d_cpDampedSpringSetAnchorA(cpConstraint * x0, cpVect x1)
{
  cpDampedSpringSetAnchorA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetAnchorA(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetAnchorA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetAnchorA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpDampedSpringSetAnchorA(cpConstraint * x0, cpVect *x1)
{
  { cpDampedSpringSetAnchorA(x0, *x1); }
}
#endif

static void _cffi_d_cpDampedSpringSetAnchorB(cpConstraint * x0, cpVect x1)
{
  cpDampedSpringSetAnchorB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetAnchorB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetAnchorB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetAnchorB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpDampedSpringSetAnchorB(cpConstraint * x0, cpVect *x1)
{
  { cpDampedSpringSetAnchorB(x0, *x1); }
}
#endif

static void _cffi_d_cpDampedSpringSetDamping(cpConstraint * x0, double x1)
{
  cpDampedSpringSetDamping(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetDamping(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetDamping", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetDamping(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedSpringSetDamping _cffi_d_cpDampedSpringSetDamping
#endif

static void _cffi_d_cpDampedSpringSetRestLength(cpConstraint * x0, double x1)
{
  cpDampedSpringSetRestLength(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetRestLength(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetRestLength", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetRestLength(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedSpringSetRestLength _cffi_d_cpDampedSpringSetRestLength
#endif

static void _cffi_d_cpDampedSpringSetSpringForceFunc(cpConstraint * x0, double(* x1)(cpConstraint *, double))
{
  cpDampedSpringSetSpringForceFunc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetSpringForceFunc(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double(* x1)(cpConstraint *, double);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetSpringForceFunc", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double(*)(cpConstraint *, double))_cffi_to_c_pointer(arg1, _cffi_type(747));
  if (x1 == (double(*)(cpConstraint *, double))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetSpringForceFunc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedSpringSetSpringForceFunc _cffi_d_cpDampedSpringSetSpringForceFunc
#endif

static void _cffi_d_cpDampedSpringSetStiffness(cpConstraint * x0, double x1)
{
  cpDampedSpringSetStiffness(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpDampedSpringSetStiffness(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpDampedSpringSetStiffness", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpDampedSpringSetStiffness(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpDampedSpringSetStiffness _cffi_d_cpDampedSpringSetStiffness
#endif

static cpGearJoint * _cffi_d_cpGearJointAlloc(void)
{
  return cpGearJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointAlloc(PyObject *self, PyObject *noarg)
{
  cpGearJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGearJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(167));
  return pyresult;
}
#else
#  define _cffi_f_cpGearJointAlloc _cffi_d_cpGearJointAlloc
#endif

static double _cffi_d_cpGearJointGetPhase(cpConstraint const * x0)
{
  return cpGearJointGetPhase(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointGetPhase(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGearJointGetPhase(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpGearJointGetPhase _cffi_d_cpGearJointGetPhase
#endif

static double _cffi_d_cpGearJointGetRatio(cpConstraint const * x0)
{
  return cpGearJointGetRatio(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointGetRatio(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGearJointGetRatio(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpGearJointGetRatio _cffi_d_cpGearJointGetRatio
#endif

static cpGearJoint * _cffi_d_cpGearJointInit(cpGearJoint * x0, cpBody * x1, cpBody * x2, double x3, double x4)
{
  return cpGearJointInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointInit(PyObject *self, PyObject *args)
{
  cpGearJoint * x0;
  cpBody * x1;
  cpBody * x2;
  double x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpGearJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpGearJointInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(167), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpGearJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(167), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGearJointInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(167));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpGearJointInit _cffi_d_cpGearJointInit
#endif

static cpConstraint * _cffi_d_cpGearJointNew(cpBody * x0, cpBody * x1, double x2, double x3)
{
  return cpGearJointNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  double x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpGearJointNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGearJointNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpGearJointNew _cffi_d_cpGearJointNew
#endif

static void _cffi_d_cpGearJointSetPhase(cpConstraint * x0, double x1)
{
  cpGearJointSetPhase(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointSetPhase(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpGearJointSetPhase", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpGearJointSetPhase(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpGearJointSetPhase _cffi_d_cpGearJointSetPhase
#endif

static void _cffi_d_cpGearJointSetRatio(cpConstraint * x0, double x1)
{
  cpGearJointSetRatio(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGearJointSetRatio(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpGearJointSetRatio", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpGearJointSetRatio(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpGearJointSetRatio _cffi_d_cpGearJointSetRatio
#endif

static cpGrooveJoint * _cffi_d_cpGrooveJointAlloc(void)
{
  return cpGrooveJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointAlloc(PyObject *self, PyObject *noarg)
{
  cpGrooveJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(176));
  return pyresult;
}
#else
#  define _cffi_f_cpGrooveJointAlloc _cffi_d_cpGrooveJointAlloc
#endif

static cpVect _cffi_d_cpGrooveJointGetAnchorB(cpConstraint const * x0)
{
  return cpGrooveJointGetAnchorB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointGetAnchorB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointGetAnchorB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpGrooveJointGetAnchorB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpGrooveJointGetAnchorB(x0); }
}
#endif

static cpVect _cffi_d_cpGrooveJointGetGrooveA(cpConstraint const * x0)
{
  return cpGrooveJointGetGrooveA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointGetGrooveA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointGetGrooveA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpGrooveJointGetGrooveA(cpVect *result, cpConstraint const * x0)
{
  { *result = cpGrooveJointGetGrooveA(x0); }
}
#endif

static cpVect _cffi_d_cpGrooveJointGetGrooveB(cpConstraint const * x0)
{
  return cpGrooveJointGetGrooveB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointGetGrooveB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointGetGrooveB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpGrooveJointGetGrooveB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpGrooveJointGetGrooveB(x0); }
}
#endif

static cpGrooveJoint * _cffi_d_cpGrooveJointInit(cpGrooveJoint * x0, cpBody * x1, cpBody * x2, cpVect x3, cpVect x4, cpVect x5)
{
  return cpGrooveJointInit(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointInit(PyObject *self, PyObject *args)
{
  cpGrooveJoint * x0;
  cpBody * x1;
  cpBody * x2;
  cpVect x3;
  cpVect x4;
  cpVect x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpGrooveJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpGrooveJointInit", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpGrooveJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(176), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x5, _cffi_type(6), arg5) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointInit(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(176));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpGrooveJoint * _cffi_f_cpGrooveJointInit(cpGrooveJoint * x0, cpBody * x1, cpBody * x2, cpVect *x3, cpVect *x4, cpVect *x5)
{
  cpGrooveJoint * result;
  { result = cpGrooveJointInit(x0, x1, x2, *x3, *x4, *x5); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpGrooveJointNew(cpBody * x0, cpBody * x1, cpVect x2, cpVect x3, cpVect x4)
{
  return cpGrooveJointNew(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  cpVect x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpGrooveJointNew", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpGrooveJointNew(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpGrooveJointNew(cpBody * x0, cpBody * x1, cpVect *x2, cpVect *x3, cpVect *x4)
{
  cpConstraint * result;
  { result = cpGrooveJointNew(x0, x1, *x2, *x3, *x4); }
  return result;
}
#endif

static void _cffi_d_cpGrooveJointSetAnchorB(cpConstraint * x0, cpVect x1)
{
  cpGrooveJointSetAnchorB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointSetAnchorB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpGrooveJointSetAnchorB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpGrooveJointSetAnchorB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpGrooveJointSetAnchorB(cpConstraint * x0, cpVect *x1)
{
  { cpGrooveJointSetAnchorB(x0, *x1); }
}
#endif

static void _cffi_d_cpGrooveJointSetGrooveA(cpConstraint * x0, cpVect x1)
{
  cpGrooveJointSetGrooveA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointSetGrooveA(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpGrooveJointSetGrooveA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpGrooveJointSetGrooveA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpGrooveJointSetGrooveA(cpConstraint * x0, cpVect *x1)
{
  { cpGrooveJointSetGrooveA(x0, *x1); }
}
#endif

static void _cffi_d_cpGrooveJointSetGrooveB(cpConstraint * x0, cpVect x1)
{
  cpGrooveJointSetGrooveB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpGrooveJointSetGrooveB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpGrooveJointSetGrooveB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpGrooveJointSetGrooveB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpGrooveJointSetGrooveB(cpConstraint * x0, cpVect *x1)
{
  { cpGrooveJointSetGrooveB(x0, *x1); }
}
#endif

static void _cffi_d_cpHastySpaceFree(cpSpace * x0)
{
  cpHastySpaceFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpHastySpaceFree(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpHastySpaceFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpHastySpaceFree _cffi_d_cpHastySpaceFree
#endif

static unsigned long _cffi_d_cpHastySpaceGetThreads(cpSpace * x0)
{
  return cpHastySpaceGetThreads(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpHastySpaceGetThreads(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpHastySpaceGetThreads(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpHastySpaceGetThreads _cffi_d_cpHastySpaceGetThreads
#endif

static cpSpace * _cffi_d_cpHastySpaceNew(void)
{
  return cpHastySpaceNew();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpHastySpaceNew(PyObject *self, PyObject *noarg)
{
  cpSpace * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpHastySpaceNew(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpHastySpaceNew _cffi_d_cpHastySpaceNew
#endif

static void _cffi_d_cpHastySpaceSetThreads(cpSpace * x0, unsigned long x1)
{
  cpHastySpaceSetThreads(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpHastySpaceSetThreads(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpHastySpaceSetThreads", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpHastySpaceSetThreads(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpHastySpaceSetThreads _cffi_d_cpHastySpaceSetThreads
#endif

static void _cffi_d_cpHastySpaceStep(cpSpace * x0, double x1)
{
  cpHastySpaceStep(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpHastySpaceStep(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpHastySpaceStep", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpHastySpaceStep(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpHastySpaceStep _cffi_d_cpHastySpaceStep
#endif

static void _cffi_d_cpMarchHard(cpBB x0, unsigned long x1, unsigned long x2, double x3, void(* x4)(cpVect, cpVect, void *), void * x5, double(* x6)(cpVect, void *), void * x7)
{
  cpMarchHard(x0, x1, x2, x3, x4, x5, x6, x7);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMarchHard(PyObject *self, PyObject *args)
{
  cpBB x0;
  unsigned long x1;
  unsigned long x2;
  double x3;
  void(* x4)(cpVect, cpVect, void *);
  void * x5;
  double(* x6)(cpVect, void *);
  void * x7;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;

  if (!PyArg_UnpackTuple(args, "cpMarchHard", 8, 8, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (void(*)(cpVect, cpVect, void *))_cffi_to_c_pointer(arg4, _cffi_type(653));
  if (x4 == (void(*)(cpVect, cpVect, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = (double(*)(cpVect, void *))_cffi_to_c_pointer(arg6, _cffi_type(655));
  if (x6 == (double(*)(cpVect, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg7, (char **)&x7);
  if (datasize != 0) {
    x7 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg7, (char **)&x7,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpMarchHard(x0, x1, x2, x3, x4, x5, x6, x7); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpMarchHard(cpBB *x0, unsigned long x1, unsigned long x2, double x3, void(* x4)(cpVect, cpVect, void *), void * x5, double(* x6)(cpVect, void *), void * x7)
{
  { cpMarchHard(*x0, x1, x2, x3, x4, x5, x6, x7); }
}
#endif

static void _cffi_d_cpMarchSoft(cpBB x0, unsigned long x1, unsigned long x2, double x3, void(* x4)(cpVect, cpVect, void *), void * x5, double(* x6)(cpVect, void *), void * x7)
{
  cpMarchSoft(x0, x1, x2, x3, x4, x5, x6, x7);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMarchSoft(PyObject *self, PyObject *args)
{
  cpBB x0;
  unsigned long x1;
  unsigned long x2;
  double x3;
  void(* x4)(cpVect, cpVect, void *);
  void * x5;
  double(* x6)(cpVect, void *);
  void * x7;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;

  if (!PyArg_UnpackTuple(args, "cpMarchSoft", 8, 8, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(1), arg0) < 0)
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (void(*)(cpVect, cpVect, void *))_cffi_to_c_pointer(arg4, _cffi_type(653));
  if (x4 == (void(*)(cpVect, cpVect, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = (double(*)(cpVect, void *))_cffi_to_c_pointer(arg6, _cffi_type(655));
  if (x6 == (double(*)(cpVect, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg7, (char **)&x7);
  if (datasize != 0) {
    x7 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg7, (char **)&x7,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpMarchSoft(x0, x1, x2, x3, x4, x5, x6, x7); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpMarchSoft(cpBB *x0, unsigned long x1, unsigned long x2, double x3, void(* x4)(cpVect, cpVect, void *), void * x5, double(* x6)(cpVect, void *), void * x7)
{
  { cpMarchSoft(*x0, x1, x2, x3, x4, x5, x6, x7); }
}
#endif

static double _cffi_d_cpMomentForBox(double x0, double x1, double x2)
{
  return cpMomentForBox(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMomentForBox(PyObject *self, PyObject *args)
{
  double x0;
  double x1;
  double x2;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpMomentForBox", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpMomentForBox(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
#  define _cffi_f_cpMomentForBox _cffi_d_cpMomentForBox
#endif

static double _cffi_d_cpMomentForBox2(double x0, cpBB x1)
{
  return cpMomentForBox2(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMomentForBox2(PyObject *self, PyObject *args)
{
  double x0;
  cpBB x1;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpMomentForBox2", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpMomentForBox2(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpMomentForBox2(double x0, cpBB *x1)
{
  double result;
  { result = cpMomentForBox2(x0, *x1); }
  return result;
}
#endif

static double _cffi_d_cpMomentForCircle(double x0, double x1, double x2, cpVect x3)
{
  return cpMomentForCircle(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMomentForCircle(PyObject *self, PyObject *args)
{
  double x0;
  double x1;
  double x2;
  cpVect x3;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpMomentForCircle", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpMomentForCircle(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpMomentForCircle(double x0, double x1, double x2, cpVect *x3)
{
  double result;
  { result = cpMomentForCircle(x0, x1, x2, *x3); }
  return result;
}
#endif

static double _cffi_d_cpMomentForPoly(double x0, int x1, cpVect const * x2, cpVect x3, double x4)
{
  return cpMomentForPoly(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMomentForPoly(PyObject *self, PyObject *args)
{
  double x0;
  int x1;
  cpVect const * x2;
  cpVect x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpMomentForPoly", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpMomentForPoly(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static double _cffi_f_cpMomentForPoly(double x0, int x1, cpVect const * x2, cpVect *x3, double x4)
{
  double result;
  { result = cpMomentForPoly(x0, x1, x2, *x3, x4); }
  return result;
}
#endif

static double _cffi_d_cpMomentForSegment(double x0, cpVect x1, cpVect x2, double x3)
{
  return cpMomentForSegment(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpMomentForSegment(PyObject *self, PyObject *args)
{
  double x0;
  cpVect x1;
  cpVect x2;
  double x3;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpMomentForSegment", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = (double)_cffi_to_c_double(arg0);
  if (x0 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpMomentForSegment(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  return pyresult;
}
#else
static double _cffi_f_cpMomentForSegment(double x0, cpVect *x1, cpVect *x2, double x3)
{
  double result;
  { result = cpMomentForSegment(x0, *x1, *x2, x3); }
  return result;
}
#endif

static cpPinJoint * _cffi_d_cpPinJointAlloc(void)
{
  return cpPinJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointAlloc(PyObject *self, PyObject *noarg)
{
  cpPinJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(186));
  return pyresult;
}
#else
#  define _cffi_f_cpPinJointAlloc _cffi_d_cpPinJointAlloc
#endif

static cpVect _cffi_d_cpPinJointGetAnchorA(cpConstraint const * x0)
{
  return cpPinJointGetAnchorA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointGetAnchorA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointGetAnchorA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpPinJointGetAnchorA(cpVect *result, cpConstraint const * x0)
{
  { *result = cpPinJointGetAnchorA(x0); }
}
#endif

static cpVect _cffi_d_cpPinJointGetAnchorB(cpConstraint const * x0)
{
  return cpPinJointGetAnchorB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointGetAnchorB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointGetAnchorB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpPinJointGetAnchorB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpPinJointGetAnchorB(x0); }
}
#endif

static double _cffi_d_cpPinJointGetDist(cpConstraint const * x0)
{
  return cpPinJointGetDist(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointGetDist(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointGetDist(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPinJointGetDist _cffi_d_cpPinJointGetDist
#endif

static cpPinJoint * _cffi_d_cpPinJointInit(cpPinJoint * x0, cpBody * x1, cpBody * x2, cpVect x3, cpVect x4)
{
  return cpPinJointInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointInit(PyObject *self, PyObject *args)
{
  cpPinJoint * x0;
  cpBody * x1;
  cpBody * x2;
  cpVect x3;
  cpVect x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPinJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpPinJointInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(186), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPinJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(186), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(186));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpPinJoint * _cffi_f_cpPinJointInit(cpPinJoint * x0, cpBody * x1, cpBody * x2, cpVect *x3, cpVect *x4)
{
  cpPinJoint * result;
  { result = cpPinJointInit(x0, x1, x2, *x3, *x4); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpPinJointNew(cpBody * x0, cpBody * x1, cpVect x2, cpVect x3)
{
  return cpPinJointNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpPinJointNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPinJointNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpPinJointNew(cpBody * x0, cpBody * x1, cpVect *x2, cpVect *x3)
{
  cpConstraint * result;
  { result = cpPinJointNew(x0, x1, *x2, *x3); }
  return result;
}
#endif

static void _cffi_d_cpPinJointSetAnchorA(cpConstraint * x0, cpVect x1)
{
  cpPinJointSetAnchorA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointSetAnchorA(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPinJointSetAnchorA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPinJointSetAnchorA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPinJointSetAnchorA(cpConstraint * x0, cpVect *x1)
{
  { cpPinJointSetAnchorA(x0, *x1); }
}
#endif

static void _cffi_d_cpPinJointSetAnchorB(cpConstraint * x0, cpVect x1)
{
  cpPinJointSetAnchorB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointSetAnchorB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPinJointSetAnchorB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPinJointSetAnchorB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPinJointSetAnchorB(cpConstraint * x0, cpVect *x1)
{
  { cpPinJointSetAnchorB(x0, *x1); }
}
#endif

static void _cffi_d_cpPinJointSetDist(cpConstraint * x0, double x1)
{
  cpPinJointSetDist(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPinJointSetDist(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPinJointSetDist", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPinJointSetDist(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPinJointSetDist _cffi_d_cpPinJointSetDist
#endif

static cpPivotJoint * _cffi_d_cpPivotJointAlloc(void)
{
  return cpPivotJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointAlloc(PyObject *self, PyObject *noarg)
{
  cpPivotJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(195));
  return pyresult;
}
#else
#  define _cffi_f_cpPivotJointAlloc _cffi_d_cpPivotJointAlloc
#endif

static cpVect _cffi_d_cpPivotJointGetAnchorA(cpConstraint const * x0)
{
  return cpPivotJointGetAnchorA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointGetAnchorA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointGetAnchorA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpPivotJointGetAnchorA(cpVect *result, cpConstraint const * x0)
{
  { *result = cpPivotJointGetAnchorA(x0); }
}
#endif

static cpVect _cffi_d_cpPivotJointGetAnchorB(cpConstraint const * x0)
{
  return cpPivotJointGetAnchorB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointGetAnchorB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointGetAnchorB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpPivotJointGetAnchorB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpPivotJointGetAnchorB(x0); }
}
#endif

static cpPivotJoint * _cffi_d_cpPivotJointInit(cpPivotJoint * x0, cpBody * x1, cpBody * x2, cpVect x3, cpVect x4)
{
  return cpPivotJointInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointInit(PyObject *self, PyObject *args)
{
  cpPivotJoint * x0;
  cpBody * x1;
  cpBody * x2;
  cpVect x3;
  cpVect x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPivotJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpPivotJointInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(195), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPivotJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(195), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(195));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpPivotJoint * _cffi_f_cpPivotJointInit(cpPivotJoint * x0, cpBody * x1, cpBody * x2, cpVect *x3, cpVect *x4)
{
  cpPivotJoint * result;
  { result = cpPivotJointInit(x0, x1, x2, *x3, *x4); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpPivotJointNew(cpBody * x0, cpBody * x1, cpVect x2)
{
  return cpPivotJointNew(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpPivotJointNew", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointNew(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpPivotJointNew(cpBody * x0, cpBody * x1, cpVect *x2)
{
  cpConstraint * result;
  { result = cpPivotJointNew(x0, x1, *x2); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpPivotJointNew2(cpBody * x0, cpBody * x1, cpVect x2, cpVect x3)
{
  return cpPivotJointNew2(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointNew2(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpPivotJointNew2", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPivotJointNew2(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpPivotJointNew2(cpBody * x0, cpBody * x1, cpVect *x2, cpVect *x3)
{
  cpConstraint * result;
  { result = cpPivotJointNew2(x0, x1, *x2, *x3); }
  return result;
}
#endif

static void _cffi_d_cpPivotJointSetAnchorA(cpConstraint * x0, cpVect x1)
{
  cpPivotJointSetAnchorA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointSetAnchorA(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPivotJointSetAnchorA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPivotJointSetAnchorA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPivotJointSetAnchorA(cpConstraint * x0, cpVect *x1)
{
  { cpPivotJointSetAnchorA(x0, *x1); }
}
#endif

static void _cffi_d_cpPivotJointSetAnchorB(cpConstraint * x0, cpVect x1)
{
  cpPivotJointSetAnchorB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPivotJointSetAnchorB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPivotJointSetAnchorB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPivotJointSetAnchorB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPivotJointSetAnchorB(cpConstraint * x0, cpVect *x1)
{
  { cpPivotJointSetAnchorB(x0, *x1); }
}
#endif

static cpPolyShape * _cffi_d_cpPolyShapeAlloc(void)
{
  return cpPolyShapeAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeAlloc(PyObject *self, PyObject *noarg)
{
  cpPolyShape * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  return pyresult;
}
#else
#  define _cffi_f_cpPolyShapeAlloc _cffi_d_cpPolyShapeAlloc
#endif

static int _cffi_d_cpPolyShapeGetCount(cpShape const * x0)
{
  return cpPolyShapeGetCount(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeGetCount(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeGetCount(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolyShapeGetCount _cffi_d_cpPolyShapeGetCount
#endif

static double _cffi_d_cpPolyShapeGetRadius(cpShape const * x0)
{
  return cpPolyShapeGetRadius(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeGetRadius(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeGetRadius(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolyShapeGetRadius _cffi_d_cpPolyShapeGetRadius
#endif

static cpVect _cffi_d_cpPolyShapeGetVert(cpShape const * x0, int x1)
{
  return cpPolyShapeGetVert(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeGetVert(PyObject *self, PyObject *args)
{
  cpShape const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeGetVert", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeGetVert(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpPolyShapeGetVert(cpVect *result, cpShape const * x0, int x1)
{
  { *result = cpPolyShapeGetVert(x0, x1); }
}
#endif

static cpPolyShape * _cffi_d_cpPolyShapeInit(cpPolyShape * x0, cpBody * x1, int x2, cpVect const * x3, cpTransform x4, double x5)
{
  return cpPolyShapeInit(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeInit(PyObject *self, PyObject *args)
{
  cpPolyShape * x0;
  cpBody * x1;
  int x2;
  cpVect const * x3;
  cpTransform x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeInit", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x4, _cffi_type(13), arg4) < 0)
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeInit(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpPolyShape * _cffi_f_cpPolyShapeInit(cpPolyShape * x0, cpBody * x1, int x2, cpVect const * x3, cpTransform *x4, double x5)
{
  cpPolyShape * result;
  { result = cpPolyShapeInit(x0, x1, x2, x3, *x4, x5); }
  return result;
}
#endif

static cpPolyShape * _cffi_d_cpPolyShapeInitRaw(cpPolyShape * x0, cpBody * x1, int x2, cpVect const * x3, double x4)
{
  return cpPolyShapeInitRaw(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeInitRaw(PyObject *self, PyObject *args)
{
  cpPolyShape * x0;
  cpBody * x1;
  int x2;
  cpVect const * x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeInitRaw", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(204), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(204), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeInitRaw(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(204));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolyShapeInitRaw _cffi_d_cpPolyShapeInitRaw
#endif

static cpShape * _cffi_d_cpPolyShapeNew(cpBody * x0, int x1, cpVect const * x2, cpTransform x3, double x4)
{
  return cpPolyShapeNew(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  int x1;
  cpVect const * x2;
  cpTransform x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeNew", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(13), arg3) < 0)
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeNew(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpPolyShapeNew(cpBody * x0, int x1, cpVect const * x2, cpTransform *x3, double x4)
{
  cpShape * result;
  { result = cpPolyShapeNew(x0, x1, x2, *x3, x4); }
  return result;
}
#endif

static cpShape * _cffi_d_cpPolyShapeNewRaw(cpBody * x0, int x1, cpVect const * x2, double x3)
{
  return cpPolyShapeNewRaw(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeNewRaw(PyObject *self, PyObject *args)
{
  cpBody * x0;
  int x1;
  cpVect const * x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeNewRaw", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpVect const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(220), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolyShapeNewRaw(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolyShapeNewRaw _cffi_d_cpPolyShapeNewRaw
#endif

static void _cffi_d_cpPolyShapeSetRadius(cpShape * x0, double x1)
{
  cpPolyShapeSetRadius(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeSetRadius(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeSetRadius", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolyShapeSetRadius(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPolyShapeSetRadius _cffi_d_cpPolyShapeSetRadius
#endif

static void _cffi_d_cpPolyShapeSetVerts(cpShape * x0, int x1, cpVect * x2, cpTransform x3)
{
  cpPolyShapeSetVerts(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeSetVerts(PyObject *self, PyObject *args)
{
  cpShape * x0;
  int x1;
  cpVect * x2;
  cpTransform x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeSetVerts", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(818), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpVect *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(818), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(13), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolyShapeSetVerts(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPolyShapeSetVerts(cpShape * x0, int x1, cpVect * x2, cpTransform *x3)
{
  { cpPolyShapeSetVerts(x0, x1, x2, *x3); }
}
#endif

static void _cffi_d_cpPolyShapeSetVertsRaw(cpShape * x0, int x1, cpVect * x2)
{
  cpPolyShapeSetVertsRaw(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolyShapeSetVertsRaw(PyObject *self, PyObject *args)
{
  cpShape * x0;
  int x1;
  cpVect * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpPolyShapeSetVertsRaw", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(818), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpVect *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(818), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolyShapeSetVertsRaw(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPolyShapeSetVertsRaw _cffi_d_cpPolyShapeSetVertsRaw
#endif

static cpPolylineSet * _cffi_d_cpPolylineConvexDecomposition(cpPolyline * x0, double x1)
{
  return cpPolylineConvexDecomposition(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineConvexDecomposition(PyObject *self, PyObject *args)
{
  cpPolyline * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolylineSet * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineConvexDecomposition", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineConvexDecomposition(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(242));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineConvexDecomposition _cffi_d_cpPolylineConvexDecomposition
#endif

static void _cffi_d_cpPolylineFree(cpPolyline * x0)
{
  cpPolylineFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineFree(PyObject *self, PyObject *arg0)
{
  cpPolyline * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolylineFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPolylineFree _cffi_d_cpPolylineFree
#endif

static unsigned char _cffi_d_cpPolylineIsClosed(cpPolyline * x0)
{
  return cpPolylineIsClosed(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineIsClosed(PyObject *self, PyObject *arg0)
{
  cpPolyline * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineIsClosed(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineIsClosed _cffi_d_cpPolylineIsClosed
#endif

static cpPolylineSet * _cffi_d_cpPolylineSetAlloc(void)
{
  return cpPolylineSetAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetAlloc(PyObject *self, PyObject *noarg)
{
  cpPolylineSet * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineSetAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(242));
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineSetAlloc _cffi_d_cpPolylineSetAlloc
#endif

static void _cffi_d_cpPolylineSetCollectSegment(cpVect x0, cpVect x1, cpPolylineSet * x2)
{
  cpPolylineSetCollectSegment(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetCollectSegment(PyObject *self, PyObject *args)
{
  cpVect x0;
  cpVect x1;
  cpPolylineSet * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpPolylineSetCollectSegment", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(6), arg0) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(242), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpPolylineSet *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(242), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolylineSetCollectSegment(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpPolylineSetCollectSegment(cpVect *x0, cpVect *x1, cpPolylineSet * x2)
{
  { cpPolylineSetCollectSegment(*x0, *x1, x2); }
}
#endif

static void _cffi_d_cpPolylineSetDestroy(cpPolylineSet * x0, unsigned char x1)
{
  cpPolylineSetDestroy(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetDestroy(PyObject *self, PyObject *args)
{
  cpPolylineSet * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineSetDestroy", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(242), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolylineSet *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(242), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolylineSetDestroy(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPolylineSetDestroy _cffi_d_cpPolylineSetDestroy
#endif

static void _cffi_d_cpPolylineSetFree(cpPolylineSet * x0, unsigned char x1)
{
  cpPolylineSetFree(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetFree(PyObject *self, PyObject *args)
{
  cpPolylineSet * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineSetFree", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(242), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolylineSet *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(242), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpPolylineSetFree(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpPolylineSetFree _cffi_d_cpPolylineSetFree
#endif

static cpPolylineSet * _cffi_d_cpPolylineSetInit(cpPolylineSet * x0)
{
  return cpPolylineSetInit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetInit(PyObject *self, PyObject *arg0)
{
  cpPolylineSet * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolylineSet * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(242), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolylineSet *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(242), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineSetInit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(242));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineSetInit _cffi_d_cpPolylineSetInit
#endif

static cpPolylineSet * _cffi_d_cpPolylineSetNew(void)
{
  return cpPolylineSetNew();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSetNew(PyObject *self, PyObject *noarg)
{
  cpPolylineSet * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineSetNew(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(242));
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineSetNew _cffi_d_cpPolylineSetNew
#endif

static cpPolyline * _cffi_d_cpPolylineSimplifyCurves(cpPolyline * x0, double x1)
{
  return cpPolylineSimplifyCurves(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSimplifyCurves(PyObject *self, PyObject *args)
{
  cpPolyline * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyline * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineSimplifyCurves", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineSimplifyCurves(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(234));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineSimplifyCurves _cffi_d_cpPolylineSimplifyCurves
#endif

static cpPolyline * _cffi_d_cpPolylineSimplifyVertexes(cpPolyline * x0, double x1)
{
  return cpPolylineSimplifyVertexes(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineSimplifyVertexes(PyObject *self, PyObject *args)
{
  cpPolyline * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyline * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineSimplifyVertexes", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineSimplifyVertexes(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(234));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineSimplifyVertexes _cffi_d_cpPolylineSimplifyVertexes
#endif

static cpPolyline * _cffi_d_cpPolylineToConvexHull(cpPolyline * x0, double x1)
{
  return cpPolylineToConvexHull(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpPolylineToConvexHull(PyObject *self, PyObject *args)
{
  cpPolyline * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpPolyline * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpPolylineToConvexHull", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(234), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpPolyline *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(234), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpPolylineToConvexHull(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(234));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpPolylineToConvexHull _cffi_d_cpPolylineToConvexHull
#endif

static cpRatchetJoint * _cffi_d_cpRatchetJointAlloc(void)
{
  return cpRatchetJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointAlloc(PyObject *self, PyObject *noarg)
{
  cpRatchetJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(247));
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointAlloc _cffi_d_cpRatchetJointAlloc
#endif

static double _cffi_d_cpRatchetJointGetAngle(cpConstraint const * x0)
{
  return cpRatchetJointGetAngle(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointGetAngle(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointGetAngle(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointGetAngle _cffi_d_cpRatchetJointGetAngle
#endif

static double _cffi_d_cpRatchetJointGetPhase(cpConstraint const * x0)
{
  return cpRatchetJointGetPhase(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointGetPhase(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointGetPhase(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointGetPhase _cffi_d_cpRatchetJointGetPhase
#endif

static double _cffi_d_cpRatchetJointGetRatchet(cpConstraint const * x0)
{
  return cpRatchetJointGetRatchet(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointGetRatchet(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointGetRatchet(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointGetRatchet _cffi_d_cpRatchetJointGetRatchet
#endif

static cpRatchetJoint * _cffi_d_cpRatchetJointInit(cpRatchetJoint * x0, cpBody * x1, cpBody * x2, double x3, double x4)
{
  return cpRatchetJointInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointInit(PyObject *self, PyObject *args)
{
  cpRatchetJoint * x0;
  cpBody * x1;
  cpBody * x2;
  double x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpRatchetJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpRatchetJointInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(247), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpRatchetJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(247), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(247));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointInit _cffi_d_cpRatchetJointInit
#endif

static cpConstraint * _cffi_d_cpRatchetJointNew(cpBody * x0, cpBody * x1, double x2, double x3)
{
  return cpRatchetJointNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  double x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpRatchetJointNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRatchetJointNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRatchetJointNew _cffi_d_cpRatchetJointNew
#endif

static void _cffi_d_cpRatchetJointSetAngle(cpConstraint * x0, double x1)
{
  cpRatchetJointSetAngle(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointSetAngle(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpRatchetJointSetAngle", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpRatchetJointSetAngle(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpRatchetJointSetAngle _cffi_d_cpRatchetJointSetAngle
#endif

static void _cffi_d_cpRatchetJointSetPhase(cpConstraint * x0, double x1)
{
  cpRatchetJointSetPhase(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointSetPhase(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpRatchetJointSetPhase", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpRatchetJointSetPhase(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpRatchetJointSetPhase _cffi_d_cpRatchetJointSetPhase
#endif

static void _cffi_d_cpRatchetJointSetRatchet(cpConstraint * x0, double x1)
{
  cpRatchetJointSetRatchet(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRatchetJointSetRatchet(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpRatchetJointSetRatchet", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpRatchetJointSetRatchet(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpRatchetJointSetRatchet _cffi_d_cpRatchetJointSetRatchet
#endif

static cpRotaryLimitJoint * _cffi_d_cpRotaryLimitJointAlloc(void)
{
  return cpRotaryLimitJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointAlloc(PyObject *self, PyObject *noarg)
{
  cpRotaryLimitJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRotaryLimitJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(256));
  return pyresult;
}
#else
#  define _cffi_f_cpRotaryLimitJointAlloc _cffi_d_cpRotaryLimitJointAlloc
#endif

static double _cffi_d_cpRotaryLimitJointGetMax(cpConstraint const * x0)
{
  return cpRotaryLimitJointGetMax(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointGetMax(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRotaryLimitJointGetMax(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRotaryLimitJointGetMax _cffi_d_cpRotaryLimitJointGetMax
#endif

static double _cffi_d_cpRotaryLimitJointGetMin(cpConstraint const * x0)
{
  return cpRotaryLimitJointGetMin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointGetMin(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRotaryLimitJointGetMin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRotaryLimitJointGetMin _cffi_d_cpRotaryLimitJointGetMin
#endif

static cpRotaryLimitJoint * _cffi_d_cpRotaryLimitJointInit(cpRotaryLimitJoint * x0, cpBody * x1, cpBody * x2, double x3, double x4)
{
  return cpRotaryLimitJointInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointInit(PyObject *self, PyObject *args)
{
  cpRotaryLimitJoint * x0;
  cpBody * x1;
  cpBody * x2;
  double x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpRotaryLimitJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpRotaryLimitJointInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(256), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpRotaryLimitJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(256), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRotaryLimitJointInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(256));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRotaryLimitJointInit _cffi_d_cpRotaryLimitJointInit
#endif

static cpConstraint * _cffi_d_cpRotaryLimitJointNew(cpBody * x0, cpBody * x1, double x2, double x3)
{
  return cpRotaryLimitJointNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  double x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpRotaryLimitJointNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpRotaryLimitJointNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpRotaryLimitJointNew _cffi_d_cpRotaryLimitJointNew
#endif

static void _cffi_d_cpRotaryLimitJointSetMax(cpConstraint * x0, double x1)
{
  cpRotaryLimitJointSetMax(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointSetMax(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpRotaryLimitJointSetMax", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpRotaryLimitJointSetMax(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpRotaryLimitJointSetMax _cffi_d_cpRotaryLimitJointSetMax
#endif

static void _cffi_d_cpRotaryLimitJointSetMin(cpConstraint * x0, double x1)
{
  cpRotaryLimitJointSetMin(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpRotaryLimitJointSetMin(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpRotaryLimitJointSetMin", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpRotaryLimitJointSetMin(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpRotaryLimitJointSetMin _cffi_d_cpRotaryLimitJointSetMin
#endif

static cpSegmentShape * _cffi_d_cpSegmentShapeAlloc(void)
{
  return cpSegmentShapeAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeAlloc(PyObject *self, PyObject *noarg)
{
  cpSegmentShape * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(265));
  return pyresult;
}
#else
#  define _cffi_f_cpSegmentShapeAlloc _cffi_d_cpSegmentShapeAlloc
#endif

static cpVect _cffi_d_cpSegmentShapeGetA(cpShape const * x0)
{
  return cpSegmentShapeGetA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeGetA(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeGetA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSegmentShapeGetA(cpVect *result, cpShape const * x0)
{
  { *result = cpSegmentShapeGetA(x0); }
}
#endif

static cpVect _cffi_d_cpSegmentShapeGetB(cpShape const * x0)
{
  return cpSegmentShapeGetB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeGetB(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeGetB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSegmentShapeGetB(cpVect *result, cpShape const * x0)
{
  { *result = cpSegmentShapeGetB(x0); }
}
#endif

static cpVect _cffi_d_cpSegmentShapeGetNormal(cpShape const * x0)
{
  return cpSegmentShapeGetNormal(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeGetNormal(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeGetNormal(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSegmentShapeGetNormal(cpVect *result, cpShape const * x0)
{
  { *result = cpSegmentShapeGetNormal(x0); }
}
#endif

static double _cffi_d_cpSegmentShapeGetRadius(cpShape const * x0)
{
  return cpSegmentShapeGetRadius(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeGetRadius(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeGetRadius(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSegmentShapeGetRadius _cffi_d_cpSegmentShapeGetRadius
#endif

static cpSegmentShape * _cffi_d_cpSegmentShapeInit(cpSegmentShape * x0, cpBody * x1, cpVect x2, cpVect x3, double x4)
{
  return cpSegmentShapeInit(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeInit(PyObject *self, PyObject *args)
{
  cpSegmentShape * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  double x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSegmentShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpSegmentShapeInit", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(265), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSegmentShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(265), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeInit(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(265));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpSegmentShape * _cffi_f_cpSegmentShapeInit(cpSegmentShape * x0, cpBody * x1, cpVect *x2, cpVect *x3, double x4)
{
  cpSegmentShape * result;
  { result = cpSegmentShapeInit(x0, x1, *x2, *x3, x4); }
  return result;
}
#endif

static cpShape * _cffi_d_cpSegmentShapeNew(cpBody * x0, cpVect x1, cpVect x2, double x3)
{
  return cpSegmentShapeNew(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpVect x1;
  cpVect x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpSegmentShapeNew", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSegmentShapeNew(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpSegmentShapeNew(cpBody * x0, cpVect *x1, cpVect *x2, double x3)
{
  cpShape * result;
  { result = cpSegmentShapeNew(x0, *x1, *x2, x3); }
  return result;
}
#endif

static void _cffi_d_cpSegmentShapeSetEndpoints(cpShape * x0, cpVect x1, cpVect x2)
{
  cpSegmentShapeSetEndpoints(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeSetEndpoints(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSegmentShapeSetEndpoints", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSegmentShapeSetEndpoints(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSegmentShapeSetEndpoints(cpShape * x0, cpVect *x1, cpVect *x2)
{
  { cpSegmentShapeSetEndpoints(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpSegmentShapeSetNeighbors(cpShape * x0, cpVect x1, cpVect x2)
{
  cpSegmentShapeSetNeighbors(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeSetNeighbors(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpVect x1;
  cpVect x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSegmentShapeSetNeighbors", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSegmentShapeSetNeighbors(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSegmentShapeSetNeighbors(cpShape * x0, cpVect *x1, cpVect *x2)
{
  { cpSegmentShapeSetNeighbors(x0, *x1, *x2); }
}
#endif

static void _cffi_d_cpSegmentShapeSetRadius(cpShape * x0, double x1)
{
  cpSegmentShapeSetRadius(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSegmentShapeSetRadius(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSegmentShapeSetRadius", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSegmentShapeSetRadius(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSegmentShapeSetRadius _cffi_d_cpSegmentShapeSetRadius
#endif

static cpBB _cffi_d_cpShapeCacheBB(cpShape * x0)
{
  return cpShapeCacheBB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeCacheBB(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBB result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeCacheBB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeCacheBB(cpBB *result, cpShape * x0)
{
  { *result = cpShapeCacheBB(x0); }
}
#endif

static void _cffi_d_cpShapeDestroy(cpShape * x0)
{
  cpShapeDestroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeDestroy(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeDestroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeDestroy _cffi_d_cpShapeDestroy
#endif

static void _cffi_d_cpShapeFree(cpShape * x0)
{
  cpShapeFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeFree(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeFree _cffi_d_cpShapeFree
#endif

static double _cffi_d_cpShapeGetArea(cpShape * x0)
{
  return cpShapeGetArea(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetArea(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetArea(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetArea _cffi_d_cpShapeGetArea
#endif

static cpBB _cffi_d_cpShapeGetBB(cpShape const * x0)
{
  return cpShapeGetBB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetBB(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBB result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetBB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeGetBB(cpBB *result, cpShape const * x0)
{
  { *result = cpShapeGetBB(x0); }
}
#endif

static cpBody * _cffi_d_cpShapeGetBody(cpShape const * x0)
{
  return cpShapeGetBody(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetBody(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetBody(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetBody _cffi_d_cpShapeGetBody
#endif

static cpVect _cffi_d_cpShapeGetCenterOfGravity(cpShape * x0)
{
  return cpShapeGetCenterOfGravity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetCenterOfGravity(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetCenterOfGravity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeGetCenterOfGravity(cpVect *result, cpShape * x0)
{
  { *result = cpShapeGetCenterOfGravity(x0); }
}
#endif

static uintptr_t _cffi_d_cpShapeGetCollisionType(cpShape const * x0)
{
  return cpShapeGetCollisionType(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetCollisionType(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uintptr_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetCollisionType(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uintptr_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetCollisionType _cffi_d_cpShapeGetCollisionType
#endif

static double _cffi_d_cpShapeGetDensity(cpShape * x0)
{
  return cpShapeGetDensity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetDensity(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetDensity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetDensity _cffi_d_cpShapeGetDensity
#endif

static double _cffi_d_cpShapeGetElasticity(cpShape const * x0)
{
  return cpShapeGetElasticity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetElasticity(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetElasticity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetElasticity _cffi_d_cpShapeGetElasticity
#endif

static cpShapeFilter _cffi_d_cpShapeGetFilter(cpShape const * x0)
{
  return cpShapeGetFilter(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetFilter(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShapeFilter result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetFilter(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(317));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeGetFilter(cpShapeFilter *result, cpShape const * x0)
{
  { *result = cpShapeGetFilter(x0); }
}
#endif

static double _cffi_d_cpShapeGetFriction(cpShape const * x0)
{
  return cpShapeGetFriction(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetFriction(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetFriction(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetFriction _cffi_d_cpShapeGetFriction
#endif

static double _cffi_d_cpShapeGetMass(cpShape * x0)
{
  return cpShapeGetMass(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetMass(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetMass(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetMass _cffi_d_cpShapeGetMass
#endif

static double _cffi_d_cpShapeGetMoment(cpShape * x0)
{
  return cpShapeGetMoment(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetMoment(PyObject *self, PyObject *arg0)
{
  cpShape * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetMoment(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetMoment _cffi_d_cpShapeGetMoment
#endif

static unsigned char _cffi_d_cpShapeGetSensor(cpShape const * x0)
{
  return cpShapeGetSensor(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetSensor(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetSensor(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetSensor _cffi_d_cpShapeGetSensor
#endif

static cpSpace * _cffi_d_cpShapeGetSpace(cpShape const * x0)
{
  return cpShapeGetSpace(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetSpace(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSpace * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetSpace(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetSpace _cffi_d_cpShapeGetSpace
#endif

static cpVect _cffi_d_cpShapeGetSurfaceVelocity(cpShape const * x0)
{
  return cpShapeGetSurfaceVelocity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetSurfaceVelocity(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetSurfaceVelocity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeGetSurfaceVelocity(cpVect *result, cpShape const * x0)
{
  { *result = cpShapeGetSurfaceVelocity(x0); }
}
#endif

static void * _cffi_d_cpShapeGetUserData(cpShape const * x0)
{
  return cpShapeGetUserData(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeGetUserData(PyObject *self, PyObject *arg0)
{
  cpShape const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeGetUserData(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(365));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpShapeGetUserData _cffi_d_cpShapeGetUserData
#endif

static double _cffi_d_cpShapePointQuery(cpShape const * x0, cpVect x1, cpPointQueryInfo * x2)
{
  return cpShapePointQuery(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapePointQuery(PyObject *self, PyObject *args)
{
  cpShape const * x0;
  cpVect x1;
  cpPointQueryInfo * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpShapePointQuery", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(325), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpPointQueryInfo *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(325), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapePointQuery(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static double _cffi_f_cpShapePointQuery(cpShape const * x0, cpVect *x1, cpPointQueryInfo * x2)
{
  double result;
  { result = cpShapePointQuery(x0, *x1, x2); }
  return result;
}
#endif

static unsigned char _cffi_d_cpShapeSegmentQuery(cpShape const * x0, cpVect x1, cpVect x2, double x3, cpSegmentQueryInfo * x4)
{
  return cpShapeSegmentQuery(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSegmentQuery(PyObject *self, PyObject *args)
{
  cpShape const * x0;
  cpVect x1;
  cpVect x2;
  double x3;
  cpSegmentQueryInfo * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpShapeSegmentQuery", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(318), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (cpSegmentQueryInfo *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(318), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeSegmentQuery(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static unsigned char _cffi_f_cpShapeSegmentQuery(cpShape const * x0, cpVect *x1, cpVect *x2, double x3, cpSegmentQueryInfo * x4)
{
  unsigned char result;
  { result = cpShapeSegmentQuery(x0, *x1, *x2, x3, x4); }
  return result;
}
#endif

static void _cffi_d_cpShapeSetBody(cpShape * x0, cpBody * x1)
{
  cpShapeSetBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetBody(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetBody _cffi_d_cpShapeSetBody
#endif

static void _cffi_d_cpShapeSetCollisionType(cpShape * x0, uintptr_t x1)
{
  cpShapeSetCollisionType(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetCollisionType(PyObject *self, PyObject *args)
{
  cpShape * x0;
  uintptr_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetCollisionType", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uintptr_t);
  if (x1 == (uintptr_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetCollisionType(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetCollisionType _cffi_d_cpShapeSetCollisionType
#endif

static void _cffi_d_cpShapeSetDensity(cpShape * x0, double x1)
{
  cpShapeSetDensity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetDensity(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetDensity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetDensity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetDensity _cffi_d_cpShapeSetDensity
#endif

static void _cffi_d_cpShapeSetElasticity(cpShape * x0, double x1)
{
  cpShapeSetElasticity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetElasticity(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetElasticity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetElasticity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetElasticity _cffi_d_cpShapeSetElasticity
#endif

static void _cffi_d_cpShapeSetFilter(cpShape * x0, cpShapeFilter x1)
{
  cpShapeSetFilter(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetFilter(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpShapeFilter x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetFilter", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(317), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetFilter(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpShapeSetFilter(cpShape * x0, cpShapeFilter *x1)
{
  { cpShapeSetFilter(x0, *x1); }
}
#endif

static void _cffi_d_cpShapeSetFriction(cpShape * x0, double x1)
{
  cpShapeSetFriction(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetFriction(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetFriction", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetFriction(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetFriction _cffi_d_cpShapeSetFriction
#endif

static void _cffi_d_cpShapeSetMass(cpShape * x0, double x1)
{
  cpShapeSetMass(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetMass(PyObject *self, PyObject *args)
{
  cpShape * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetMass", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetMass(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetMass _cffi_d_cpShapeSetMass
#endif

static void _cffi_d_cpShapeSetSensor(cpShape * x0, unsigned char x1)
{
  cpShapeSetSensor(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetSensor(PyObject *self, PyObject *args)
{
  cpShape * x0;
  unsigned char x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetSensor", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetSensor(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetSensor _cffi_d_cpShapeSetSensor
#endif

static void _cffi_d_cpShapeSetSurfaceVelocity(cpShape * x0, cpVect x1)
{
  cpShapeSetSurfaceVelocity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetSurfaceVelocity(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetSurfaceVelocity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetSurfaceVelocity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpShapeSetSurfaceVelocity(cpShape * x0, cpVect *x1)
{
  { cpShapeSetSurfaceVelocity(x0, *x1); }
}
#endif

static void _cffi_d_cpShapeSetUserData(cpShape * x0, void * x1)
{
  cpShapeSetUserData(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeSetUserData(PyObject *self, PyObject *args)
{
  cpShape * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeSetUserData", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpShapeSetUserData(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpShapeSetUserData _cffi_d_cpShapeSetUserData
#endif

static cpBB _cffi_d_cpShapeUpdate(cpShape * x0, cpTransform x1)
{
  return cpShapeUpdate(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapeUpdate(PyObject *self, PyObject *args)
{
  cpShape * x0;
  cpTransform x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBB result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapeUpdate", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(13), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapeUpdate(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(1));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapeUpdate(cpBB *result, cpShape * x0, cpTransform *x1)
{
  { *result = cpShapeUpdate(x0, *x1); }
}
#endif

static cpContactPointSet _cffi_d_cpShapesCollide(cpShape const * x0, cpShape const * x1)
{
  return cpShapesCollide(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpShapesCollide(PyObject *self, PyObject *args)
{
  cpShape const * x0;
  cpShape const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpContactPointSet result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpShapesCollide", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpShapesCollide(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(992));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpShapesCollide(cpContactPointSet *result, cpShape const * x0, cpShape const * x1)
{
  { *result = cpShapesCollide(x0, x1); }
}
#endif

static cpSimpleMotor * _cffi_d_cpSimpleMotorAlloc(void)
{
  return cpSimpleMotorAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSimpleMotorAlloc(PyObject *self, PyObject *noarg)
{
  cpSimpleMotor * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSimpleMotorAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(331));
  return pyresult;
}
#else
#  define _cffi_f_cpSimpleMotorAlloc _cffi_d_cpSimpleMotorAlloc
#endif

static double _cffi_d_cpSimpleMotorGetRate(cpConstraint const * x0)
{
  return cpSimpleMotorGetRate(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSimpleMotorGetRate(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSimpleMotorGetRate(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSimpleMotorGetRate _cffi_d_cpSimpleMotorGetRate
#endif

static cpSimpleMotor * _cffi_d_cpSimpleMotorInit(cpSimpleMotor * x0, cpBody * x1, cpBody * x2, double x3)
{
  return cpSimpleMotorInit(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSimpleMotorInit(PyObject *self, PyObject *args)
{
  cpSimpleMotor * x0;
  cpBody * x1;
  cpBody * x2;
  double x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSimpleMotor * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpSimpleMotorInit", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(331), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSimpleMotor *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(331), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSimpleMotorInit(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(331));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSimpleMotorInit _cffi_d_cpSimpleMotorInit
#endif

static cpConstraint * _cffi_d_cpSimpleMotorNew(cpBody * x0, cpBody * x1, double x2)
{
  return cpSimpleMotorNew(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSimpleMotorNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  double x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSimpleMotorNew", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSimpleMotorNew(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSimpleMotorNew _cffi_d_cpSimpleMotorNew
#endif

static void _cffi_d_cpSimpleMotorSetRate(cpConstraint * x0, double x1)
{
  cpSimpleMotorSetRate(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSimpleMotorSetRate(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSimpleMotorSetRate", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSimpleMotorSetRate(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSimpleMotorSetRate _cffi_d_cpSimpleMotorSetRate
#endif

static cpSlideJoint * _cffi_d_cpSlideJointAlloc(void)
{
  return cpSlideJointAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointAlloc(PyObject *self, PyObject *noarg)
{
  cpSlideJoint * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(339));
  return pyresult;
}
#else
#  define _cffi_f_cpSlideJointAlloc _cffi_d_cpSlideJointAlloc
#endif

static cpVect _cffi_d_cpSlideJointGetAnchorA(cpConstraint const * x0)
{
  return cpSlideJointGetAnchorA(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointGetAnchorA(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointGetAnchorA(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSlideJointGetAnchorA(cpVect *result, cpConstraint const * x0)
{
  { *result = cpSlideJointGetAnchorA(x0); }
}
#endif

static cpVect _cffi_d_cpSlideJointGetAnchorB(cpConstraint const * x0)
{
  return cpSlideJointGetAnchorB(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointGetAnchorB(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointGetAnchorB(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSlideJointGetAnchorB(cpVect *result, cpConstraint const * x0)
{
  { *result = cpSlideJointGetAnchorB(x0); }
}
#endif

static double _cffi_d_cpSlideJointGetMax(cpConstraint const * x0)
{
  return cpSlideJointGetMax(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointGetMax(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointGetMax(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSlideJointGetMax _cffi_d_cpSlideJointGetMax
#endif

static double _cffi_d_cpSlideJointGetMin(cpConstraint const * x0)
{
  return cpSlideJointGetMin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointGetMin(PyObject *self, PyObject *arg0)
{
  cpConstraint const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointGetMin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSlideJointGetMin _cffi_d_cpSlideJointGetMin
#endif

static cpSlideJoint * _cffi_d_cpSlideJointInit(cpSlideJoint * x0, cpBody * x1, cpBody * x2, cpVect x3, cpVect x4, double x5, double x6)
{
  return cpSlideJointInit(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointInit(PyObject *self, PyObject *args)
{
  cpSlideJoint * x0;
  cpBody * x1;
  cpBody * x2;
  cpVect x3;
  cpVect x4;
  double x5;
  double x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSlideJoint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "cpSlideJointInit", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(339), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSlideJoint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(339), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(6), arg4) < 0)
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  x6 = (double)_cffi_to_c_double(arg6);
  if (x6 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointInit(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(339));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpSlideJoint * _cffi_f_cpSlideJointInit(cpSlideJoint * x0, cpBody * x1, cpBody * x2, cpVect *x3, cpVect *x4, double x5, double x6)
{
  cpSlideJoint * result;
  { result = cpSlideJointInit(x0, x1, x2, *x3, *x4, x5, x6); }
  return result;
}
#endif

static cpConstraint * _cffi_d_cpSlideJointNew(cpBody * x0, cpBody * x1, cpVect x2, cpVect x3, double x4, double x5)
{
  return cpSlideJointNew(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointNew(PyObject *self, PyObject *args)
{
  cpBody * x0;
  cpBody * x1;
  cpVect x2;
  cpVect x3;
  double x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpSlideJointNew", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(6), arg3) < 0)
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSlideJointNew(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpConstraint * _cffi_f_cpSlideJointNew(cpBody * x0, cpBody * x1, cpVect *x2, cpVect *x3, double x4, double x5)
{
  cpConstraint * result;
  { result = cpSlideJointNew(x0, x1, *x2, *x3, x4, x5); }
  return result;
}
#endif

static void _cffi_d_cpSlideJointSetAnchorA(cpConstraint * x0, cpVect x1)
{
  cpSlideJointSetAnchorA(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointSetAnchorA(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSlideJointSetAnchorA", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSlideJointSetAnchorA(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSlideJointSetAnchorA(cpConstraint * x0, cpVect *x1)
{
  { cpSlideJointSetAnchorA(x0, *x1); }
}
#endif

static void _cffi_d_cpSlideJointSetAnchorB(cpConstraint * x0, cpVect x1)
{
  cpSlideJointSetAnchorB(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointSetAnchorB(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSlideJointSetAnchorB", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSlideJointSetAnchorB(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSlideJointSetAnchorB(cpConstraint * x0, cpVect *x1)
{
  { cpSlideJointSetAnchorB(x0, *x1); }
}
#endif

static void _cffi_d_cpSlideJointSetMax(cpConstraint * x0, double x1)
{
  cpSlideJointSetMax(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointSetMax(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSlideJointSetMax", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSlideJointSetMax(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSlideJointSetMax _cffi_d_cpSlideJointSetMax
#endif

static void _cffi_d_cpSlideJointSetMin(cpConstraint * x0, double x1)
{
  cpSlideJointSetMin(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSlideJointSetMin(PyObject *self, PyObject *args)
{
  cpConstraint * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSlideJointSetMin", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSlideJointSetMin(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSlideJointSetMin _cffi_d_cpSlideJointSetMin
#endif

static cpBody * _cffi_d_cpSpaceAddBody(cpSpace * x0, cpBody * x1)
{
  return cpSpaceAddBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddBody _cffi_d_cpSpaceAddBody
#endif

static cpCollisionHandler * _cffi_d_cpSpaceAddCollisionHandler(cpSpace * x0, uintptr_t x1, uintptr_t x2)
{
  return cpSpaceAddCollisionHandler(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddCollisionHandler(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  uintptr_t x1;
  uintptr_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpCollisionHandler * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddCollisionHandler", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uintptr_t);
  if (x1 == (uintptr_t)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, uintptr_t);
  if (x2 == (uintptr_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddCollisionHandler(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(989));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddCollisionHandler _cffi_d_cpSpaceAddCollisionHandler
#endif

static cpConstraint * _cffi_d_cpSpaceAddConstraint(cpSpace * x0, cpConstraint * x1)
{
  return cpSpaceAddConstraint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddConstraint(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpConstraint * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpConstraint * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddConstraint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddConstraint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(135));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddConstraint _cffi_d_cpSpaceAddConstraint
#endif

static cpCollisionHandler * _cffi_d_cpSpaceAddDefaultCollisionHandler(cpSpace * x0)
{
  return cpSpaceAddDefaultCollisionHandler(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddDefaultCollisionHandler(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpCollisionHandler * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddDefaultCollisionHandler(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(989));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddDefaultCollisionHandler _cffi_d_cpSpaceAddDefaultCollisionHandler
#endif

static unsigned char _cffi_d_cpSpaceAddPostStepCallback(cpSpace * x0, void(* x1)(cpSpace *, void *, void *), void * x2, void * x3)
{
  return cpSpaceAddPostStepCallback(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddPostStepCallback(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  void(* x1)(cpSpace *, void *, void *);
  void * x2;
  void * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddPostStepCallback", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpSpace *, void *, void *))_cffi_to_c_pointer(arg1, _cffi_type(588));
  if (x1 == (void(*)(cpSpace *, void *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddPostStepCallback(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddPostStepCallback _cffi_d_cpSpaceAddPostStepCallback
#endif

static cpShape * _cffi_d_cpSpaceAddShape(cpSpace * x0, cpShape * x1)
{
  return cpSpaceAddShape(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddShape(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpShape * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddShape", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddShape(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddShape _cffi_d_cpSpaceAddShape
#endif

static cpCollisionHandler * _cffi_d_cpSpaceAddWildcardHandler(cpSpace * x0, uintptr_t x1)
{
  return cpSpaceAddWildcardHandler(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAddWildcardHandler(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  uintptr_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpCollisionHandler * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceAddWildcardHandler", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uintptr_t);
  if (x1 == (uintptr_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAddWildcardHandler(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(989));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAddWildcardHandler _cffi_d_cpSpaceAddWildcardHandler
#endif

static cpSpace * _cffi_d_cpSpaceAlloc(void)
{
  return cpSpaceAlloc();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceAlloc(PyObject *self, PyObject *noarg)
{
  cpSpace * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceAlloc(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceAlloc _cffi_d_cpSpaceAlloc
#endif

static void _cffi_d_cpSpaceBBQuery(cpSpace * x0, cpBB x1, cpShapeFilter x2, void(* x3)(cpShape *, void *), void * x4)
{
  cpSpaceBBQuery(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceBBQuery(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBB x1;
  cpShapeFilter x2;
  void(* x3)(cpShape *, void *);
  void * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpSpaceBBQuery", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(1), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(317), arg2) < 0)
    return NULL;

  x3 = (void(*)(cpShape *, void *))_cffi_to_c_pointer(arg3, _cffi_type(845));
  if (x3 == (void(*)(cpShape *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceBBQuery(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSpaceBBQuery(cpSpace * x0, cpBB *x1, cpShapeFilter *x2, void(* x3)(cpShape *, void *), void * x4)
{
  { cpSpaceBBQuery(x0, *x1, *x2, x3, x4); }
}
#endif

static unsigned char _cffi_d_cpSpaceContainsBody(cpSpace * x0, cpBody * x1)
{
  return cpSpaceContainsBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceContainsBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceContainsBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceContainsBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceContainsBody _cffi_d_cpSpaceContainsBody
#endif

static unsigned char _cffi_d_cpSpaceContainsConstraint(cpSpace * x0, cpConstraint * x1)
{
  return cpSpaceContainsConstraint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceContainsConstraint(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpConstraint * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceContainsConstraint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceContainsConstraint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceContainsConstraint _cffi_d_cpSpaceContainsConstraint
#endif

static unsigned char _cffi_d_cpSpaceContainsShape(cpSpace * x0, cpShape * x1)
{
  return cpSpaceContainsShape(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceContainsShape(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpShape * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceContainsShape", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceContainsShape(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceContainsShape _cffi_d_cpSpaceContainsShape
#endif

static void _cffi_d_cpSpaceDebugDraw(cpSpace * x0, cpSpaceDebugDrawOptions * x1)
{
  cpSpaceDebugDraw(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceDebugDraw(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpSpaceDebugDrawOptions * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceDebugDraw", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(862), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpSpaceDebugDrawOptions *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(862), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceDebugDraw(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceDebugDraw _cffi_d_cpSpaceDebugDraw
#endif

static void _cffi_d_cpSpaceDestroy(cpSpace * x0)
{
  cpSpaceDestroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceDestroy(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceDestroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceDestroy _cffi_d_cpSpaceDestroy
#endif

static void _cffi_d_cpSpaceEachBody(cpSpace * x0, void(* x1)(cpBody *, void *), void * x2)
{
  cpSpaceEachBody(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceEachBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  void(* x1)(cpBody *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSpaceEachBody", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpBody *, void *))_cffi_to_c_pointer(arg1, _cffi_type(921));
  if (x1 == (void(*)(cpBody *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceEachBody(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceEachBody _cffi_d_cpSpaceEachBody
#endif

static void _cffi_d_cpSpaceEachConstraint(cpSpace * x0, void(* x1)(cpConstraint *, void *), void * x2)
{
  cpSpaceEachConstraint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceEachConstraint(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  void(* x1)(cpConstraint *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSpaceEachConstraint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpConstraint *, void *))_cffi_to_c_pointer(arg1, _cffi_type(926));
  if (x1 == (void(*)(cpConstraint *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceEachConstraint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceEachConstraint _cffi_d_cpSpaceEachConstraint
#endif

static void _cffi_d_cpSpaceEachShape(cpSpace * x0, void(* x1)(cpShape *, void *), void * x2)
{
  cpSpaceEachShape(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceEachShape(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  void(* x1)(cpShape *, void *);
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSpaceEachShape", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(cpShape *, void *))_cffi_to_c_pointer(arg1, _cffi_type(845));
  if (x1 == (void(*)(cpShape *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceEachShape(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceEachShape _cffi_d_cpSpaceEachShape
#endif

static void _cffi_d_cpSpaceFree(cpSpace * x0)
{
  cpSpaceFree(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceFree(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceFree(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceFree _cffi_d_cpSpaceFree
#endif

static void _cffi_d_cpSpaceGetBodyPositions(cpSpace * x0, cpVectArr * x1)
{
  cpSpaceGetBodyPositions(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetBodyPositions(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVectArr * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceGetBodyPositions", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(887), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpVectArr *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(887), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceGetBodyPositions(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceGetBodyPositions _cffi_d_cpSpaceGetBodyPositions
#endif

static double _cffi_d_cpSpaceGetCollisionBias(cpSpace const * x0)
{
  return cpSpaceGetCollisionBias(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetCollisionBias(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetCollisionBias(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetCollisionBias _cffi_d_cpSpaceGetCollisionBias
#endif

static unsigned int _cffi_d_cpSpaceGetCollisionPersistence(cpSpace const * x0)
{
  return cpSpaceGetCollisionPersistence(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetCollisionPersistence(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetCollisionPersistence(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetCollisionPersistence _cffi_d_cpSpaceGetCollisionPersistence
#endif

static double _cffi_d_cpSpaceGetCollisionSlop(cpSpace const * x0)
{
  return cpSpaceGetCollisionSlop(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetCollisionSlop(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetCollisionSlop(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetCollisionSlop _cffi_d_cpSpaceGetCollisionSlop
#endif

static double _cffi_d_cpSpaceGetCurrentTimeStep(cpSpace const * x0)
{
  return cpSpaceGetCurrentTimeStep(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetCurrentTimeStep(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetCurrentTimeStep(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetCurrentTimeStep _cffi_d_cpSpaceGetCurrentTimeStep
#endif

static double _cffi_d_cpSpaceGetDamping(cpSpace const * x0)
{
  return cpSpaceGetDamping(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetDamping(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetDamping(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetDamping _cffi_d_cpSpaceGetDamping
#endif

static cpVect _cffi_d_cpSpaceGetGravity(cpSpace const * x0)
{
  return cpSpaceGetGravity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetGravity(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpVect result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetGravity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(6));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpSpaceGetGravity(cpVect *result, cpSpace const * x0)
{
  { *result = cpSpaceGetGravity(x0); }
}
#endif

static double _cffi_d_cpSpaceGetIdleSpeedThreshold(cpSpace const * x0)
{
  return cpSpaceGetIdleSpeedThreshold(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetIdleSpeedThreshold(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetIdleSpeedThreshold(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetIdleSpeedThreshold _cffi_d_cpSpaceGetIdleSpeedThreshold
#endif

static int _cffi_d_cpSpaceGetIterations(cpSpace const * x0)
{
  return cpSpaceGetIterations(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetIterations(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetIterations(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetIterations _cffi_d_cpSpaceGetIterations
#endif

static double _cffi_d_cpSpaceGetSleepTimeThreshold(cpSpace const * x0)
{
  return cpSpaceGetSleepTimeThreshold(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetSleepTimeThreshold(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetSleepTimeThreshold(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetSleepTimeThreshold _cffi_d_cpSpaceGetSleepTimeThreshold
#endif

static cpBody * _cffi_d_cpSpaceGetStaticBody(cpSpace const * x0)
{
  return cpSpaceGetStaticBody(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetStaticBody(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpBody * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetStaticBody(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetStaticBody _cffi_d_cpSpaceGetStaticBody
#endif

static void * _cffi_d_cpSpaceGetUserData(cpSpace const * x0)
{
  return cpSpaceGetUserData(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceGetUserData(PyObject *self, PyObject *arg0)
{
  cpSpace const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceGetUserData(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(365));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceGetUserData _cffi_d_cpSpaceGetUserData
#endif

static cpSpace * _cffi_d_cpSpaceInit(cpSpace * x0)
{
  return cpSpaceInit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceInit(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpSpace * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceInit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceInit _cffi_d_cpSpaceInit
#endif

static unsigned char _cffi_d_cpSpaceIsLocked(cpSpace * x0)
{
  return cpSpaceIsLocked(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceIsLocked(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceIsLocked(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceIsLocked _cffi_d_cpSpaceIsLocked
#endif

static cpSpace * _cffi_d_cpSpaceNew(void)
{
  return cpSpaceNew();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceNew(PyObject *self, PyObject *noarg)
{
  cpSpace * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceNew(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceNew _cffi_d_cpSpaceNew
#endif

static void _cffi_d_cpSpacePointQuery(cpSpace * x0, cpVect x1, double x2, cpShapeFilter x3, void(* x4)(cpShape *, cpVect, double, cpVect, void *), void * x5)
{
  cpSpacePointQuery(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpacePointQuery(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVect x1;
  double x2;
  cpShapeFilter x3;
  void(* x4)(cpShape *, cpVect, double, cpVect, void *);
  void * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpSpacePointQuery", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(317), arg3) < 0)
    return NULL;

  x4 = (void(*)(cpShape *, cpVect, double, cpVect, void *))_cffi_to_c_pointer(arg4, _cffi_type(882));
  if (x4 == (void(*)(cpShape *, cpVect, double, cpVect, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpacePointQuery(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSpacePointQuery(cpSpace * x0, cpVect *x1, double x2, cpShapeFilter *x3, void(* x4)(cpShape *, cpVect, double, cpVect, void *), void * x5)
{
  { cpSpacePointQuery(x0, *x1, x2, *x3, x4, x5); }
}
#endif

static cpShape * _cffi_d_cpSpacePointQueryNearest(cpSpace * x0, cpVect x1, double x2, cpShapeFilter x3, cpPointQueryInfo * x4)
{
  return cpSpacePointQueryNearest(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpacePointQueryNearest(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVect x1;
  double x2;
  cpShapeFilter x3;
  cpPointQueryInfo * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpSpacePointQueryNearest", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(317), arg3) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(325), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (cpPointQueryInfo *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(325), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpacePointQueryNearest(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpSpacePointQueryNearest(cpSpace * x0, cpVect *x1, double x2, cpShapeFilter *x3, cpPointQueryInfo * x4)
{
  cpShape * result;
  { result = cpSpacePointQueryNearest(x0, *x1, x2, *x3, x4); }
  return result;
}
#endif

static void _cffi_d_cpSpaceReindexShape(cpSpace * x0, cpShape * x1)
{
  cpSpaceReindexShape(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceReindexShape(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpShape * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceReindexShape", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceReindexShape(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceReindexShape _cffi_d_cpSpaceReindexShape
#endif

static void _cffi_d_cpSpaceReindexShapesForBody(cpSpace * x0, cpBody * x1)
{
  cpSpaceReindexShapesForBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceReindexShapesForBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceReindexShapesForBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceReindexShapesForBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceReindexShapesForBody _cffi_d_cpSpaceReindexShapesForBody
#endif

static void _cffi_d_cpSpaceReindexStatic(cpSpace * x0)
{
  cpSpaceReindexStatic(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceReindexStatic(PyObject *self, PyObject *arg0)
{
  cpSpace * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceReindexStatic(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceReindexStatic _cffi_d_cpSpaceReindexStatic
#endif

static void _cffi_d_cpSpaceRemoveBody(cpSpace * x0, cpBody * x1)
{
  cpSpaceRemoveBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceRemoveBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceRemoveBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceRemoveBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceRemoveBody _cffi_d_cpSpaceRemoveBody
#endif

static void _cffi_d_cpSpaceRemoveConstraint(cpSpace * x0, cpConstraint * x1)
{
  cpSpaceRemoveConstraint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceRemoveConstraint(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpConstraint * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceRemoveConstraint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpConstraint *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceRemoveConstraint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceRemoveConstraint _cffi_d_cpSpaceRemoveConstraint
#endif

static void _cffi_d_cpSpaceRemoveShape(cpSpace * x0, cpShape * x1)
{
  cpSpaceRemoveShape(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceRemoveShape(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpShape * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceRemoveShape", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceRemoveShape(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceRemoveShape _cffi_d_cpSpaceRemoveShape
#endif

static void _cffi_d_cpSpaceSegmentQuery(cpSpace * x0, cpVect x1, cpVect x2, double x3, cpShapeFilter x4, void(* x5)(cpShape *, cpVect, cpVect, double, void *), void * x6)
{
  cpSpaceSegmentQuery(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSegmentQuery(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVect x1;
  cpVect x2;
  double x3;
  cpShapeFilter x4;
  void(* x5)(cpShape *, cpVect, cpVect, double, void *);
  void * x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "cpSpaceSegmentQuery", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(317), arg4) < 0)
    return NULL;

  x5 = (void(*)(cpShape *, cpVect, cpVect, double, void *))_cffi_to_c_pointer(arg5, _cffi_type(874));
  if (x5 == (void(*)(cpShape *, cpVect, cpVect, double, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg6, (char **)&x6);
  if (datasize != 0) {
    x6 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg6, (char **)&x6,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSegmentQuery(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSpaceSegmentQuery(cpSpace * x0, cpVect *x1, cpVect *x2, double x3, cpShapeFilter *x4, void(* x5)(cpShape *, cpVect, cpVect, double, void *), void * x6)
{
  { cpSpaceSegmentQuery(x0, *x1, *x2, x3, *x4, x5, x6); }
}
#endif

static cpShape * _cffi_d_cpSpaceSegmentQueryFirst(cpSpace * x0, cpVect x1, cpVect x2, double x3, cpShapeFilter x4, cpSegmentQueryInfo * x5)
{
  return cpSpaceSegmentQueryFirst(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSegmentQueryFirst(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVect x1;
  cpVect x2;
  double x3;
  cpShapeFilter x4;
  cpSegmentQueryInfo * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  cpShape * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "cpSpaceSegmentQueryFirst", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(6), arg2) < 0)
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x4, _cffi_type(317), arg4) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(318), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (cpSegmentQueryInfo *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(318), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceSegmentQueryFirst(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(9));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static cpShape * _cffi_f_cpSpaceSegmentQueryFirst(cpSpace * x0, cpVect *x1, cpVect *x2, double x3, cpShapeFilter *x4, cpSegmentQueryInfo * x5)
{
  cpShape * result;
  { result = cpSpaceSegmentQueryFirst(x0, *x1, *x2, x3, *x4, x5); }
  return result;
}
#endif

static void _cffi_d_cpSpaceSetCollisionBias(cpSpace * x0, double x1)
{
  cpSpaceSetCollisionBias(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetCollisionBias(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetCollisionBias", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetCollisionBias(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetCollisionBias _cffi_d_cpSpaceSetCollisionBias
#endif

static void _cffi_d_cpSpaceSetCollisionPersistence(cpSpace * x0, unsigned int x1)
{
  cpSpaceSetCollisionPersistence(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetCollisionPersistence(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetCollisionPersistence", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetCollisionPersistence(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetCollisionPersistence _cffi_d_cpSpaceSetCollisionPersistence
#endif

static void _cffi_d_cpSpaceSetCollisionSlop(cpSpace * x0, double x1)
{
  cpSpaceSetCollisionSlop(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetCollisionSlop(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetCollisionSlop", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetCollisionSlop(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetCollisionSlop _cffi_d_cpSpaceSetCollisionSlop
#endif

static void _cffi_d_cpSpaceSetDamping(cpSpace * x0, double x1)
{
  cpSpaceSetDamping(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetDamping(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetDamping", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetDamping(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetDamping _cffi_d_cpSpaceSetDamping
#endif

static void _cffi_d_cpSpaceSetGravity(cpSpace * x0, cpVect x1)
{
  cpSpaceSetGravity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetGravity(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpVect x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetGravity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(6), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetGravity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
static void _cffi_f_cpSpaceSetGravity(cpSpace * x0, cpVect *x1)
{
  { cpSpaceSetGravity(x0, *x1); }
}
#endif

static void _cffi_d_cpSpaceSetIdleSpeedThreshold(cpSpace * x0, double x1)
{
  cpSpaceSetIdleSpeedThreshold(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetIdleSpeedThreshold(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetIdleSpeedThreshold", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetIdleSpeedThreshold(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetIdleSpeedThreshold _cffi_d_cpSpaceSetIdleSpeedThreshold
#endif

static void _cffi_d_cpSpaceSetIterations(cpSpace * x0, int x1)
{
  cpSpaceSetIterations(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetIterations(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetIterations", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetIterations(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetIterations _cffi_d_cpSpaceSetIterations
#endif

static void _cffi_d_cpSpaceSetSleepTimeThreshold(cpSpace * x0, double x1)
{
  cpSpaceSetSleepTimeThreshold(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetSleepTimeThreshold(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetSleepTimeThreshold", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetSleepTimeThreshold(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetSleepTimeThreshold _cffi_d_cpSpaceSetSleepTimeThreshold
#endif

static void _cffi_d_cpSpaceSetStaticBody(cpSpace * x0, cpBody * x1)
{
  cpSpaceSetStaticBody(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetStaticBody(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpBody * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetStaticBody", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpBody *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetStaticBody(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetStaticBody _cffi_d_cpSpaceSetStaticBody
#endif

static void _cffi_d_cpSpaceSetUserData(cpSpace * x0, void * x1)
{
  cpSpaceSetUserData(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceSetUserData(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceSetUserData", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceSetUserData(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceSetUserData _cffi_d_cpSpaceSetUserData
#endif

static unsigned char _cffi_d_cpSpaceShapeQuery(cpSpace * x0, cpShape * x1, void(* x2)(cpShape *, cpContactPointSet *, void *), void * x3)
{
  return cpSpaceShapeQuery(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceShapeQuery(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  cpShape * x1;
  void(* x2)(cpShape *, cpContactPointSet *, void *);
  void * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned char result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "cpSpaceShapeQuery", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (cpShape *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = (void(*)(cpShape *, cpContactPointSet *, void *))_cffi_to_c_pointer(arg2, _cffi_type(583));
  if (x2 == (void(*)(cpShape *, cpContactPointSet *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(365), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(365), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpSpaceShapeQuery(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned char);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpSpaceShapeQuery _cffi_d_cpSpaceShapeQuery
#endif

static void _cffi_d_cpSpaceStep(cpSpace * x0, double x1)
{
  cpSpaceStep(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceStep(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpSpaceStep", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceStep(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceStep _cffi_d_cpSpaceStep
#endif

static void _cffi_d_cpSpaceUseSpatialHash(cpSpace * x0, double x1, int x2)
{
  cpSpaceUseSpatialHash(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpSpaceUseSpatialHash(PyObject *self, PyObject *args)
{
  cpSpace * x0;
  double x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpSpaceUseSpatialHash", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpSpace *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpSpaceUseSpatialHash(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpSpaceUseSpatialHash _cffi_d_cpSpaceUseSpatialHash
#endif

static int _cffi_const_CP_MAX_CONTACTS_PER_ARBITER(unsigned long long *o)
{
  int n = (CP_MAX_CONTACTS_PER_ARBITER) <= 0;
  *o = (unsigned long long)((CP_MAX_CONTACTS_PER_ARBITER) | 0);  /* check that CP_MAX_CONTACTS_PER_ARBITER is an integer */
  if (!_cffi_check_int(*o, n, 2U))
    n |= 2;
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpBB(cpBB *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { double *tmp = &p->l; (void)tmp; }
  { double *tmp = &p->b; (void)tmp; }
  { double *tmp = &p->r; (void)tmp; }
  { double *tmp = &p->t; (void)tmp; }
}
struct _cffi_align__cpBB { char x; cpBB y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpCollisionHandler(cpCollisionHandler *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->typeA) | 0);  /* check that 'cpCollisionHandler.typeA' is an integer */
  (void)((p->typeB) | 0);  /* check that 'cpCollisionHandler.typeB' is an integer */
  { unsigned char(* *tmp)(cpArbiter *, cpSpace *, void *) = &p->beginFunc; (void)tmp; }
  { unsigned char(* *tmp)(cpArbiter *, cpSpace *, void *) = &p->preSolveFunc; (void)tmp; }
  { void(* *tmp)(cpArbiter *, cpSpace *, void *) = &p->postSolveFunc; (void)tmp; }
  { void(* *tmp)(cpArbiter *, cpSpace *, void *) = &p->separateFunc; (void)tmp; }
  { void * *tmp = &p->userData; (void)tmp; }
}
struct _cffi_align__cpCollisionHandler { char x; cpCollisionHandler y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpContactPointSet(cpContactPointSet *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->count) | 0);  /* check that 'cpContactPointSet.count' is an integer */
  { cpVect *tmp = &p->normal; (void)tmp; }
  /* cannot generate 'struct $1[2]' in field 'points': unknown type name */
}
struct _cffi_align__cpContactPointSet { char x; cpContactPointSet y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpPointQueryInfo(cpPointQueryInfo *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { cpShape const * *tmp = &p->shape; (void)tmp; }
  { cpVect *tmp = &p->point; (void)tmp; }
  { double *tmp = &p->distance; (void)tmp; }
  { cpVect *tmp = &p->gradient; (void)tmp; }
}
struct _cffi_align__cpPointQueryInfo { char x; cpPointQueryInfo y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpPolyline(cpPolyline *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->count) | 0);  /* check that 'cpPolyline.count' is an integer */
  (void)((p->capacity) | 0);  /* check that 'cpPolyline.capacity' is an integer */
  { cpVect *tmp = &p->verts[0]; (void)tmp; }
}
struct _cffi_align__cpPolyline { char x; cpPolyline y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpPolylineSet(cpPolylineSet *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->count) | 0);  /* check that 'cpPolylineSet.count' is an integer */
  (void)((p->capacity) | 0);  /* check that 'cpPolylineSet.capacity' is an integer */
  { cpPolyline * * *tmp = &p->lines; (void)tmp; }
}
struct _cffi_align__cpPolylineSet { char x; cpPolylineSet y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpSegmentQueryInfo(cpSegmentQueryInfo *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { cpShape const * *tmp = &p->shape; (void)tmp; }
  { cpVect *tmp = &p->point; (void)tmp; }
  { cpVect *tmp = &p->normal; (void)tmp; }
  { double *tmp = &p->alpha; (void)tmp; }
}
struct _cffi_align__cpSegmentQueryInfo { char x; cpSegmentQueryInfo y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpShapeFilter(cpShapeFilter *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->group) | 0);  /* check that 'cpShapeFilter.group' is an integer */
  (void)((p->categories) | 0);  /* check that 'cpShapeFilter.categories' is an integer */
  (void)((p->mask) | 0);  /* check that 'cpShapeFilter.mask' is an integer */
}
struct _cffi_align__cpShapeFilter { char x; cpShapeFilter y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpSpaceDebugColor(cpSpaceDebugColor *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { float *tmp = &p->r; (void)tmp; }
  { float *tmp = &p->g; (void)tmp; }
  { float *tmp = &p->b; (void)tmp; }
  { float *tmp = &p->a; (void)tmp; }
}
struct _cffi_align__cpSpaceDebugColor { char x; cpSpaceDebugColor y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpSpaceDebugDrawOptions(cpSpaceDebugDrawOptions *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void(* *tmp)(cpVect, double, double, cpSpaceDebugColor, cpSpaceDebugColor, void *) = &p->drawCircle; (void)tmp; }
  { void(* *tmp)(cpVect, cpVect, cpSpaceDebugColor, void *) = &p->drawSegment; (void)tmp; }
  { void(* *tmp)(cpVect, cpVect, double, cpSpaceDebugColor, cpSpaceDebugColor, void *) = &p->drawFatSegment; (void)tmp; }
  { void(* *tmp)(int, cpVect const *, double, cpSpaceDebugColor, cpSpaceDebugColor, void *) = &p->drawPolygon; (void)tmp; }
  { void(* *tmp)(double, cpVect, cpSpaceDebugColor, void *) = &p->drawDot; (void)tmp; }
  { cpSpaceDebugDrawFlags *tmp = &p->flags; (void)tmp; }
  { cpSpaceDebugColor *tmp = &p->shapeOutlineColor; (void)tmp; }
  { cpSpaceDebugColor(* *tmp)(cpShape *, void *) = &p->colorForShape; (void)tmp; }
  { cpSpaceDebugColor *tmp = &p->constraintColor; (void)tmp; }
  { cpSpaceDebugColor *tmp = &p->collisionPointColor; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
}
struct _cffi_align__cpSpaceDebugDrawOptions { char x; cpSpaceDebugDrawOptions y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpTransform(cpTransform *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { double *tmp = &p->a; (void)tmp; }
  { double *tmp = &p->b; (void)tmp; }
  { double *tmp = &p->c; (void)tmp; }
  { double *tmp = &p->d; (void)tmp; }
  { double *tmp = &p->tx; (void)tmp; }
  { double *tmp = &p->ty; (void)tmp; }
}
struct _cffi_align__cpTransform { char x; cpTransform y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpVect(cpVect *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { double *tmp = &p->x; (void)tmp; }
  { double *tmp = &p->y; (void)tmp; }
}
struct _cffi_align__cpVect { char x; cpVect y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__cpVectArr(cpVectArr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->num) | 0);  /* check that 'cpVectArr.num' is an integer */
  (void)((p->max) | 0);  /* check that 'cpVectArr.max' is an integer */
  { cpVect * *tmp = &p->arr; (void)tmp; }
}
struct _cffi_align__cpVectArr { char x; cpVectArr y; };

static char const * *_cffi_var_cpVersionString(void)
{
  return &(cpVersionString);
}

static const struct _cffi_global_s _cffi_globals[] = {
  { "CP_BODY_TYPE_DYNAMIC", (void *)_cffi_const_CP_BODY_TYPE_DYNAMIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CP_BODY_TYPE_KINEMATIC", (void *)_cffi_const_CP_BODY_TYPE_KINEMATIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CP_BODY_TYPE_STATIC", (void *)_cffi_const_CP_BODY_TYPE_STATIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CP_MAX_CONTACTS_PER_ARBITER", (void *)_cffi_const_CP_MAX_CONTACTS_PER_ARBITER, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "CP_SPACE_DEBUG_DRAW_COLLISION_POINTS", (void *)_cffi_const_CP_SPACE_DEBUG_DRAW_COLLISION_POINTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CP_SPACE_DEBUG_DRAW_CONSTRAINTS", (void *)_cffi_const_CP_SPACE_DEBUG_DRAW_CONSTRAINTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CP_SPACE_DEBUG_DRAW_SHAPES", (void *)_cffi_const_CP_SPACE_DEBUG_DRAW_SHAPES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "cpArbiterCallWildcardBeginA", (void *)_cffi_f_cpArbiterCallWildcardBeginA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_cpArbiterCallWildcardBeginA },
  { "cpArbiterCallWildcardBeginB", (void *)_cffi_f_cpArbiterCallWildcardBeginB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_cpArbiterCallWildcardBeginB },
  { "cpArbiterCallWildcardPostSolveA", (void *)_cffi_f_cpArbiterCallWildcardPostSolveA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 617), (void *)_cffi_d_cpArbiterCallWildcardPostSolveA },
  { "cpArbiterCallWildcardPostSolveB", (void *)_cffi_f_cpArbiterCallWildcardPostSolveB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 617), (void *)_cffi_d_cpArbiterCallWildcardPostSolveB },
  { "cpArbiterCallWildcardPreSolveA", (void *)_cffi_f_cpArbiterCallWildcardPreSolveA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_cpArbiterCallWildcardPreSolveA },
  { "cpArbiterCallWildcardPreSolveB", (void *)_cffi_f_cpArbiterCallWildcardPreSolveB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_cpArbiterCallWildcardPreSolveB },
  { "cpArbiterCallWildcardSeparateA", (void *)_cffi_f_cpArbiterCallWildcardSeparateA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 617), (void *)_cffi_d_cpArbiterCallWildcardSeparateA },
  { "cpArbiterCallWildcardSeparateB", (void *)_cffi_f_cpArbiterCallWildcardSeparateB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 617), (void *)_cffi_d_cpArbiterCallWildcardSeparateB },
  { "cpArbiterGetBodies", (void *)_cffi_f_cpArbiterGetBodies, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 638), (void *)_cffi_d_cpArbiterGetBodies },
  { "cpArbiterGetContactPointSet", (void *)_cffi_f_cpArbiterGetContactPointSet, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 137), (void *)_cffi_d_cpArbiterGetContactPointSet },
  { "cpArbiterGetCount", (void *)_cffi_f_cpArbiterGetCount, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 506), (void *)_cffi_d_cpArbiterGetCount },
  { "cpArbiterGetDepth", (void *)_cffi_f_cpArbiterGetDepth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 414), (void *)_cffi_d_cpArbiterGetDepth },
  { "cpArbiterGetFriction", (void *)_cffi_f_cpArbiterGetFriction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 411), (void *)_cffi_d_cpArbiterGetFriction },
  { "cpArbiterGetNormal", (void *)_cffi_f_cpArbiterGetNormal, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 370), (void *)_cffi_d_cpArbiterGetNormal },
  { "cpArbiterGetPointA", (void *)_cffi_f_cpArbiterGetPointA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 373), (void *)_cffi_d_cpArbiterGetPointA },
  { "cpArbiterGetPointB", (void *)_cffi_f_cpArbiterGetPointB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 373), (void *)_cffi_d_cpArbiterGetPointB },
  { "cpArbiterGetRestitution", (void *)_cffi_f_cpArbiterGetRestitution, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 411), (void *)_cffi_d_cpArbiterGetRestitution },
  { "cpArbiterGetShapes", (void *)_cffi_f_cpArbiterGetShapes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 643), (void *)_cffi_d_cpArbiterGetShapes },
  { "cpArbiterGetSurfaceVelocity", (void *)_cffi_f_cpArbiterGetSurfaceVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 367), (void *)_cffi_d_cpArbiterGetSurfaceVelocity },
  { "cpArbiterGetUserData", (void *)_cffi_f_cpArbiterGetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 598), (void *)_cffi_d_cpArbiterGetUserData },
  { "cpArbiterIgnore", (void *)_cffi_f_cpArbiterIgnore, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 518), (void *)_cffi_d_cpArbiterIgnore },
  { "cpArbiterIsFirstContact", (void *)_cffi_f_cpArbiterIsFirstContact, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 530), (void *)_cffi_d_cpArbiterIsFirstContact },
  { "cpArbiterIsRemoval", (void *)_cffi_f_cpArbiterIsRemoval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 530), (void *)_cffi_d_cpArbiterIsRemoval },
  { "cpArbiterSetContactPointSet", (void *)_cffi_f_cpArbiterSetContactPointSet, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 613), (void *)_cffi_d_cpArbiterSetContactPointSet },
  { "cpArbiterSetFriction", (void *)_cffi_f_cpArbiterSetFriction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 630), (void *)_cffi_d_cpArbiterSetFriction },
  { "cpArbiterSetRestitution", (void *)_cffi_f_cpArbiterSetRestitution, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 630), (void *)_cffi_d_cpArbiterSetRestitution },
  { "cpArbiterSetSurfaceVelocity", (void *)_cffi_f_cpArbiterSetSurfaceVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 626), (void *)_cffi_d_cpArbiterSetSurfaceVelocity },
  { "cpArbiterSetUserData", (void *)_cffi_f_cpArbiterSetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 634), (void *)_cffi_d_cpArbiterSetUserData },
  { "cpArbiterTotalImpulse", (void *)_cffi_f_cpArbiterTotalImpulse, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 370), (void *)_cffi_d_cpArbiterTotalImpulse },
  { "cpArbiterTotalKE", (void *)_cffi_f_cpArbiterTotalKE, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 411), (void *)_cffi_d_cpArbiterTotalKE },
  { "cpAreaForCircle", (void *)_cffi_f_cpAreaForCircle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 476), (void *)_cffi_d_cpAreaForCircle },
  { "cpAreaForPoly", (void *)_cffi_f_cpAreaForPoly, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 498), (void *)_cffi_d_cpAreaForPoly },
  { "cpAreaForSegment", (void *)_cffi_f_cpAreaForSegment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 457), (void *)_cffi_d_cpAreaForSegment },
  { "cpBBArea", (void *)_cffi_f_cpBBArea, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 418), (void *)_cffi_d_cpBBArea },
  { "cpBBCenter", (void *)_cffi_f_cpBBCenter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 377), (void *)_cffi_d_cpBBCenter },
  { "cpBBClampVect", (void *)_cffi_f_cpBBClampVect, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 380), (void *)_cffi_d_cpBBClampVect },
  { "cpBBContainsBB", (void *)_cffi_f_cpBBContainsBB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 533), (void *)_cffi_d_cpBBContainsBB },
  { "cpBBContainsVect", (void *)_cffi_f_cpBBContainsVect, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 537), (void *)_cffi_d_cpBBContainsVect },
  { "cpBBExpand", (void *)_cffi_f_cpBBExpand, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 4), (void *)_cffi_d_cpBBExpand },
  { "cpBBIntersects", (void *)_cffi_f_cpBBIntersects, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 533), (void *)_cffi_d_cpBBIntersects },
  { "cpBBIntersectsSegment", (void *)_cffi_f_cpBBIntersectsSegment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 541), (void *)_cffi_d_cpBBIntersectsSegment },
  { "cpBBMerge", (void *)_cffi_f_cpBBMerge, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_cpBBMerge },
  { "cpBBMergedArea", (void *)_cffi_f_cpBBMergedArea, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 421), (void *)_cffi_d_cpBBMergedArea },
  { "cpBBNew", (void *)_cffi_f_cpBBNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 27), (void *)_cffi_d_cpBBNew },
  { "cpBBNewForCircle", (void *)_cffi_f_cpBBNewForCircle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 18), (void *)_cffi_d_cpBBNewForCircle },
  { "cpBBNewForExtents", (void *)_cffi_f_cpBBNewForExtents, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 22), (void *)_cffi_d_cpBBNewForExtents },
  { "cpBBOffset", (void *)_cffi_f_cpBBOffset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 4), (void *)_cffi_d_cpBBOffset },
  { "cpBBSegmentQuery", (void *)_cffi_f_cpBBSegmentQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 425), (void *)_cffi_d_cpBBSegmentQuery },
  { "cpBBWrapVect", (void *)_cffi_f_cpBBWrapVect, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 380), (void *)_cffi_d_cpBBWrapVect },
  { "cpBodyActivate", (void *)_cffi_f_cpBodyActivate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 658), (void *)_cffi_d_cpBodyActivate },
  { "cpBodyActivateStatic", (void *)_cffi_f_cpBodyActivateStatic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 679), (void *)_cffi_d_cpBodyActivateStatic },
  { "cpBodyAlloc", (void *)_cffi_f_cpBodyAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 55), (void *)_cffi_d_cpBodyAlloc },
  { "cpBodyApplyForceAtLocalPoint", (void *)_cffi_f_cpBodyApplyForceAtLocalPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 692), (void *)_cffi_d_cpBodyApplyForceAtLocalPoint },
  { "cpBodyApplyForceAtWorldPoint", (void *)_cffi_f_cpBodyApplyForceAtWorldPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 692), (void *)_cffi_d_cpBodyApplyForceAtWorldPoint },
  { "cpBodyApplyImpulseAtLocalPoint", (void *)_cffi_f_cpBodyApplyImpulseAtLocalPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 692), (void *)_cffi_d_cpBodyApplyImpulseAtLocalPoint },
  { "cpBodyApplyImpulseAtWorldPoint", (void *)_cffi_f_cpBodyApplyImpulseAtWorldPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 692), (void *)_cffi_d_cpBodyApplyImpulseAtWorldPoint },
  { "cpBodyDestroy", (void *)_cffi_f_cpBodyDestroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 658), (void *)_cffi_d_cpBodyDestroy },
  { "cpBodyEachArbiter", (void *)_cffi_f_cpBodyEachArbiter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 711), (void *)_cffi_d_cpBodyEachArbiter },
  { "cpBodyEachConstraint", (void *)_cffi_f_cpBodyEachConstraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 716), (void *)_cffi_d_cpBodyEachConstraint },
  { "cpBodyEachShape", (void *)_cffi_f_cpBodyEachShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 721), (void *)_cffi_d_cpBodyEachShape },
  { "cpBodyFree", (void *)_cffi_f_cpBodyFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 658), (void *)_cffi_d_cpBodyFree },
  { "cpBodyGetAngle", (void *)_cffi_f_cpBodyGetAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyGetAngle },
  { "cpBodyGetAngularVelocity", (void *)_cffi_f_cpBodyGetAngularVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyGetAngularVelocity },
  { "cpBodyGetCenterOfGravity", (void *)_cffi_f_cpBodyGetCenterOfGravity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_cpBodyGetCenterOfGravity },
  { "cpBodyGetForce", (void *)_cffi_f_cpBodyGetForce, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_cpBodyGetForce },
  { "cpBodyGetMass", (void *)_cffi_f_cpBodyGetMass, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyGetMass },
  { "cpBodyGetMoment", (void *)_cffi_f_cpBodyGetMoment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyGetMoment },
  { "cpBodyGetPosition", (void *)_cffi_f_cpBodyGetPosition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_cpBodyGetPosition },
  { "cpBodyGetRotation", (void *)_cffi_f_cpBodyGetRotation, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_cpBodyGetRotation },
  { "cpBodyGetSpace", (void *)_cffi_f_cpBodyGetSpace, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 349), (void *)_cffi_d_cpBodyGetSpace },
  { "cpBodyGetTorque", (void *)_cffi_f_cpBodyGetTorque, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyGetTorque },
  { "cpBodyGetType", (void *)_cffi_f_cpBodyGetType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 57), (void *)_cffi_d_cpBodyGetType },
  { "cpBodyGetUserData", (void *)_cffi_f_cpBodyGetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 601), (void *)_cffi_d_cpBodyGetUserData },
  { "cpBodyGetVelocity", (void *)_cffi_f_cpBodyGetVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_cpBodyGetVelocity },
  { "cpBodyGetVelocityAtLocalPoint", (void *)_cffi_f_cpBodyGetVelocityAtLocalPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 387), (void *)_cffi_d_cpBodyGetVelocityAtLocalPoint },
  { "cpBodyGetVelocityAtWorldPoint", (void *)_cffi_f_cpBodyGetVelocityAtWorldPoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 387), (void *)_cffi_d_cpBodyGetVelocityAtWorldPoint },
  { "cpBodyInit", (void *)_cffi_f_cpBodyInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 33), (void *)_cffi_d_cpBodyInit },
  { "cpBodyIsSleeping", (void *)_cffi_f_cpBodyIsSleeping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 546), (void *)_cffi_d_cpBodyIsSleeping },
  { "cpBodyKineticEnergy", (void *)_cffi_f_cpBodyKineticEnergy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 430), (void *)_cffi_d_cpBodyKineticEnergy },
  { "cpBodyLocalToWorld", (void *)_cffi_f_cpBodyLocalToWorld, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 387), (void *)_cffi_d_cpBodyLocalToWorld },
  { "cpBodyNew", (void *)_cffi_f_cpBodyNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 51), (void *)_cffi_d_cpBodyNew },
  { "cpBodyNewKinematic", (void *)_cffi_f_cpBodyNewKinematic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 55), (void *)_cffi_d_cpBodyNewKinematic },
  { "cpBodyNewStatic", (void *)_cffi_f_cpBodyNewStatic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 55), (void *)_cffi_d_cpBodyNewStatic },
  { "cpBodySetAngle", (void *)_cffi_f_cpBodySetAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodySetAngle },
  { "cpBodySetAngularVelocity", (void *)_cffi_f_cpBodySetAngularVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodySetAngularVelocity },
  { "cpBodySetCenterOfGravity", (void *)_cffi_f_cpBodySetCenterOfGravity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 688), (void *)_cffi_d_cpBodySetCenterOfGravity },
  { "cpBodySetForce", (void *)_cffi_f_cpBodySetForce, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 688), (void *)_cffi_d_cpBodySetForce },
  { "cpBodySetMass", (void *)_cffi_f_cpBodySetMass, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodySetMass },
  { "cpBodySetMoment", (void *)_cffi_f_cpBodySetMoment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodySetMoment },
  { "cpBodySetPosition", (void *)_cffi_f_cpBodySetPosition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 688), (void *)_cffi_d_cpBodySetPosition },
  { "cpBodySetPositionUpdateFunc", (void *)_cffi_f_cpBodySetPositionUpdateFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 730), (void *)_cffi_d_cpBodySetPositionUpdateFunc },
  { "cpBodySetTorque", (void *)_cffi_f_cpBodySetTorque, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodySetTorque },
  { "cpBodySetType", (void *)_cffi_f_cpBodySetType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 670), (void *)_cffi_d_cpBodySetType },
  { "cpBodySetUserData", (void *)_cffi_f_cpBodySetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 707), (void *)_cffi_d_cpBodySetUserData },
  { "cpBodySetVelocity", (void *)_cffi_f_cpBodySetVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 688), (void *)_cffi_d_cpBodySetVelocity },
  { "cpBodySetVelocityUpdateFunc", (void *)_cffi_f_cpBodySetVelocityUpdateFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 726), (void *)_cffi_d_cpBodySetVelocityUpdateFunc },
  { "cpBodySleep", (void *)_cffi_f_cpBodySleep, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 658), (void *)_cffi_d_cpBodySleep },
  { "cpBodySleepWithGroup", (void *)_cffi_f_cpBodySleepWithGroup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 666), (void *)_cffi_d_cpBodySleepWithGroup },
  { "cpBodyUpdatePosition", (void *)_cffi_f_cpBodyUpdatePosition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 703), (void *)_cffi_d_cpBodyUpdatePosition },
  { "cpBodyUpdateVelocity", (void *)_cffi_f_cpBodyUpdateVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 697), (void *)_cffi_d_cpBodyUpdateVelocity },
  { "cpBodyWorldToLocal", (void *)_cffi_f_cpBodyWorldToLocal, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 387), (void *)_cffi_d_cpBodyWorldToLocal },
  { "cpBoxShapeInit", (void *)_cffi_f_cpBoxShapeInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 209), (void *)_cffi_d_cpBoxShapeInit },
  { "cpBoxShapeInit2", (void *)_cffi_f_cpBoxShapeInit2, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 203), (void *)_cffi_d_cpBoxShapeInit2 },
  { "cpBoxShapeNew", (void *)_cffi_f_cpBoxShapeNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 289), (void *)_cffi_d_cpBoxShapeNew },
  { "cpBoxShapeNew2", (void *)_cffi_f_cpBoxShapeNew2, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 273), (void *)_cffi_d_cpBoxShapeNew2 },
  { "cpCentroidForPoly", (void *)_cffi_f_cpCentroidForPoly, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 407), (void *)_cffi_d_cpCentroidForPoly },
  { "cpCircleShapeAlloc", (void *)_cffi_f_cpCircleShapeAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 66), (void *)_cffi_d_cpCircleShapeAlloc },
  { "cpCircleShapeGetOffset", (void *)_cffi_f_cpCircleShapeGetOffset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 397), (void *)_cffi_d_cpCircleShapeGetOffset },
  { "cpCircleShapeGetRadius", (void *)_cffi_f_cpCircleShapeGetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 446), (void *)_cffi_d_cpCircleShapeGetRadius },
  { "cpCircleShapeInit", (void *)_cffi_f_cpCircleShapeInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 60), (void *)_cffi_d_cpCircleShapeInit },
  { "cpCircleShapeNew", (void *)_cffi_f_cpCircleShapeNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 284), (void *)_cffi_d_cpCircleShapeNew },
  { "cpCircleShapeSetOffset", (void *)_cffi_f_cpCircleShapeSetOffset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 788), (void *)_cffi_d_cpCircleShapeSetOffset },
  { "cpCircleShapeSetRadius", (void *)_cffi_f_cpCircleShapeSetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpCircleShapeSetRadius },
  { "cpConstraintDestroy", (void *)_cffi_f_cpConstraintDestroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 734), (void *)_cffi_d_cpConstraintDestroy },
  { "cpConstraintFree", (void *)_cffi_f_cpConstraintFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 734), (void *)_cffi_d_cpConstraintFree },
  { "cpConstraintGetBodyA", (void *)_cffi_f_cpConstraintGetBodyA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 38), (void *)_cffi_d_cpConstraintGetBodyA },
  { "cpConstraintGetBodyB", (void *)_cffi_f_cpConstraintGetBodyB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 38), (void *)_cffi_d_cpConstraintGetBodyB },
  { "cpConstraintGetCollideBodies", (void *)_cffi_f_cpConstraintGetCollideBodies, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintGetCollideBodies },
  { "cpConstraintGetErrorBias", (void *)_cffi_f_cpConstraintGetErrorBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpConstraintGetErrorBias },
  { "cpConstraintGetImpulse", (void *)_cffi_f_cpConstraintGetImpulse, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 433), (void *)_cffi_d_cpConstraintGetImpulse },
  { "cpConstraintGetMaxBias", (void *)_cffi_f_cpConstraintGetMaxBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpConstraintGetMaxBias },
  { "cpConstraintGetMaxForce", (void *)_cffi_f_cpConstraintGetMaxForce, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpConstraintGetMaxForce },
  { "cpConstraintGetPostSolveFunc", (void *)_cffi_f_cpConstraintGetPostSolveFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 980), (void *)_cffi_d_cpConstraintGetPostSolveFunc },
  { "cpConstraintGetPreSolveFunc", (void *)_cffi_f_cpConstraintGetPreSolveFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 980), (void *)_cffi_d_cpConstraintGetPreSolveFunc },
  { "cpConstraintGetSpace", (void *)_cffi_f_cpConstraintGetSpace, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 352), (void *)_cffi_d_cpConstraintGetSpace },
  { "cpConstraintGetUserData", (void *)_cffi_f_cpConstraintGetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 604), (void *)_cffi_d_cpConstraintGetUserData },
  { "cpConstraintIsDampedRotarySpring", (void *)_cffi_f_cpConstraintIsDampedRotarySpring, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsDampedRotarySpring },
  { "cpConstraintIsDampedSpring", (void *)_cffi_f_cpConstraintIsDampedSpring, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsDampedSpring },
  { "cpConstraintIsGearJoint", (void *)_cffi_f_cpConstraintIsGearJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsGearJoint },
  { "cpConstraintIsGrooveJoint", (void *)_cffi_f_cpConstraintIsGrooveJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsGrooveJoint },
  { "cpConstraintIsPinJoint", (void *)_cffi_f_cpConstraintIsPinJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsPinJoint },
  { "cpConstraintIsPivotJoint", (void *)_cffi_f_cpConstraintIsPivotJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsPivotJoint },
  { "cpConstraintIsRatchetJoint", (void *)_cffi_f_cpConstraintIsRatchetJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsRatchetJoint },
  { "cpConstraintIsRotaryLimitJoint", (void *)_cffi_f_cpConstraintIsRotaryLimitJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsRotaryLimitJoint },
  { "cpConstraintIsSimpleMotor", (void *)_cffi_f_cpConstraintIsSimpleMotor, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsSimpleMotor },
  { "cpConstraintIsSlideJoint", (void *)_cffi_f_cpConstraintIsSlideJoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_cpConstraintIsSlideJoint },
  { "cpConstraintSetCollideBodies", (void *)_cffi_f_cpConstraintSetCollideBodies, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 753), (void *)_cffi_d_cpConstraintSetCollideBodies },
  { "cpConstraintSetErrorBias", (void *)_cffi_f_cpConstraintSetErrorBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpConstraintSetErrorBias },
  { "cpConstraintSetMaxBias", (void *)_cffi_f_cpConstraintSetMaxBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpConstraintSetMaxBias },
  { "cpConstraintSetMaxForce", (void *)_cffi_f_cpConstraintSetMaxForce, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpConstraintSetMaxForce },
  { "cpConstraintSetPostSolveFunc", (void *)_cffi_f_cpConstraintSetPostSolveFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 761), (void *)_cffi_d_cpConstraintSetPostSolveFunc },
  { "cpConstraintSetPreSolveFunc", (void *)_cffi_f_cpConstraintSetPreSolveFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 761), (void *)_cffi_d_cpConstraintSetPreSolveFunc },
  { "cpConstraintSetUserData", (void *)_cffi_f_cpConstraintSetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 757), (void *)_cffi_d_cpConstraintSetUserData },
  { "cpDampedRotarySpringAlloc", (void *)_cffi_f_cpDampedRotarySpringAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 152), (void *)_cffi_d_cpDampedRotarySpringAlloc },
  { "cpDampedRotarySpringGetDamping", (void *)_cffi_f_cpDampedRotarySpringGetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedRotarySpringGetDamping },
  { "cpDampedRotarySpringGetRestAngle", (void *)_cffi_f_cpDampedRotarySpringGetRestAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedRotarySpringGetRestAngle },
  { "cpDampedRotarySpringGetSpringTorqueFunc", (void *)_cffi_f_cpDampedRotarySpringGetSpringTorqueFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 503), (void *)_cffi_d_cpDampedRotarySpringGetSpringTorqueFunc },
  { "cpDampedRotarySpringGetStiffness", (void *)_cffi_f_cpDampedRotarySpringGetStiffness, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedRotarySpringGetStiffness },
  { "cpDampedRotarySpringInit", (void *)_cffi_f_cpDampedRotarySpringInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_cpDampedRotarySpringInit },
  { "cpDampedRotarySpringNew", (void *)_cffi_f_cpDampedRotarySpringNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 126), (void *)_cffi_d_cpDampedRotarySpringNew },
  { "cpDampedRotarySpringSetDamping", (void *)_cffi_f_cpDampedRotarySpringSetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedRotarySpringSetDamping },
  { "cpDampedRotarySpringSetRestAngle", (void *)_cffi_f_cpDampedRotarySpringSetRestAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedRotarySpringSetRestAngle },
  { "cpDampedRotarySpringSetSpringTorqueFunc", (void *)_cffi_f_cpDampedRotarySpringSetSpringTorqueFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 745), (void *)_cffi_d_cpDampedRotarySpringSetSpringTorqueFunc },
  { "cpDampedRotarySpringSetStiffness", (void *)_cffi_f_cpDampedRotarySpringSetStiffness, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedRotarySpringSetStiffness },
  { "cpDampedSpringAlloc", (void *)_cffi_f_cpDampedSpringAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 164), (void *)_cffi_d_cpDampedSpringAlloc },
  { "cpDampedSpringGetAnchorA", (void *)_cffi_f_cpDampedSpringGetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpDampedSpringGetAnchorA },
  { "cpDampedSpringGetAnchorB", (void *)_cffi_f_cpDampedSpringGetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpDampedSpringGetAnchorB },
  { "cpDampedSpringGetDamping", (void *)_cffi_f_cpDampedSpringGetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedSpringGetDamping },
  { "cpDampedSpringGetRestLength", (void *)_cffi_f_cpDampedSpringGetRestLength, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedSpringGetRestLength },
  { "cpDampedSpringGetSpringForceFunc", (void *)_cffi_f_cpDampedSpringGetSpringForceFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 503), (void *)_cffi_d_cpDampedSpringGetSpringForceFunc },
  { "cpDampedSpringGetStiffness", (void *)_cffi_f_cpDampedSpringGetStiffness, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpDampedSpringGetStiffness },
  { "cpDampedSpringInit", (void *)_cffi_f_cpDampedSpringInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 154), (void *)_cffi_d_cpDampedSpringInit },
  { "cpDampedSpringNew", (void *)_cffi_f_cpDampedSpringNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 106), (void *)_cffi_d_cpDampedSpringNew },
  { "cpDampedSpringSetAnchorA", (void *)_cffi_f_cpDampedSpringSetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpDampedSpringSetAnchorA },
  { "cpDampedSpringSetAnchorB", (void *)_cffi_f_cpDampedSpringSetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpDampedSpringSetAnchorB },
  { "cpDampedSpringSetDamping", (void *)_cffi_f_cpDampedSpringSetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedSpringSetDamping },
  { "cpDampedSpringSetRestLength", (void *)_cffi_f_cpDampedSpringSetRestLength, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedSpringSetRestLength },
  { "cpDampedSpringSetSpringForceFunc", (void *)_cffi_f_cpDampedSpringSetSpringForceFunc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 745), (void *)_cffi_d_cpDampedSpringSetSpringForceFunc },
  { "cpDampedSpringSetStiffness", (void *)_cffi_f_cpDampedSpringSetStiffness, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpDampedSpringSetStiffness },
  { "cpGearJointAlloc", (void *)_cffi_f_cpGearJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 173), (void *)_cffi_d_cpGearJointAlloc },
  { "cpGearJointGetPhase", (void *)_cffi_f_cpGearJointGetPhase, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpGearJointGetPhase },
  { "cpGearJointGetRatio", (void *)_cffi_f_cpGearJointGetRatio, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpGearJointGetRatio },
  { "cpGearJointInit", (void *)_cffi_f_cpGearJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 166), (void *)_cffi_d_cpGearJointInit },
  { "cpGearJointNew", (void *)_cffi_f_cpGearJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 120), (void *)_cffi_d_cpGearJointNew },
  { "cpGearJointSetPhase", (void *)_cffi_f_cpGearJointSetPhase, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpGearJointSetPhase },
  { "cpGearJointSetRatio", (void *)_cffi_f_cpGearJointSetRatio, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpGearJointSetRatio },
  { "cpGrooveJointAlloc", (void *)_cffi_f_cpGrooveJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 183), (void *)_cffi_d_cpGrooveJointAlloc },
  { "cpGrooveJointGetAnchorB", (void *)_cffi_f_cpGrooveJointGetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpGrooveJointGetAnchorB },
  { "cpGrooveJointGetGrooveA", (void *)_cffi_f_cpGrooveJointGetGrooveA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpGrooveJointGetGrooveA },
  { "cpGrooveJointGetGrooveB", (void *)_cffi_f_cpGrooveJointGetGrooveB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpGrooveJointGetGrooveB },
  { "cpGrooveJointInit", (void *)_cffi_f_cpGrooveJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_cpGrooveJointInit },
  { "cpGrooveJointNew", (void *)_cffi_f_cpGrooveJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 91), (void *)_cffi_d_cpGrooveJointNew },
  { "cpGrooveJointSetAnchorB", (void *)_cffi_f_cpGrooveJointSetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpGrooveJointSetAnchorB },
  { "cpGrooveJointSetGrooveA", (void *)_cffi_f_cpGrooveJointSetGrooveA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpGrooveJointSetGrooveA },
  { "cpGrooveJointSetGrooveB", (void *)_cffi_f_cpGrooveJointSetGrooveB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpGrooveJointSetGrooveB },
  { "cpHastySpaceFree", (void *)_cffi_f_cpHastySpaceFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 838), (void *)_cffi_d_cpHastySpaceFree },
  { "cpHastySpaceGetThreads", (void *)_cffi_f_cpHastySpaceGetThreads, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 595), (void *)_cffi_d_cpHastySpaceGetThreads },
  { "cpHastySpaceNew", (void *)_cffi_f_cpHastySpaceNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 361), (void *)_cffi_d_cpHastySpaceNew },
  { "cpHastySpaceSetThreads", (void *)_cffi_f_cpHastySpaceSetThreads, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 906), (void *)_cffi_d_cpHastySpaceSetThreads },
  { "cpHastySpaceStep", (void *)_cffi_f_cpHastySpaceStep, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpHastySpaceStep },
  { "cpMarchHard", (void *)_cffi_f_cpMarchHard, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 648), (void *)_cffi_d_cpMarchHard },
  { "cpMarchSoft", (void *)_cffi_f_cpMarchSoft, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 648), (void *)_cffi_d_cpMarchSoft },
  { "cpMomentForBox", (void *)_cffi_f_cpMomentForBox, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 480), (void *)_cffi_d_cpMomentForBox },
  { "cpMomentForBox2", (void *)_cffi_f_cpMomentForBox2, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 466), (void *)_cffi_d_cpMomentForBox2 },
  { "cpMomentForCircle", (void *)_cffi_f_cpMomentForCircle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 485), (void *)_cffi_d_cpMomentForCircle },
  { "cpMomentForPoly", (void *)_cffi_f_cpMomentForPoly, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 491), (void *)_cffi_d_cpMomentForPoly },
  { "cpMomentForSegment", (void *)_cffi_f_cpMomentForSegment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 470), (void *)_cffi_d_cpMomentForSegment },
  { "cpPinJointAlloc", (void *)_cffi_f_cpPinJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 192), (void *)_cffi_d_cpPinJointAlloc },
  { "cpPinJointGetAnchorA", (void *)_cffi_f_cpPinJointGetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpPinJointGetAnchorA },
  { "cpPinJointGetAnchorB", (void *)_cffi_f_cpPinJointGetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpPinJointGetAnchorB },
  { "cpPinJointGetDist", (void *)_cffi_f_cpPinJointGetDist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpPinJointGetDist },
  { "cpPinJointInit", (void *)_cffi_f_cpPinJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 185), (void *)_cffi_d_cpPinJointInit },
  { "cpPinJointNew", (void *)_cffi_f_cpPinJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 85), (void *)_cffi_d_cpPinJointNew },
  { "cpPinJointSetAnchorA", (void *)_cffi_f_cpPinJointSetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpPinJointSetAnchorA },
  { "cpPinJointSetAnchorB", (void *)_cffi_f_cpPinJointSetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpPinJointSetAnchorB },
  { "cpPinJointSetDist", (void *)_cffi_f_cpPinJointSetDist, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpPinJointSetDist },
  { "cpPivotJointAlloc", (void *)_cffi_f_cpPivotJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 201), (void *)_cffi_d_cpPivotJointAlloc },
  { "cpPivotJointGetAnchorA", (void *)_cffi_f_cpPivotJointGetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpPivotJointGetAnchorA },
  { "cpPivotJointGetAnchorB", (void *)_cffi_f_cpPivotJointGetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpPivotJointGetAnchorB },
  { "cpPivotJointInit", (void *)_cffi_f_cpPivotJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 194), (void *)_cffi_d_cpPivotJointInit },
  { "cpPivotJointNew", (void *)_cffi_f_cpPivotJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 80), (void *)_cffi_d_cpPivotJointNew },
  { "cpPivotJointNew2", (void *)_cffi_f_cpPivotJointNew2, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 85), (void *)_cffi_d_cpPivotJointNew2 },
  { "cpPivotJointSetAnchorA", (void *)_cffi_f_cpPivotJointSetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpPivotJointSetAnchorA },
  { "cpPivotJointSetAnchorB", (void *)_cffi_f_cpPivotJointSetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpPivotJointSetAnchorB },
  { "cpPolyShapeAlloc", (void *)_cffi_f_cpPolyShapeAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 231), (void *)_cffi_d_cpPolyShapeAlloc },
  { "cpPolyShapeGetCount", (void *)_cffi_f_cpPolyShapeGetCount, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 509), (void *)_cffi_d_cpPolyShapeGetCount },
  { "cpPolyShapeGetRadius", (void *)_cffi_f_cpPolyShapeGetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 446), (void *)_cffi_d_cpPolyShapeGetRadius },
  { "cpPolyShapeGetVert", (void *)_cffi_f_cpPolyShapeGetVert, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 400), (void *)_cffi_d_cpPolyShapeGetVert },
  { "cpPolyShapeInit", (void *)_cffi_f_cpPolyShapeInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 216), (void *)_cffi_d_cpPolyShapeInit },
  { "cpPolyShapeInitRaw", (void *)_cffi_f_cpPolyShapeInitRaw, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 224), (void *)_cffi_d_cpPolyShapeInitRaw },
  { "cpPolyShapeNew", (void *)_cffi_f_cpPolyShapeNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_cpPolyShapeNew },
  { "cpPolyShapeNewRaw", (void *)_cffi_f_cpPolyShapeNewRaw, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 302), (void *)_cffi_d_cpPolyShapeNewRaw },
  { "cpPolyShapeSetRadius", (void *)_cffi_f_cpPolyShapeSetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpPolyShapeSetRadius },
  { "cpPolyShapeSetVerts", (void *)_cffi_f_cpPolyShapeSetVerts, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 820), (void *)_cffi_d_cpPolyShapeSetVerts },
  { "cpPolyShapeSetVertsRaw", (void *)_cffi_f_cpPolyShapeSetVertsRaw, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 815), (void *)_cffi_d_cpPolyShapeSetVertsRaw },
  { "cpPolylineConvexDecomposition", (void *)_cffi_f_cpPolylineConvexDecomposition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 237), (void *)_cffi_d_cpPolylineConvexDecomposition },
  { "cpPolylineFree", (void *)_cffi_f_cpPolylineFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 765), (void *)_cffi_d_cpPolylineFree },
  { "cpPolylineIsClosed", (void *)_cffi_f_cpPolylineIsClosed, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 552), (void *)_cffi_d_cpPolylineIsClosed },
  { "cpPolylineSetAlloc", (void *)_cffi_f_cpPolylineSetAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 244), (void *)_cffi_d_cpPolylineSetAlloc },
  { "cpPolylineSetCollectSegment", (void *)_cffi_f_cpPolylineSetCollectSegment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 934), (void *)_cffi_d_cpPolylineSetCollectSegment },
  { "cpPolylineSetDestroy", (void *)_cffi_f_cpPolylineSetDestroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 768), (void *)_cffi_d_cpPolylineSetDestroy },
  { "cpPolylineSetFree", (void *)_cffi_f_cpPolylineSetFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 768), (void *)_cffi_d_cpPolylineSetFree },
  { "cpPolylineSetInit", (void *)_cffi_f_cpPolylineSetInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 241), (void *)_cffi_d_cpPolylineSetInit },
  { "cpPolylineSetNew", (void *)_cffi_f_cpPolylineSetNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 244), (void *)_cffi_d_cpPolylineSetNew },
  { "cpPolylineSimplifyCurves", (void *)_cffi_f_cpPolylineSimplifyCurves, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 233), (void *)_cffi_d_cpPolylineSimplifyCurves },
  { "cpPolylineSimplifyVertexes", (void *)_cffi_f_cpPolylineSimplifyVertexes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 233), (void *)_cffi_d_cpPolylineSimplifyVertexes },
  { "cpPolylineToConvexHull", (void *)_cffi_f_cpPolylineToConvexHull, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 233), (void *)_cffi_d_cpPolylineToConvexHull },
  { "cpRatchetJointAlloc", (void *)_cffi_f_cpRatchetJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 253), (void *)_cffi_d_cpRatchetJointAlloc },
  { "cpRatchetJointGetAngle", (void *)_cffi_f_cpRatchetJointGetAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpRatchetJointGetAngle },
  { "cpRatchetJointGetPhase", (void *)_cffi_f_cpRatchetJointGetPhase, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpRatchetJointGetPhase },
  { "cpRatchetJointGetRatchet", (void *)_cffi_f_cpRatchetJointGetRatchet, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpRatchetJointGetRatchet },
  { "cpRatchetJointInit", (void *)_cffi_f_cpRatchetJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 246), (void *)_cffi_d_cpRatchetJointInit },
  { "cpRatchetJointNew", (void *)_cffi_f_cpRatchetJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 120), (void *)_cffi_d_cpRatchetJointNew },
  { "cpRatchetJointSetAngle", (void *)_cffi_f_cpRatchetJointSetAngle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpRatchetJointSetAngle },
  { "cpRatchetJointSetPhase", (void *)_cffi_f_cpRatchetJointSetPhase, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpRatchetJointSetPhase },
  { "cpRatchetJointSetRatchet", (void *)_cffi_f_cpRatchetJointSetRatchet, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpRatchetJointSetRatchet },
  { "cpRotaryLimitJointAlloc", (void *)_cffi_f_cpRotaryLimitJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 262), (void *)_cffi_d_cpRotaryLimitJointAlloc },
  { "cpRotaryLimitJointGetMax", (void *)_cffi_f_cpRotaryLimitJointGetMax, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpRotaryLimitJointGetMax },
  { "cpRotaryLimitJointGetMin", (void *)_cffi_f_cpRotaryLimitJointGetMin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpRotaryLimitJointGetMin },
  { "cpRotaryLimitJointInit", (void *)_cffi_f_cpRotaryLimitJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 255), (void *)_cffi_d_cpRotaryLimitJointInit },
  { "cpRotaryLimitJointNew", (void *)_cffi_f_cpRotaryLimitJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 120), (void *)_cffi_d_cpRotaryLimitJointNew },
  { "cpRotaryLimitJointSetMax", (void *)_cffi_f_cpRotaryLimitJointSetMax, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpRotaryLimitJointSetMax },
  { "cpRotaryLimitJointSetMin", (void *)_cffi_f_cpRotaryLimitJointSetMin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpRotaryLimitJointSetMin },
  { "cpSegmentShapeAlloc", (void *)_cffi_f_cpSegmentShapeAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 271), (void *)_cffi_d_cpSegmentShapeAlloc },
  { "cpSegmentShapeGetA", (void *)_cffi_f_cpSegmentShapeGetA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 397), (void *)_cffi_d_cpSegmentShapeGetA },
  { "cpSegmentShapeGetB", (void *)_cffi_f_cpSegmentShapeGetB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 397), (void *)_cffi_d_cpSegmentShapeGetB },
  { "cpSegmentShapeGetNormal", (void *)_cffi_f_cpSegmentShapeGetNormal, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 397), (void *)_cffi_d_cpSegmentShapeGetNormal },
  { "cpSegmentShapeGetRadius", (void *)_cffi_f_cpSegmentShapeGetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 446), (void *)_cffi_d_cpSegmentShapeGetRadius },
  { "cpSegmentShapeInit", (void *)_cffi_f_cpSegmentShapeInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 264), (void *)_cffi_d_cpSegmentShapeInit },
  { "cpSegmentShapeNew", (void *)_cffi_f_cpSegmentShapeNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 278), (void *)_cffi_d_cpSegmentShapeNew },
  { "cpSegmentShapeSetEndpoints", (void *)_cffi_f_cpSegmentShapeSetEndpoints, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 792), (void *)_cffi_d_cpSegmentShapeSetEndpoints },
  { "cpSegmentShapeSetNeighbors", (void *)_cffi_f_cpSegmentShapeSetNeighbors, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 792), (void *)_cffi_d_cpSegmentShapeSetNeighbors },
  { "cpSegmentShapeSetRadius", (void *)_cffi_f_cpSegmentShapeSetRadius, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpSegmentShapeSetRadius },
  { "cpShapeCacheBB", (void *)_cffi_f_cpShapeCacheBB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 8), (void *)_cffi_d_cpShapeCacheBB },
  { "cpShapeDestroy", (void *)_cffi_f_cpShapeDestroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 772), (void *)_cffi_d_cpShapeDestroy },
  { "cpShapeFree", (void *)_cffi_f_cpShapeFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 772), (void *)_cffi_d_cpShapeFree },
  { "cpShapeGetArea", (void *)_cffi_f_cpShapeGetArea, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 443), (void *)_cffi_d_cpShapeGetArea },
  { "cpShapeGetBB", (void *)_cffi_f_cpShapeGetBB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 15), (void *)_cffi_d_cpShapeGetBB },
  { "cpShapeGetBody", (void *)_cffi_f_cpShapeGetBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 41), (void *)_cffi_d_cpShapeGetBody },
  { "cpShapeGetCenterOfGravity", (void *)_cffi_f_cpShapeGetCenterOfGravity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 394), (void *)_cffi_d_cpShapeGetCenterOfGravity },
  { "cpShapeGetCollisionType", (void *)_cffi_f_cpShapeGetCollisionType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 515), (void *)_cffi_d_cpShapeGetCollisionType },
  { "cpShapeGetDensity", (void *)_cffi_f_cpShapeGetDensity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 443), (void *)_cffi_d_cpShapeGetDensity },
  { "cpShapeGetElasticity", (void *)_cffi_f_cpShapeGetElasticity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 446), (void *)_cffi_d_cpShapeGetElasticity },
  { "cpShapeGetFilter", (void *)_cffi_f_cpShapeGetFilter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 327), (void *)_cffi_d_cpShapeGetFilter },
  { "cpShapeGetFriction", (void *)_cffi_f_cpShapeGetFriction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 446), (void *)_cffi_d_cpShapeGetFriction },
  { "cpShapeGetMass", (void *)_cffi_f_cpShapeGetMass, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 443), (void *)_cffi_d_cpShapeGetMass },
  { "cpShapeGetMoment", (void *)_cffi_f_cpShapeGetMoment, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 443), (void *)_cffi_d_cpShapeGetMoment },
  { "cpShapeGetSensor", (void *)_cffi_f_cpShapeGetSensor, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 555), (void *)_cffi_d_cpShapeGetSensor },
  { "cpShapeGetSpace", (void *)_cffi_f_cpShapeGetSpace, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 355), (void *)_cffi_d_cpShapeGetSpace },
  { "cpShapeGetSurfaceVelocity", (void *)_cffi_f_cpShapeGetSurfaceVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 397), (void *)_cffi_d_cpShapeGetSurfaceVelocity },
  { "cpShapeGetUserData", (void *)_cffi_f_cpShapeGetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 607), (void *)_cffi_d_cpShapeGetUserData },
  { "cpShapePointQuery", (void *)_cffi_f_cpShapePointQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 449), (void *)_cffi_d_cpShapePointQuery },
  { "cpShapeSegmentQuery", (void *)_cffi_f_cpShapeSegmentQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 558), (void *)_cffi_d_cpShapeSegmentQuery },
  { "cpShapeSetBody", (void *)_cffi_f_cpShapeSetBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 775), (void *)_cffi_d_cpShapeSetBody },
  { "cpShapeSetCollisionType", (void *)_cffi_f_cpShapeSetCollisionType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 826), (void *)_cffi_d_cpShapeSetCollisionType },
  { "cpShapeSetDensity", (void *)_cffi_f_cpShapeSetDensity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpShapeSetDensity },
  { "cpShapeSetElasticity", (void *)_cffi_f_cpShapeSetElasticity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpShapeSetElasticity },
  { "cpShapeSetFilter", (void *)_cffi_f_cpShapeSetFilter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 784), (void *)_cffi_d_cpShapeSetFilter },
  { "cpShapeSetFriction", (void *)_cffi_f_cpShapeSetFriction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpShapeSetFriction },
  { "cpShapeSetMass", (void *)_cffi_f_cpShapeSetMass, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 811), (void *)_cffi_d_cpShapeSetMass },
  { "cpShapeSetSensor", (void *)_cffi_f_cpShapeSetSensor, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 830), (void *)_cffi_d_cpShapeSetSensor },
  { "cpShapeSetSurfaceVelocity", (void *)_cffi_f_cpShapeSetSurfaceVelocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 788), (void *)_cffi_d_cpShapeSetSurfaceVelocity },
  { "cpShapeSetUserData", (void *)_cffi_f_cpShapeSetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 834), (void *)_cffi_d_cpShapeSetUserData },
  { "cpShapeUpdate", (void *)_cffi_f_cpShapeUpdate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 11), (void *)_cffi_d_cpShapeUpdate },
  { "cpShapesCollide", (void *)_cffi_f_cpShapesCollide, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 140), (void *)_cffi_d_cpShapesCollide },
  { "cpSimpleMotorAlloc", (void *)_cffi_f_cpSimpleMotorAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 336), (void *)_cffi_d_cpSimpleMotorAlloc },
  { "cpSimpleMotorGetRate", (void *)_cffi_f_cpSimpleMotorGetRate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpSimpleMotorGetRate },
  { "cpSimpleMotorInit", (void *)_cffi_f_cpSimpleMotorInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 330), (void *)_cffi_d_cpSimpleMotorInit },
  { "cpSimpleMotorNew", (void *)_cffi_f_cpSimpleMotorNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_cpSimpleMotorNew },
  { "cpSimpleMotorSetRate", (void *)_cffi_f_cpSimpleMotorSetRate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpSimpleMotorSetRate },
  { "cpSlideJointAlloc", (void *)_cffi_f_cpSlideJointAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 347), (void *)_cffi_d_cpSlideJointAlloc },
  { "cpSlideJointGetAnchorA", (void *)_cffi_f_cpSlideJointGetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpSlideJointGetAnchorA },
  { "cpSlideJointGetAnchorB", (void *)_cffi_f_cpSlideJointGetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 391), (void *)_cffi_d_cpSlideJointGetAnchorB },
  { "cpSlideJointGetMax", (void *)_cffi_f_cpSlideJointGetMax, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpSlideJointGetMax },
  { "cpSlideJointGetMin", (void *)_cffi_f_cpSlideJointGetMin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 440), (void *)_cffi_d_cpSlideJointGetMin },
  { "cpSlideJointInit", (void *)_cffi_f_cpSlideJointInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_cpSlideJointInit },
  { "cpSlideJointNew", (void *)_cffi_f_cpSlideJointNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 98), (void *)_cffi_d_cpSlideJointNew },
  { "cpSlideJointSetAnchorA", (void *)_cffi_f_cpSlideJointSetAnchorA, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpSlideJointSetAnchorA },
  { "cpSlideJointSetAnchorB", (void *)_cffi_f_cpSlideJointSetAnchorB, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_cpSlideJointSetAnchorB },
  { "cpSlideJointSetMax", (void *)_cffi_f_cpSlideJointSetMax, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpSlideJointSetMax },
  { "cpSlideJointSetMin", (void *)_cffi_f_cpSlideJointSetMin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 749), (void *)_cffi_d_cpSlideJointSetMin },
  { "cpSpaceAddBody", (void *)_cffi_f_cpSpaceAddBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 44), (void *)_cffi_d_cpSpaceAddBody },
  { "cpSpaceAddCollisionHandler", (void *)_cffi_f_cpSpaceAddCollisionHandler, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 75), (void *)_cffi_d_cpSpaceAddCollisionHandler },
  { "cpSpaceAddConstraint", (void *)_cffi_f_cpSpaceAddConstraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 133), (void *)_cffi_d_cpSpaceAddConstraint },
  { "cpSpaceAddDefaultCollisionHandler", (void *)_cffi_f_cpSpaceAddDefaultCollisionHandler, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 68), (void *)_cffi_d_cpSpaceAddDefaultCollisionHandler },
  { "cpSpaceAddPostStepCallback", (void *)_cffi_f_cpSpaceAddPostStepCallback, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 586), (void *)_cffi_d_cpSpaceAddPostStepCallback },
  { "cpSpaceAddShape", (void *)_cffi_f_cpSpaceAddShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 308), (void *)_cffi_d_cpSpaceAddShape },
  { "cpSpaceAddWildcardHandler", (void *)_cffi_f_cpSpaceAddWildcardHandler, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 71), (void *)_cffi_d_cpSpaceAddWildcardHandler },
  { "cpSpaceAlloc", (void *)_cffi_f_cpSpaceAlloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 361), (void *)_cffi_d_cpSpaceAlloc },
  { "cpSpaceBBQuery", (void *)_cffi_f_cpSpaceBBQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 841), (void *)_cffi_d_cpSpaceBBQuery },
  { "cpSpaceContainsBody", (void *)_cffi_f_cpSpaceContainsBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 568), (void *)_cffi_d_cpSpaceContainsBody },
  { "cpSpaceContainsConstraint", (void *)_cffi_f_cpSpaceContainsConstraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 572), (void *)_cffi_d_cpSpaceContainsConstraint },
  { "cpSpaceContainsShape", (void *)_cffi_f_cpSpaceContainsShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 576), (void *)_cffi_d_cpSpaceContainsShape },
  { "cpSpaceDebugDraw", (void *)_cffi_f_cpSpaceDebugDraw, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 860), (void *)_cffi_d_cpSpaceDebugDraw },
  { "cpSpaceDestroy", (void *)_cffi_f_cpSpaceDestroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 838), (void *)_cffi_d_cpSpaceDestroy },
  { "cpSpaceEachBody", (void *)_cffi_f_cpSpaceEachBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 919), (void *)_cffi_d_cpSpaceEachBody },
  { "cpSpaceEachConstraint", (void *)_cffi_f_cpSpaceEachConstraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 924), (void *)_cffi_d_cpSpaceEachConstraint },
  { "cpSpaceEachShape", (void *)_cffi_f_cpSpaceEachShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 929), (void *)_cffi_d_cpSpaceEachShape },
  { "cpSpaceFree", (void *)_cffi_f_cpSpaceFree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 838), (void *)_cffi_d_cpSpaceFree },
  { "cpSpaceGetBodyPositions", (void *)_cffi_f_cpSpaceGetBodyPositions, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 885), (void *)_cffi_d_cpSpaceGetBodyPositions },
  { "cpSpaceGetCollisionBias", (void *)_cffi_f_cpSpaceGetCollisionBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetCollisionBias },
  { "cpSpaceGetCollisionPersistence", (void *)_cffi_f_cpSpaceGetCollisionPersistence, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 592), (void *)_cffi_d_cpSpaceGetCollisionPersistence },
  { "cpSpaceGetCollisionSlop", (void *)_cffi_f_cpSpaceGetCollisionSlop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetCollisionSlop },
  { "cpSpaceGetCurrentTimeStep", (void *)_cffi_f_cpSpaceGetCurrentTimeStep, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetCurrentTimeStep },
  { "cpSpaceGetDamping", (void *)_cffi_f_cpSpaceGetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetDamping },
  { "cpSpaceGetGravity", (void *)_cffi_f_cpSpaceGetGravity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 404), (void *)_cffi_d_cpSpaceGetGravity },
  { "cpSpaceGetIdleSpeedThreshold", (void *)_cffi_f_cpSpaceGetIdleSpeedThreshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetIdleSpeedThreshold },
  { "cpSpaceGetIterations", (void *)_cffi_f_cpSpaceGetIterations, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 512), (void *)_cffi_d_cpSpaceGetIterations },
  { "cpSpaceGetSleepTimeThreshold", (void *)_cffi_f_cpSpaceGetSleepTimeThreshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_cpSpaceGetSleepTimeThreshold },
  { "cpSpaceGetStaticBody", (void *)_cffi_f_cpSpaceGetStaticBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 48), (void *)_cffi_d_cpSpaceGetStaticBody },
  { "cpSpaceGetUserData", (void *)_cffi_f_cpSpaceGetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 610), (void *)_cffi_d_cpSpaceGetUserData },
  { "cpSpaceInit", (void *)_cffi_f_cpSpaceInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 358), (void *)_cffi_d_cpSpaceInit },
  { "cpSpaceIsLocked", (void *)_cffi_f_cpSpaceIsLocked, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 565), (void *)_cffi_d_cpSpaceIsLocked },
  { "cpSpaceNew", (void *)_cffi_f_cpSpaceNew, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 361), (void *)_cffi_d_cpSpaceNew },
  { "cpSpacePointQuery", (void *)_cffi_f_cpSpacePointQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 877), (void *)_cffi_d_cpSpacePointQuery },
  { "cpSpacePointQueryNearest", (void *)_cffi_f_cpSpacePointQueryNearest, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 320), (void *)_cffi_d_cpSpacePointQueryNearest },
  { "cpSpaceReindexShape", (void *)_cffi_f_cpSpaceReindexShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 856), (void *)_cffi_d_cpSpaceReindexShape },
  { "cpSpaceReindexShapesForBody", (void *)_cffi_f_cpSpaceReindexShapesForBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 848), (void *)_cffi_d_cpSpaceReindexShapesForBody },
  { "cpSpaceReindexStatic", (void *)_cffi_f_cpSpaceReindexStatic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 838), (void *)_cffi_d_cpSpaceReindexStatic },
  { "cpSpaceRemoveBody", (void *)_cffi_f_cpSpaceRemoveBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 848), (void *)_cffi_d_cpSpaceRemoveBody },
  { "cpSpaceRemoveConstraint", (void *)_cffi_f_cpSpaceRemoveConstraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 852), (void *)_cffi_d_cpSpaceRemoveConstraint },
  { "cpSpaceRemoveShape", (void *)_cffi_f_cpSpaceRemoveShape, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 856), (void *)_cffi_d_cpSpaceRemoveShape },
  { "cpSpaceSegmentQuery", (void *)_cffi_f_cpSpaceSegmentQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 868), (void *)_cffi_d_cpSpaceSegmentQuery },
  { "cpSpaceSegmentQueryFirst", (void *)_cffi_f_cpSpaceSegmentQueryFirst, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 312), (void *)_cffi_d_cpSpaceSegmentQueryFirst },
  { "cpSpaceSetCollisionBias", (void *)_cffi_f_cpSpaceSetCollisionBias, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceSetCollisionBias },
  { "cpSpaceSetCollisionPersistence", (void *)_cffi_f_cpSpaceSetCollisionPersistence, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 902), (void *)_cffi_d_cpSpaceSetCollisionPersistence },
  { "cpSpaceSetCollisionSlop", (void *)_cffi_f_cpSpaceSetCollisionSlop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceSetCollisionSlop },
  { "cpSpaceSetDamping", (void *)_cffi_f_cpSpaceSetDamping, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceSetDamping },
  { "cpSpaceSetGravity", (void *)_cffi_f_cpSpaceSetGravity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 864), (void *)_cffi_d_cpSpaceSetGravity },
  { "cpSpaceSetIdleSpeedThreshold", (void *)_cffi_f_cpSpaceSetIdleSpeedThreshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceSetIdleSpeedThreshold },
  { "cpSpaceSetIterations", (void *)_cffi_f_cpSpaceSetIterations, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 898), (void *)_cffi_d_cpSpaceSetIterations },
  { "cpSpaceSetSleepTimeThreshold", (void *)_cffi_f_cpSpaceSetSleepTimeThreshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceSetSleepTimeThreshold },
  { "cpSpaceSetStaticBody", (void *)_cffi_f_cpSpaceSetStaticBody, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 848), (void *)_cffi_d_cpSpaceSetStaticBody },
  { "cpSpaceSetUserData", (void *)_cffi_f_cpSpaceSetUserData, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 910), (void *)_cffi_d_cpSpaceSetUserData },
  { "cpSpaceShapeQuery", (void *)_cffi_f_cpSpaceShapeQuery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 580), (void *)_cffi_d_cpSpaceShapeQuery },
  { "cpSpaceStep", (void *)_cffi_f_cpSpaceStep, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 889), (void *)_cffi_d_cpSpaceStep },
  { "cpSpaceUseSpatialHash", (void *)_cffi_f_cpSpaceUseSpatialHash, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 893), (void *)_cffi_d_cpSpaceUseSpatialHash },
  { "cpVersionString", (void *)_cffi_var_cpVersionString, _CFFI_OP(_CFFI_OP_GLOBAL_VAR_F, 983), (void *)0 },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "l", offsetof(cpBB, l),
         sizeof(((cpBB *)0)->l),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "b", offsetof(cpBB, b),
         sizeof(((cpBB *)0)->b),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "r", offsetof(cpBB, r),
         sizeof(((cpBB *)0)->r),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "t", offsetof(cpBB, t),
         sizeof(((cpBB *)0)->t),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "typeA", offsetof(cpCollisionHandler, typeA),
             sizeof(((cpCollisionHandler *)0)->typeA),
             _CFFI_OP(_CFFI_OP_NOOP, 73) },
  { "typeB", offsetof(cpCollisionHandler, typeB),
             sizeof(((cpCollisionHandler *)0)->typeB),
             _CFFI_OP(_CFFI_OP_NOOP, 73) },
  { "beginFunc", offsetof(cpCollisionHandler, beginFunc),
                 sizeof(((cpCollisionHandler *)0)->beginFunc),
                 _CFFI_OP(_CFFI_OP_NOOP, 1024) },
  { "preSolveFunc", offsetof(cpCollisionHandler, preSolveFunc),
                    sizeof(((cpCollisionHandler *)0)->preSolveFunc),
                    _CFFI_OP(_CFFI_OP_NOOP, 1024) },
  { "postSolveFunc", offsetof(cpCollisionHandler, postSolveFunc),
                     sizeof(((cpCollisionHandler *)0)->postSolveFunc),
                     _CFFI_OP(_CFFI_OP_NOOP, 1025) },
  { "separateFunc", offsetof(cpCollisionHandler, separateFunc),
                    sizeof(((cpCollisionHandler *)0)->separateFunc),
                    _CFFI_OP(_CFFI_OP_NOOP, 1025) },
  { "userData", offsetof(cpCollisionHandler, userData),
                sizeof(((cpCollisionHandler *)0)->userData),
                _CFFI_OP(_CFFI_OP_NOOP, 365) },
  { "count", offsetof(cpContactPointSet, count),
             sizeof(((cpContactPointSet *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "normal", offsetof(cpContactPointSet, normal),
              sizeof(((cpContactPointSet *)0)->normal),
              _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "points", offsetof(cpContactPointSet, points),
              sizeof(((cpContactPointSet *)0)->points),
              _CFFI_OP(_CFFI_OP_NOOP, 1022) },
  { "shape", offsetof(cpPointQueryInfo, shape),
             sizeof(((cpPointQueryInfo *)0)->shape),
             _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "point", offsetof(cpPointQueryInfo, point),
             sizeof(((cpPointQueryInfo *)0)->point),
             _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "distance", offsetof(cpPointQueryInfo, distance),
                sizeof(((cpPointQueryInfo *)0)->distance),
                _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "gradient", offsetof(cpPointQueryInfo, gradient),
                sizeof(((cpPointQueryInfo *)0)->gradient),
                _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "count", offsetof(cpPolyline, count),
             sizeof(((cpPolyline *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "capacity", offsetof(cpPolyline, capacity),
                sizeof(((cpPolyline *)0)->capacity),
                _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "verts", offsetof(cpPolyline, verts),
             (size_t)-1,
             _CFFI_OP(_CFFI_OP_NOOP, 1019) },
  { "count", offsetof(cpPolylineSet, count),
             sizeof(((cpPolylineSet *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "capacity", offsetof(cpPolylineSet, capacity),
                sizeof(((cpPolylineSet *)0)->capacity),
                _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "lines", offsetof(cpPolylineSet, lines),
             sizeof(((cpPolylineSet *)0)->lines),
             _CFFI_OP(_CFFI_OP_NOOP, 1003) },
  { "shape", offsetof(cpSegmentQueryInfo, shape),
             sizeof(((cpSegmentQueryInfo *)0)->shape),
             _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "point", offsetof(cpSegmentQueryInfo, point),
             sizeof(((cpSegmentQueryInfo *)0)->point),
             _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "normal", offsetof(cpSegmentQueryInfo, normal),
              sizeof(((cpSegmentQueryInfo *)0)->normal),
              _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "alpha", offsetof(cpSegmentQueryInfo, alpha),
             sizeof(((cpSegmentQueryInfo *)0)->alpha),
             _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "group", offsetof(cpShapeFilter, group),
             sizeof(((cpShapeFilter *)0)->group),
             _CFFI_OP(_CFFI_OP_NOOP, 73) },
  { "categories", offsetof(cpShapeFilter, categories),
                  sizeof(((cpShapeFilter *)0)->categories),
                  _CFFI_OP(_CFFI_OP_NOOP, 904) },
  { "mask", offsetof(cpShapeFilter, mask),
            sizeof(((cpShapeFilter *)0)->mask),
            _CFFI_OP(_CFFI_OP_NOOP, 904) },
  { "r", offsetof(cpSpaceDebugColor, r),
         sizeof(((cpSpaceDebugColor *)0)->r),
         _CFFI_OP(_CFFI_OP_NOOP, 1020) },
  { "g", offsetof(cpSpaceDebugColor, g),
         sizeof(((cpSpaceDebugColor *)0)->g),
         _CFFI_OP(_CFFI_OP_NOOP, 1020) },
  { "b", offsetof(cpSpaceDebugColor, b),
         sizeof(((cpSpaceDebugColor *)0)->b),
         _CFFI_OP(_CFFI_OP_NOOP, 1020) },
  { "a", offsetof(cpSpaceDebugColor, a),
         sizeof(((cpSpaceDebugColor *)0)->a),
         _CFFI_OP(_CFFI_OP_NOOP, 1020) },
  { "drawCircle", offsetof(cpSpaceDebugDrawOptions, drawCircle),
                  sizeof(((cpSpaceDebugDrawOptions *)0)->drawCircle),
                  _CFFI_OP(_CFFI_OP_NOOP, 1028) },
  { "drawSegment", offsetof(cpSpaceDebugDrawOptions, drawSegment),
                   sizeof(((cpSpaceDebugDrawOptions *)0)->drawSegment),
                   _CFFI_OP(_CFFI_OP_NOOP, 1026) },
  { "drawFatSegment", offsetof(cpSpaceDebugDrawOptions, drawFatSegment),
                      sizeof(((cpSpaceDebugDrawOptions *)0)->drawFatSegment),
                      _CFFI_OP(_CFFI_OP_NOOP, 1027) },
  { "drawPolygon", offsetof(cpSpaceDebugDrawOptions, drawPolygon),
                   sizeof(((cpSpaceDebugDrawOptions *)0)->drawPolygon),
                   _CFFI_OP(_CFFI_OP_NOOP, 1030) },
  { "drawDot", offsetof(cpSpaceDebugDrawOptions, drawDot),
               sizeof(((cpSpaceDebugDrawOptions *)0)->drawDot),
               _CFFI_OP(_CFFI_OP_NOOP, 1029) },
  { "flags", offsetof(cpSpaceDebugDrawOptions, flags),
             sizeof(((cpSpaceDebugDrawOptions *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 1016) },
  { "shapeOutlineColor", offsetof(cpSpaceDebugDrawOptions, shapeOutlineColor),
                         sizeof(((cpSpaceDebugDrawOptions *)0)->shapeOutlineColor),
                         _CFFI_OP(_CFFI_OP_NOOP, 942) },
  { "colorForShape", offsetof(cpSpaceDebugDrawOptions, colorForShape),
                     sizeof(((cpSpaceDebugDrawOptions *)0)->colorForShape),
                     _CFFI_OP(_CFFI_OP_NOOP, 1015) },
  { "constraintColor", offsetof(cpSpaceDebugDrawOptions, constraintColor),
                       sizeof(((cpSpaceDebugDrawOptions *)0)->constraintColor),
                       _CFFI_OP(_CFFI_OP_NOOP, 942) },
  { "collisionPointColor", offsetof(cpSpaceDebugDrawOptions, collisionPointColor),
                           sizeof(((cpSpaceDebugDrawOptions *)0)->collisionPointColor),
                           _CFFI_OP(_CFFI_OP_NOOP, 942) },
  { "data", offsetof(cpSpaceDebugDrawOptions, data),
            sizeof(((cpSpaceDebugDrawOptions *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 365) },
  { "a", offsetof(cpTransform, a),
         sizeof(((cpTransform *)0)->a),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "b", offsetof(cpTransform, b),
         sizeof(((cpTransform *)0)->b),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "c", offsetof(cpTransform, c),
         sizeof(((cpTransform *)0)->c),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "d", offsetof(cpTransform, d),
         sizeof(((cpTransform *)0)->d),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "tx", offsetof(cpTransform, tx),
          sizeof(((cpTransform *)0)->tx),
          _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "ty", offsetof(cpTransform, ty),
          sizeof(((cpTransform *)0)->ty),
          _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "x", offsetof(cpVect, x),
         sizeof(((cpVect *)0)->x),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "y", offsetof(cpVect, y),
         sizeof(((cpVect *)0)->y),
         _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "num", offsetof(cpVectArr, num),
           sizeof(((cpVectArr *)0)->num),
           _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "max", offsetof(cpVectArr, max),
           sizeof(((cpVectArr *)0)->max),
           _CFFI_OP(_CFFI_OP_NOOP, 219) },
  { "arr", offsetof(cpVectArr, arr),
           sizeof(((cpVectArr *)0)->arr),
           _CFFI_OP(_CFFI_OP_NOOP, 818) },
  { "pointA", (size_t)-1,
              (size_t)-1,
              _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "pointB", (size_t)-1,
              (size_t)-1,
              _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "distance", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 20) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$1", 1021, _CFFI_F_CHECK_FIELDS,
    (size_t)-2, -2, 57, 3 /* unnamed */ },
  { "cpArbiter", 985, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpArray", 986, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpBB", 1, _CFFI_F_CHECK_FIELDS,
    sizeof(cpBB), offsetof(struct _cffi_align__cpBB, y), 0, 4 },
  { "cpBody", 987, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpCircleShape", 988, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpCollisionHandler", 990, _CFFI_F_CHECK_FIELDS,
    sizeof(cpCollisionHandler), offsetof(struct _cffi_align__cpCollisionHandler, y), 4, 7 },
  { "cpConstraint", 991, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpContactPointSet", 992, _CFFI_F_CHECK_FIELDS,
    sizeof(cpContactPointSet), offsetof(struct _cffi_align__cpContactPointSet, y), 11, 3 },
  { "cpDampedRotarySpring", 993, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpDampedSpring", 994, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpGearJoint", 995, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpGrooveJoint", 996, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpHashSet", 997, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpHastySpace", 998, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpPinJoint", 999, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpPivotJoint", 1000, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpPointQueryInfo", 1001, _CFFI_F_CHECK_FIELDS,
    sizeof(cpPointQueryInfo), offsetof(struct _cffi_align__cpPointQueryInfo, y), 14, 4 },
  { "cpPolyShape", 1002, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpPolyline", 1004, _CFFI_F_CHECK_FIELDS,
    sizeof(cpPolyline), offsetof(struct _cffi_align__cpPolyline, y), 18, 3 },
  { "cpPolylineSet", 1005, _CFFI_F_CHECK_FIELDS,
    sizeof(cpPolylineSet), offsetof(struct _cffi_align__cpPolylineSet, y), 21, 3 },
  { "cpRatchetJoint", 1006, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpRotaryLimitJoint", 1007, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpSegmentQueryInfo", 1008, _CFFI_F_CHECK_FIELDS,
    sizeof(cpSegmentQueryInfo), offsetof(struct _cffi_align__cpSegmentQueryInfo, y), 24, 4 },
  { "cpSegmentShape", 1009, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpShape", 1010, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpShapeFilter", 317, _CFFI_F_CHECK_FIELDS,
    sizeof(cpShapeFilter), offsetof(struct _cffi_align__cpShapeFilter, y), 28, 3 },
  { "cpSimpleMotor", 1011, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpSimpleMotorJoint", 1012, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpSlideJoint", 1013, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpSpace", 1014, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "cpSpaceDebugColor", 942, _CFFI_F_CHECK_FIELDS,
    sizeof(cpSpaceDebugColor), offsetof(struct _cffi_align__cpSpaceDebugColor, y), 31, 4 },
  { "cpSpaceDebugDrawOptions", 1017, _CFFI_F_CHECK_FIELDS,
    sizeof(cpSpaceDebugDrawOptions), offsetof(struct _cffi_align__cpSpaceDebugDrawOptions, y), 35, 11 },
  { "cpTransform", 13, _CFFI_F_CHECK_FIELDS,
    sizeof(cpTransform), offsetof(struct _cffi_align__cpTransform, y), 46, 6 },
  { "cpVect", 6, _CFFI_F_CHECK_FIELDS,
    sizeof(cpVect), offsetof(struct _cffi_align__cpVect, y), 52, 2 },
  { "cpVectArr", 1018, _CFFI_F_CHECK_FIELDS,
    sizeof(cpVectArr), offsetof(struct _cffi_align__cpVectArr, y), 54, 3 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "cpBodyType", 672, _cffi_prim_int(sizeof(cpBodyType), ((cpBodyType)-1) <= 0),
    "CP_BODY_TYPE_DYNAMIC,CP_BODY_TYPE_KINEMATIC,CP_BODY_TYPE_STATIC" },
  { "cpSpaceDebugDrawFlags", 1016, _cffi_prim_int(sizeof(cpSpaceDebugDrawFlags), ((cpSpaceDebugDrawFlags)-1) <= 0),
    "CP_SPACE_DEBUG_DRAW_SHAPES,CP_SPACE_DEBUG_DRAW_CONSTRAINTS,CP_SPACE_DEBUG_DRAW_COLLISION_POINTS" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "cpArbiter", 985 },
  { "cpArray", 986 },
  { "cpBB", 1 },
  { "cpBitmask", 904 },
  { "cpBody", 987 },
  { "cpBodyArbiterIteratorFunc", 713 },
  { "cpBodyConstraintIteratorFunc", 718 },
  { "cpBodyPositionFunc", 732 },
  { "cpBodyShapeIteratorFunc", 723 },
  { "cpBodyType", 672 },
  { "cpBodyVelocityFunc", 728 },
  { "cpBool", 755 },
  { "cpCircleShape", 988 },
  { "cpCollisionBeginFunc", 1024 },
  { "cpCollisionHandler", 990 },
  { "cpCollisionPostSolveFunc", 1025 },
  { "cpCollisionPreSolveFunc", 1024 },
  { "cpCollisionSeparateFunc", 1025 },
  { "cpCollisionType", 73 },
  { "cpConstraint", 991 },
  { "cpConstraintPostSolveFunc", 763 },
  { "cpConstraintPreSolveFunc", 763 },
  { "cpContactPointSet", 992 },
  { "cpDampedRotarySpring", 993 },
  { "cpDampedRotarySpringTorqueFunc", 747 },
  { "cpDampedSpring", 994 },
  { "cpDampedSpringForceFunc", 747 },
  { "cpDataPointer", 365 },
  { "cpFloat", 20 },
  { "cpGearJoint", 995 },
  { "cpGrooveJoint", 996 },
  { "cpGroup", 73 },
  { "cpHashSet", 997 },
  { "cpHastySpace", 998 },
  { "cpMarchSampleFunc", 655 },
  { "cpMarchSegmentFunc", 653 },
  { "cpPinJoint", 999 },
  { "cpPivotJoint", 1000 },
  { "cpPointQueryInfo", 1001 },
  { "cpPolyShape", 1002 },
  { "cpPolyline", 1004 },
  { "cpPolylineSet", 1005 },
  { "cpPostStepFunc", 588 },
  { "cpRatchetJoint", 1006 },
  { "cpRotaryLimitJoint", 1007 },
  { "cpSegmentQueryInfo", 1008 },
  { "cpSegmentShape", 1009 },
  { "cpShape", 1010 },
  { "cpShapeFilter", 317 },
  { "cpSimpleMotor", 1011 },
  { "cpSimpleMotorJoint", 1012 },
  { "cpSlideJoint", 1013 },
  { "cpSpace", 1014 },
  { "cpSpaceBBQueryFunc", 845 },
  { "cpSpaceBodyIteratorFunc", 921 },
  { "cpSpaceConstraintIteratorFunc", 926 },
  { "cpSpaceDebugColor", 942 },
  { "cpSpaceDebugDrawCircleImpl", 1028 },
  { "cpSpaceDebugDrawColorForShapeImpl", 1015 },
  { "cpSpaceDebugDrawDotImpl", 1029 },
  { "cpSpaceDebugDrawFatSegmentImpl", 1027 },
  { "cpSpaceDebugDrawFlags", 1016 },
  { "cpSpaceDebugDrawOptions", 1017 },
  { "cpSpaceDebugDrawPolygonImpl", 1030 },
  { "cpSpaceDebugDrawSegmentImpl", 1026 },
  { "cpSpacePointQueryFunc", 882 },
  { "cpSpaceSegmentQueryFunc", 874 },
  { "cpSpaceShapeIteratorFunc", 845 },
  { "cpSpaceShapeQueryFunc", 583 },
  { "cpTimestamp", 904 },
  { "cpTransform", 13 },
  { "cpVect", 6 },
  { "cpVectArr", 1018 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  375,  /* num_globals */
  36,  /* num_struct_unions */
  2,  /* num_enums */
  73,  /* num_typenames */
  NULL,  /* no includes */
  1032,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__chipmunk(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__chipmunk(void) { return NULL; }
#  else
     init_chipmunk(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__chipmunk(void)
{
  return _cffi_init("pymunk._chipmunk", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_chipmunk(void)
{
  _cffi_init("pymunk._chipmunk", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
